@@ -65,6 +65,10 @@ static char faceColorChar[MAX_COLORS] =
 #else
 #include "picture.h"
 
+#if defined( USE_SOUND ) && defined( USE_NAS )
+Display *dsp;
+#endif
+
 #ifndef LOGPATH
 #ifdef VMS
 #define LOGPATH "SYS$SCRATCH:"
@@ -2371,6 +2375,11 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int i;
 
+#if 0
+#if defined( USE_SOUND ) && defined( USE_ESOUND )
+	(void) shutdown_sound();
+#endif
+#endif
 	for (i = 0; i < MAX_COLORS; i++)
 		XtReleaseGC(old, w->barrel.faceGC[i]);
 	for (i = 0; i < FG_SHADES; i++)
@@ -2596,6 +2605,16 @@ Widget request, Widget renew
 		w->barrel.delay + 1 : MAX_SLICES);
 	w->barrel.cheat = False;
 	sizePuzzle(w);
+#ifdef USE_SOUND
+#ifdef USE_NAS
+	dsp = XtDisplay(w);
+#endif
+#if 0
+#ifdef USE_ESOUND
+	(void) init_sound();
+#endif
+#endif
+#endif
 }
 
 void
