@@ -1,30 +1,25 @@
-/*-
-# X-BASED BARREL(tm)
-#
-#  BarrelS.c
-#
-###
-#
-#  Taken from James G. Nourse's The Simple Solutions to Cubic Puzzles.
-#  Break ability taken from the X puzzle by Don Bennett, HP Labs
-#
-#  Copyright (c) 2003 - 2007    David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)BarrelS.c
+ *
+ * Taken from James G. Nourse's The Simple Solutions to Cubic Puzzles.
+ * Break ability taken from the X puzzle by Don Bennett, HP Labs
+ *
+ * Copyright 2003 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Solver file for Barrel */
 
@@ -35,13 +30,13 @@
 #endif
 #include "BarrelP.h"
 
-static Boolean SolvingFlag = False;
+static Boolean solvingFlag = False;
 #ifdef JMP
-static Boolean AbortSolvingFlag = False;
+static Boolean abortSolvingFlag = False;
 static jmp_buf solve_env;
 
 #ifdef DEBUG
-void PrintPuzzle(BarrelWidget w);
+void printPuzzle(BarrelWidget w);
 
 static char * colorName(int color)
 {
@@ -80,22 +75,22 @@ checkLastColorMatch(int colors[], int last)
 }
 
 static void
-AbortSolving(void)
+abortSolving(void)
 {
-	if (SolvingFlag)
-		AbortSolvingFlag = True;
+	if (solvingFlag)
+		abortSolvingFlag = True;
 }
 
 #ifdef WINVER
 static Boolean
-ProcessMessage(UINT msg)
+processMessage(UINT msg)
 {
 	switch (msg) {
 	case WM_KEYDOWN:
 	case WM_CLOSE:
 	case WM_LBUTTONDOWN:
 	case WM_RBUTTONDOWN:
-		AbortSolving();
+		abortSolving();
 		return True;
 	default:
 		return False;
@@ -103,35 +98,35 @@ ProcessMessage(UINT msg)
 }
 #else
 static void
-ProcessButton(void /*XButtonEvent *event*/)
+processButton(void /*XButtonEvent *event*/)
 {
-	AbortSolving();
+	abortSolving();
 }
 
 static void
-ProcessVisibility(XVisibilityEvent *event)
+processVisibility(XVisibilityEvent *event)
 {
 	if (event->state != VisibilityUnobscured)
-		AbortSolving();
+		abortSolving();
 }
 
 static void
-GetNextEvent(BarrelWidget w, XEvent *event)
+getNextEvent(BarrelWidget w, XEvent *event)
 {
 	if (!XCheckMaskEvent(XtDisplay(w), VisibilityChangeMask, event))
 		(void) XNextEvent(XtDisplay(w), event);
 }
 
 static void
-ProcessEvent(XEvent *event)
+processEvent(XEvent *event)
 {
 	switch(event->type) {
 	case KeyPress:
 	case ButtonPress:
-		ProcessButton(/*&event->xbutton*/);
+		processButton(/*&event->xbutton*/);
 		break;
 	case VisibilityNotify:
-		ProcessVisibility(&event->xvisibility);
+		processVisibility(&event->xvisibility);
 		break;
 	default:
 		break;
@@ -139,20 +134,20 @@ ProcessEvent(XEvent *event)
 }
 
 static void
-ProcessEvents(BarrelWidget w)
+processEvents(BarrelWidget w)
 {
 	XEvent event;
 
 	while (XPending(XtDisplay(w))) {
-		GetNextEvent(w, &event);
-		ProcessEvent(&event);
+		getNextEvent(w, &event);
+		processEvent(&event);
 	}
 }
 #endif
 #endif
 
 static void
-MoveTilePiece(BarrelWidget w,
+moveTilePiece(BarrelWidget w,
 	const int direction, const int tile,
 	const Boolean all)
 {
@@ -161,18 +156,18 @@ MoveTilePiece(BarrelWidget w,
 	MSG msg;
 
 	if (PeekMessage(&msg, NULL, 0, 0, 0)) {
-		if (!ProcessMessage(msg.message)) {
+		if (!processMessage(msg.message)) {
 			if (GetMessage(&msg, NULL, 0, 0))
 				DispatchMessage(&msg);
 		}
 	}
 #else
-	ProcessEvents(w);
+	processEvents(w);
 #endif
-	if (SolvingFlag && AbortSolvingFlag)
+	if (solvingFlag && abortSolvingFlag)
 		longjmp(solve_env, 1);
 #endif
-	MovePuzzleDelay(w, direction, tile, all);
+	movePuzzleDelay(w, direction, tile, all);
 }
 
 #define ORIENTTILE(x,y) (w->barrel.tileOfPosition[y*w->barrel.tiles+x])
@@ -184,14 +179,14 @@ MoveTilePiece(BarrelWidget w,
 #define SOLVEDTILE(x,y) ((w->barrel.orient)?ORIENTTILE(x,y):COLORTILE(x,y))
 
 static int
-CheckLevelSolved(const BarrelWidget w, int i)
+checkLevelSolved(const BarrelWidget w, int i)
 {
 	int color, j, inc;
 
 	if (w->barrel.orient) {
 		for (j = 0; j < w->barrel.faces; j++) {
-			color = COLORTILE(1,j);
-			inc = LEVELTILE(1,j);
+			color = COLORTILE(1, j);
+			inc = LEVELTILE(1, j);
 			if (i >= 2 && i <= w->barrel.tiles - 2) {
 				if (color != COLORTILE(i, j)) {
 					return j;
@@ -207,7 +202,7 @@ CheckLevelSolved(const BarrelWidget w, int i)
 				if (j != 0 && color == COLORTILE(i, j))
 					return j;
 			} else if (i == w->barrel.faces &&
-					j % 2 == 1 &&
+					(j & 1) == 1 &&
 					color != w->barrel.faces &&
 					LEVELTILE(w->barrel.tiles - 1, j) <
 					w->barrel.faces) {
@@ -230,7 +225,7 @@ CheckLevelSolved(const BarrelWidget w, int i)
 					if (color == COLORTILE(i, k))
 						return j;
 			} else if (i == w->barrel.faces &&
-					j % 2 == 1 &&
+					(j & 1) == 1 &&
 					color != w->barrel.faces) {
 				return j;
 			}
@@ -240,7 +235,7 @@ CheckLevelSolved(const BarrelWidget w, int i)
 }
 
 static int
-FindOtherColor(BarrelWidget w, int level, int colors[])
+findOtherColor(BarrelWidget w, int level, int colors[])
 {
 	int i, j, color;
 	int nrand = NRANDOM(2);
@@ -261,7 +256,7 @@ FindOtherColor(BarrelWidget w, int level, int colors[])
 				j = (w->barrel.faces - 1) / 2 + (i + 1) / 2;
 			}
 		}
-		if (j % 2 == 1 && (level == 2 || level == 5))
+		if ((j & 1) == 1 && (level == 2 || level == 5))
 			continue;
 		for (color = 0; color < w->barrel.faces; color++) {
 			if (COLORTILE(level, j) == colors[color]) {
@@ -277,7 +272,7 @@ FindOtherColor(BarrelWidget w, int level, int colors[])
 }
 
 static int
-FindMatch(BarrelWidget w, int level, int match)
+findMatch(BarrelWidget w, int level, int match)
 {
 	int face;
 
@@ -290,7 +285,7 @@ FindMatch(BarrelWidget w, int level, int match)
 }
 
 static int
-FindLevelOrient(BarrelWidget w, int match)
+findLevelOrient(BarrelWidget w, int match)
 {
 	int face, level;
 
@@ -305,7 +300,7 @@ FindLevelOrient(BarrelWidget w, int match)
 }
 
 static int
-FindFaceOrient(BarrelWidget w, int level, int match)
+findFaceOrient(BarrelWidget w, int level, int match)
 {
 	int face;
 
@@ -318,26 +313,26 @@ FindFaceOrient(BarrelWidget w, int level, int match)
 }
 
 #define LeftAway(w) if (!w->barrel.pairs){\
-  MoveTilePiece(w,TOP,1,False);MoveTilePiece(w,TOP,2,False);}else\
-  MoveTilePiece(w,TOP,1,False)
+  moveTilePiece(w,TOP,1,False);moveTilePiece(w,TOP,2,False);}else\
+  moveTilePiece(w,TOP,1,False)
 #define LeftAway2(w) LeftAway(w);LeftAway(w)
 #define LeftTowards(w) if (!w->barrel.pairs){\
-  MoveTilePiece(w,BOTTOM,1,False);MoveTilePiece(w,BOTTOM,2,False);}else\
-  MoveTilePiece(w,BOTTOM,1,False)
+  moveTilePiece(w,BOTTOM,1,False);moveTilePiece(w,BOTTOM,2,False);}else\
+  moveTilePiece(w,BOTTOM,1,False)
 #define LeftTowards2(w) LeftTowards(w);LeftTowards(w)
 #define RightAway(w) if (!w->barrel.pairs){\
-  MoveTilePiece(w,TOP,w->barrel.tiles-2,False);\
-  MoveTilePiece(w,TOP,w->barrel.tiles-3,False);}else\
-  MoveTilePiece(w,TOP,w->barrel.tiles-2,False)
+  moveTilePiece(w,TOP,w->barrel.tiles-2,False);\
+  moveTilePiece(w,TOP,w->barrel.tiles-3,False);}else\
+  moveTilePiece(w,TOP,w->barrel.tiles-2,False)
 #define RightAway2(w) RightAway(w);RightAway(w)
 #define RightTowards(w) if (!w->barrel.pairs){\
-  MoveTilePiece(w,BOTTOM,w->barrel.tiles-2,False);\
-  MoveTilePiece(w,BOTTOM,w->barrel.tiles-3,False);}else\
-  MoveTilePiece(w,BOTTOM,w->barrel.tiles-2,False)
+  moveTilePiece(w,BOTTOM,w->barrel.tiles-2,False);\
+  moveTilePiece(w,BOTTOM,w->barrel.tiles-3,False);}else\
+  moveTilePiece(w,BOTTOM,w->barrel.tiles-2,False)
 #define RightTowards2(w) RightTowards(w);RightTowards(w)
 
-#define LeftSlide(w) MoveTilePiece(w,LEFT,-1,False)
-#define RightSlide(w) MoveTilePiece(w,RIGHT,1,False)
+#define LeftSlide(w) moveTilePiece(w,LEFT,-1,False)
+#define RightSlide(w) moveTilePiece(w,RIGHT,1,False)
 
 /*
 John Ewing & Czes Kosniowski, Puzzle it Out: "
@@ -670,10 +665,10 @@ Bantam Books, New York, November 1981, "The Barrel", pp 24-42.
   LeftSlide(w);RightAway2(w);RightSlide(w);RightTowards(w)
 
 static int
-FindL1Color(BarrelWidget w, int colors[])
+findL1Color(BarrelWidget w, int colors[])
 {
 	int searchLevel = 3;
-	int piece = FindOtherColor(w, searchLevel, colors);
+	int piece = findOtherColor(w, searchLevel, colors);
 
 #ifdef DEBUG
 	(void) printf("1: search level %d, piece %d\n", searchLevel, piece);
@@ -695,7 +690,7 @@ FindL1Color(BarrelWidget w, int colors[])
 		return CENTER();
 	}
 	searchLevel = 4;
-	piece = FindOtherColor(w, searchLevel, colors);
+	piece = findOtherColor(w, searchLevel, colors);
 #ifdef DEBUG
 	(void) printf("1: search level %d, piece %d\n", searchLevel, piece);
 #endif
@@ -721,7 +716,7 @@ FindL1Color(BarrelWidget w, int colors[])
 		return CENTER();
 	}
 	searchLevel = 5;
-	piece = FindOtherColor(w, searchLevel, colors);
+	piece = findOtherColor(w, searchLevel, colors);
 #ifdef DEBUG
 	(void) printf("1: search level %d, piece %d\n", searchLevel, piece);
 #endif
@@ -737,7 +732,7 @@ FindL1Color(BarrelWidget w, int colors[])
 		return CENTER();
 	}
 	searchLevel = 2;
-	piece = FindOtherColor(w, searchLevel, colors);
+	piece = findOtherColor(w, searchLevel, colors);
 #ifdef DEBUG
 	(void) printf("1: search level %d, piece %d\n", searchLevel, piece);
 #endif
@@ -758,7 +753,7 @@ FindL1Color(BarrelWidget w, int colors[])
 		RightAway(w);
 		return CENTER();
 	}
-	(void) printf("FindL1Color: Could not find!\n");
+	(void) printf("findL1Color: Could not find!\n");
 	return 5;
 }
 
@@ -766,7 +761,7 @@ static int
 findL2(BarrelWidget w, int color)
 {
 	int searchLevel = 3;
-	int piece = FindMatch(w, searchLevel, color);
+	int piece = findMatch(w, searchLevel, color);
 
 #ifdef DEBUG
 	(void) printf("2: search level %d, %d\n", searchLevel, piece);
@@ -788,7 +783,7 @@ findL2(BarrelWidget w, int color)
 		return CENTER();
 	}
 	searchLevel = 4;
-	piece = FindMatch(w, searchLevel, color);
+	piece = findMatch(w, searchLevel, color);
 #ifdef DEBUG
 	(void) printf("2: search level %d, %d\n", searchLevel, piece);
 #endif
@@ -814,7 +809,7 @@ findL2(BarrelWidget w, int color)
 		return CENTER();
 	}
 	searchLevel = 5;
-	piece = FindMatch(w, searchLevel, color);
+	piece = findMatch(w, searchLevel, color);
 #ifdef DEBUG
 	(void) printf("2: search level %d, %d\n", searchLevel, piece);
 #endif
@@ -830,7 +825,7 @@ findL2(BarrelWidget w, int color)
 		return CENTER();
 	}
 	searchLevel = 2;
-	piece = FindMatch(w, searchLevel, color);
+	piece = findMatch(w, searchLevel, color);
 #ifdef DEBUG
 	(void) printf("2: search level %d, %d\n", searchLevel, piece);
 #endif
@@ -856,10 +851,10 @@ findL2(BarrelWidget w, int color)
 }
 
 static int
-FindL3Color(BarrelWidget w, int face, int color)
+findL3Color(BarrelWidget w, int face, int color)
 {
 	int searchLevel = 3;
-	int piece = FindMatch(w, searchLevel, color);
+	int piece = findMatch(w, searchLevel, color);
 
 #ifdef DEBUG
 	(void) printf("3: search level %d, face %d, piece %d\n",
@@ -901,8 +896,8 @@ FindL3Color(BarrelWidget w, int face, int color)
 				return searchLevel;
 			default:
 				(void) printf("Should not get here\n");
-				return searchLevel;
 			}
+			return searchLevel;
 		case 1:
 			switch (face) {
 			case 0: /* 7->3 */
@@ -918,8 +913,8 @@ FindL3Color(BarrelWidget w, int face, int color)
 				return searchLevel;
 			default:
 				(void) printf("Should not get here\n");
-				return searchLevel;
 			}
+			return searchLevel;
 		case 2:
 			(void) printf("Should have been set first\n");
 			return searchLevel;
@@ -941,8 +936,8 @@ FindL3Color(BarrelWidget w, int face, int color)
 				return searchLevel;
 			default:
 				(void) printf("Should not get here\n");
-				return searchLevel;
 			}
+			return searchLevel;
 		case 4:
 			switch (face) {
 			case 0: /* 19->3 */
@@ -960,12 +955,12 @@ FindL3Color(BarrelWidget w, int face, int color)
 				return searchLevel;
 			default:
 				(void) printf("Should not get here\n");
-				return searchLevel;
 			}
+			return searchLevel;
 		}
 	}
 	searchLevel = 4;
-	piece = FindMatch(w, searchLevel, color);
+	piece = findMatch(w, searchLevel, color);
 #ifdef DEBUG
 	(void) printf("3: search level %d, face %d, piece %d\n",
 		searchLevel, face, piece);
@@ -1122,7 +1117,7 @@ FindL3Color(BarrelWidget w, int face, int color)
 	(void) printf("3: search level %d, face %d, piece %d\n",
 		searchLevel, face, piece);
 #endif
-	piece = FindMatch(w, searchLevel, color);
+	piece = findMatch(w, searchLevel, color);
 	switch (piece) {
 	case 0:
 		switch (face) {
@@ -1214,15 +1209,15 @@ FindL3Color(BarrelWidget w, int face, int color)
 		}
 		break;
 	}
-	(void) printf("FindL3Color: Could not find!\n");
+	(void) printf("findL3Color: Could not find!\n");
 	return 0;
 }
 
 static Boolean
-FindL5Color(BarrelWidget w, int face, int color)
+findL5Color(BarrelWidget w, int face, int color)
 {
 	int searchLevel = 4;
-	int piece = FindMatch(w, searchLevel, color);
+	int piece = findMatch(w, searchLevel, color);
 
 #ifdef DEBUG
 	(void) printf("5: search level %d, face %d, piece %d\n",
@@ -1327,15 +1322,15 @@ FindL5Color(BarrelWidget w, int face, int color)
 		}
 		break;
 	}
-	(void) printf("FindL5Color: Could not find!\n");
+	(void) printf("findL5Color: Could not find!\n");
 	return False;
 }
 
 static Boolean
-FindL4Color(BarrelWidget w, int face, int color)
+findL4Color(BarrelWidget w, int face, int color)
 {
 	int searchLevel = 4;
-	int piece = FindMatch(w, searchLevel, color);
+	int piece = findMatch(w, searchLevel, color);
 
 #ifdef DEBUG
 	(void) printf("4: search level %d, face %d, piece %d\n",
@@ -1451,7 +1446,7 @@ FindL4Color(BarrelWidget w, int face, int color)
 		}
 		break;
 	}
-	(void) printf("FindL4Color: Could not find!\n");
+	(void) printf("findL4Color: Could not find!\n");
 	return False;
 }
 
@@ -1469,11 +1464,11 @@ solveRightColor(BarrelWidget w, int level, int face)
 	if (piece == check)
 		return True;
 	if (level == 3) {
-		searchLevel = FindL3Color(w, face, piece);
+		searchLevel = findL3Color(w, face, piece);
 	} else if (level == 4) {
-		(void) FindL4Color(w, face, piece);
+		(void) findL4Color(w, face, piece);
 	} else {
-		(void) FindL5Color(w, face, piece);
+		(void) findL5Color(w, face, piece);
 	}
 	check = COLORTILE(level, face);
 	if (piece != check) {
@@ -1490,22 +1485,22 @@ solveL0(BarrelWidget w)
 		if (w->barrel.tileOfPosition[0] > 0)
 			RightSlide(w);
 		if (w->barrel.spacePosition[2] == 0) {
-			MoveTilePiece(w, TOP, 0, True);
+			moveTilePiece(w, TOP, 0, True);
 		} else if (w->barrel.spacePosition[2] == 6) {
-			MoveTilePiece(w, TOP, 0, True);
-			MoveTilePiece(w, TOP, 0, True);
+			moveTilePiece(w, TOP, 0, True);
+			moveTilePiece(w, TOP, 0, True);
 		} else if (w->barrel.spacePosition[1] == w->barrel.tiles) {
-			MoveTilePiece(w, BOTTOM, 0, True);
+			moveTilePiece(w, BOTTOM, 0, True);
 		} else if (w->barrel.spacePosition[1] == 0) {
-			MoveTilePiece(w, BOTTOM, 0, True);
-			MoveTilePiece(w, BOTTOM, 0, True);
+			moveTilePiece(w, BOTTOM, 0, True);
+			moveTilePiece(w, BOTTOM, 0, True);
 		}
 }
 
 static int
-MoveToCenter(BarrelWidget w, int level, int face)
+moveToCenter(BarrelWidget w, int level, int face)
 {
-	printf("MoveToCenter level %d, face %d\n", level, face);
+	printf("moveToCenter level %d, face %d\n", level, face);
 	/* move to 11 */
 	if (level == 1) {
 		switch (face) {
@@ -1518,12 +1513,12 @@ MoveToCenter(BarrelWidget w, int level, int face)
 			LeftTowards(w);
 			L_1x7(w);
 			LeftAway(w);
-			return MoveToCenter(w, 2, 0);
+			return moveToCenter(w, 2, 0);
 		case 3:
 			LeftAway(w);
 			Lb_1x7(w);
 			LeftTowards(w);
-			return MoveToCenter(w, 2, 4);
+			return moveToCenter(w, 2, 4);
 		case 4:
 			LeftAway2(w);
 			Lx7(w);
@@ -1643,7 +1638,7 @@ static Boolean
 solveL1Orient(BarrelWidget w)
 {
 	int orient[MAX_FACES] = {-1, -1, -1, -1, -1};
-	int piece = CheckLevelSolved(w, 1);
+	int piece = checkLevelSolved(w, 1);
 	int currentLevel, currentFace;
 	int ok = -2;
 
@@ -1656,8 +1651,8 @@ solveL1Orient(BarrelWidget w)
 #endif
 	/* G1 B17 Y9 R5 O13 */
 	if (ORIENTTILE(1, 2) != piece) {
-		currentLevel = FindLevelOrient(w, piece);
-		currentFace = FindFaceOrient(w, currentLevel, piece);
+		currentLevel = findLevelOrient(w, piece);
+		currentFace = findFaceOrient(w, currentLevel, piece);
 		if (currentLevel == 1) {
 			switch (currentFace) {
 			case 0:
@@ -1700,7 +1695,7 @@ solveL1Orient(BarrelWidget w)
 					LeftAway(w);
 				}
 			} else {
-				ok = MoveToCenter(w, currentLevel,
+				ok = moveToCenter(w, currentLevel,
 					currentFace);
 				LeftSlide(w);
 				if (NRANDOM(2) == 1) {
@@ -1728,9 +1723,9 @@ solveL1Orient(BarrelWidget w)
 	piece = 17;
 	(void) printf("solving level 1, piece %d\n", piece);
 	if (ORIENTTILE(2, 2) != piece) {
-		currentLevel = FindLevelOrient(w, piece);
-		currentFace = FindFaceOrient(w, currentLevel, piece);
-		ok = MoveToCenter(w, currentLevel, currentFace);
+		currentLevel = findLevelOrient(w, piece);
+		currentFace = findFaceOrient(w, currentLevel, piece);
+		ok = moveToCenter(w, currentLevel, currentFace);
 		L2_3222(w);
 		(void) printf("solving level 1, %d %d\n",
 			currentLevel, currentFace);
@@ -1744,9 +1739,9 @@ solveL1Orient(BarrelWidget w)
 	piece = 9;
 	(void) printf("solving level 1, piece %d\n", piece);
 	if (ORIENTTILE(3, 2) != piece) {
-		currentLevel = FindLevelOrient(w, piece);
-		currentFace = FindFaceOrient(w, currentLevel, piece);
-		ok = MoveToCenter(w, currentLevel, currentFace);
+		currentLevel = findLevelOrient(w, piece);
+		currentFace = findFaceOrient(w, currentLevel, piece);
+		ok = moveToCenter(w, currentLevel, currentFace);
 		(void) printf("solving level 1, %d %d\n",
 			currentLevel, currentFace);
 	}
@@ -1778,9 +1773,9 @@ solveL1Orient(BarrelWidget w)
 	piece = 5;
 	(void) printf("solving level 1, piece %d\n", piece);
 	if (ORIENTTILE(2, 1) != piece) {
-		currentLevel = FindLevelOrient(w, piece);
-		currentFace = FindFaceOrient(w, currentLevel, piece);
-		ok = MoveToCenter(w, currentLevel, currentFace);
+		currentLevel = findLevelOrient(w, piece);
+		currentFace = findFaceOrient(w, currentLevel, piece);
+		ok = moveToCenter(w, currentLevel, currentFace);
 		(void) printf("solving level 1, %d %d\n",
 			currentLevel, currentFace);
 		L1_E(w);
@@ -1797,9 +1792,9 @@ solveL1Orient(BarrelWidget w)
 	piece = 13;
 	(void) printf("solving level 1, piece %d\n", piece);
 	if (ORIENTTILE(2, 3) != piece) {
-		currentLevel = FindLevelOrient(w, piece);
-		currentFace = FindFaceOrient(w, currentLevel, piece);
-		ok = MoveToCenter(w, currentLevel, currentFace);
+		currentLevel = findLevelOrient(w, piece);
+		currentFace = findFaceOrient(w, currentLevel, piece);
+		ok = moveToCenter(w, currentLevel, currentFace);
 		(void) printf("solving level 1, %d %d\n",
 			currentLevel, currentFace);
 		L1_F(w);
@@ -1830,7 +1825,7 @@ static Boolean
 solveL1Color(BarrelWidget w)
 {
 	int colors[MAX_FACES+1] = {-1, -1, -1, -1, -1, -1};
-	int piece = CheckLevelSolved(w, 1);
+	int piece = checkLevelSolved(w, 1);
 
 	if (piece == w->barrel.faces) {
 		return True;
@@ -1843,20 +1838,18 @@ solveL1Color(BarrelWidget w)
 		if (NRANDOM(2) == 1) {
 			if (COLORTILE(1, 1) != w->barrel.faces) {
 				LeftTowards(w);
-			} else if (COLORTILE(1, 3) !=
-					w->barrel.faces) {
-				LeftAway(w);
-			} else {
+			} else if (COLORTILE(1, 3) == w->barrel.faces) {
 				LeftTowards2(w);
+			} else {
+				LeftAway(w);
 			}
 		} else {
 			if (COLORTILE(1, 3) != w->barrel.faces) {
 				LeftAway(w);
-			} else if (COLORTILE(1, 1) !=
-					w->barrel.faces) {
-				LeftTowards(w);
-			} else {
+			} else if (COLORTILE(1, 1) == w->barrel.faces) {
 				LeftAway2(w);
+			} else {
+				LeftTowards(w);
 			}
 		}
 	}
@@ -1871,7 +1864,7 @@ solveL1Color(BarrelWidget w)
 		if (checkLastColorMatch(colors, 2)) {
 			colors[2] = -1;
 			/* rotate 3rd column to non black and non matching */
-			colors[2] = FindL1Color(w, colors);
+			colors[2] = findL1Color(w, colors);
 			L1_B(w);
 		} else {
 			LeftAway(w);
@@ -1887,7 +1880,7 @@ solveL1Color(BarrelWidget w)
 		if (checkLastColorMatch(colors, 3)) {
 			colors[3] = -1;
 			/* rotate 3rd column to non black and non matching */
-			colors[3] = FindL1Color(w, colors);
+			colors[3] = findL1Color(w, colors);
 			L1_E(w);
 		}
 #ifdef DEBUG
@@ -1909,7 +1902,7 @@ solveL1Color(BarrelWidget w)
 		if (checkLastColorMatch(colors, 4)) {
 			colors[4] = -1;
 			/* rotate 3rd column to non black and non matching */
-			colors[4] = FindL1Color(w, colors);
+			colors[4] = findL1Color(w, colors);
 			L1_E(w);
 		}
 		colors[5] = COLORTILE(2, 3); /* see if already in place */
@@ -1924,7 +1917,7 @@ solveL1Color(BarrelWidget w)
 		if (checkLastColorMatch(colors, 5)) {
 			colors[5] = -1;
 			/* rotate 3rd column to non black and non matching */
-			colors[5] = FindL1Color(w, colors);
+			colors[5] = findL1Color(w, colors);
 			L1_F(w);
 		}
 #ifdef DEBUG
@@ -1936,7 +1929,7 @@ solveL1Color(BarrelWidget w)
 			colorName(colors[5]));
 #endif
 		L1_G(w);
-	piece = CheckLevelSolved(w, 1);
+	piece = checkLevelSolved(w, 1);
 	if (piece != w->barrel.faces) {
 		(void) printf("Error in level 1, aborting, %d\n", piece);
 		return False;
@@ -1949,7 +1942,7 @@ static Boolean
 solveL2(BarrelWidget w)
 {
 	/*int faces[MAX_FACES] = {1, 3, 2, 0, 5};*/
-	int piece = CheckLevelSolved(w, 2);
+	int piece = checkLevelSolved(w, 2);
 
 	if (piece == w->barrel.faces) {
 		return True;
@@ -2023,7 +2016,7 @@ solveL2(BarrelWidget w)
 static Boolean
 solveL3Color(BarrelWidget w)
 {
-	int piece = CheckLevelSolved(w, 3);
+	int piece = checkLevelSolved(w, 3);
 
 	if (piece == w->barrel.faces) {
 		return True;
@@ -2061,7 +2054,7 @@ solveL3Color(BarrelWidget w)
 static Boolean
 solveL5Color(BarrelWidget w)
 {
-	int piece = CheckLevelSolved(w, 5);
+	int piece = checkLevelSolved(w, 5);
 
 	if (piece == w->barrel.faces) {
 		return True;
@@ -2088,7 +2081,7 @@ solveL5Color(BarrelWidget w)
 static Boolean
 solveL4Color(BarrelWidget w)
 {
-	int piece = CheckLevelSolved(w, 4);
+	int piece = checkLevelSolved(w, 4);
 
 	if (piece == w->barrel.faces) {
 		return True;
@@ -2125,15 +2118,15 @@ solveL4Color(BarrelWidget w)
 
 /* This procedure coordinates the solution process. */
 void
-SolveSomeTiles(BarrelWidget w)
+solveSomeTiles(BarrelWidget w)
 {
 	setPuzzle(w, ACTION_RESET);
 #ifdef JMP
 	if (!setjmp(solve_env))
 #endif
 	{
-		SolvingFlag = True;
-		if (!CheckSolved(w)) {
+		solvingFlag = True;
+		if (!checkSolved(w)) {
 			solveL0(w);
 			if (w->barrel.orient) {
 				/* work in progress */
@@ -2167,11 +2160,11 @@ SolveSomeTiles(BarrelWidget w)
 	}
 #ifdef JMP
 	else {
-		DrawAllTiles(w);
+		drawAllTiles(w);
 	}
-	AbortSolvingFlag = False;
+	abortSolvingFlag = False;
 #endif
-	SolvingFlag = False;
+	solvingFlag = False;
 	w->barrel.cheat = True; /* Assume the worst. */
 	setPuzzle(w, ACTION_COMPUTED);
 }
