@@ -52,6 +52,10 @@
 #else
 #include "picture.h"
 
+#if defined( USE_SOUND ) && defined( USE_NAS )
+Display *dsp;
+#endif
+
 #ifndef LOGPATH
 #ifdef VMS
 #define LOGPATH "SYS$SCRATCH:"
@@ -158,7 +162,6 @@ static char translations[] =
  <EnterWindow>: Enter()\n\
  <LeaveWindow>: Leave()";
 
-
 static XtActionsRec actionsList[] =
 {
 	{(char *) "Quit", (XtActionProc) quitPuzzle},
@@ -2325,6 +2328,11 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int i;
 
+#if 0
+#if defined( USE_SOUND ) && defined( USE_ESOUND )
+	(void) shutdown_sound();
+#endif
+#endif
 	XtReleaseGC(old, w->cubes.textGC);
 	for (i = 0; i < FG_SHADES; i++)
 		XtReleaseGC(old, w->cubes.blockGC[i]);
@@ -2556,6 +2564,16 @@ Widget request, Widget renew
 		w->cubes.delay + 1 : MAX_SLICES);
 	w->cubes.cheat = False;
 	sizePuzzle(w);
+#ifdef USE_SOUND
+#ifdef USE_NAS
+	dsp = XtDisplay(w);
+#endif
+#if 0
+#ifdef USE_ESOUND
+	(void) init_sound();
+#endif
+#endif
+#endif
 }
 
 #ifndef WINVER
