@@ -1,27 +1,22 @@
 /*
-# X-BASED DIAL
-#
-#  Dial.c
-#
-###
-#
-#  Copyright (c) 1994 - 2008	David A. Bagley, bagleyd@tux.org
-#
-#		   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "useful",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+ * @(#)Dial.c
+ *
+ * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Methods file for Dial */
 
@@ -32,20 +27,20 @@
 #define RADIANS(x) (M_PI*(x)/ST_ANGLE)
 #define DEGREES(x) ((x)/M_PI*ST_ANGLE)
 
-static Boolean SetValuesDial(Widget current, Widget request, Widget renew);
-static void QuitDial(DialWidget w, XEvent *event, char **args, int nArgs);
-static void DestroyDial(Widget old);
-static void InitializeDial(Widget request, Widget renew);
-static void ExposeDial(Widget renew, XEvent *event, Region region);
-static void HideDial(DialWidget w, XEvent *event, char **args, int n_args);
-static void ResizeDial(DialWidget w);
-static void SelectDial(DialWidget w, XEvent *event, char **args, int n_args);
-static void CheckDial(DialWidget w);
-static void EnterDial(DialWidget w, XEvent *event, char **args, int nArgs);
-static void LeaveDial(DialWidget w, XEvent *event, char **args, int nArgs);
-static void IncrementDial(DialWidget w,
+static Boolean setValuesDial(Widget current, Widget request, Widget renew);
+static void quitDial(DialWidget w, XEvent *event, char **args, int nArgs);
+static void destroyDial(Widget old);
+static void initializeDial(Widget request, Widget renew);
+static void exposeDial(Widget renew, XEvent *event, Region region);
+static void hideDial(DialWidget w, XEvent *event, char **args, int n_args);
+static void resizeDial(DialWidget w);
+static void selectDial(DialWidget w, XEvent *event, char **args, int n_args);
+static void checkDial(DialWidget w);
+static void enterDial(DialWidget w, XEvent *event, char **args, int nArgs);
+static void leaveDial(DialWidget w, XEvent *event, char **args, int nArgs);
+static void incrementDial(DialWidget w,
 	XEvent *event, char **args, int nArgs);
-static void DecrementDial(DialWidget w,
+static void decrementDial(DialWidget w,
 	XEvent *event, char **args, int nArgs);
 
 static char defaultTranslationsDial[] =
@@ -88,13 +83,13 @@ static char defaultTranslationsDial[] =
 
 static XtActionsRec actionsListDial[] =
 {
-	{(char *) "Quit", (XtActionProc) QuitDial},
-	{(char *) "Hide", (XtActionProc) HideDial},
-	{(char *) "Increment", (XtActionProc) IncrementDial},
-	{(char *) "Decrement", (XtActionProc) DecrementDial},
-	{(char *) "Select", (XtActionProc) SelectDial},
-	{(char *) "Enter", (XtActionProc) EnterDial},
-	{(char *) "Leave", (XtActionProc) LeaveDial}
+	{(char *) "Quit", (XtActionProc) quitDial},
+	{(char *) "Hide", (XtActionProc) hideDial},
+	{(char *) "Increment", (XtActionProc) incrementDial},
+	{(char *) "Decrement", (XtActionProc) decrementDial},
+	{(char *) "Select", (XtActionProc) selectDial},
+	{(char *) "Enter", (XtActionProc) enterDial},
+	{(char *) "Leave", (XtActionProc) leaveDial}
 };
 static XtResource resourcesDial[] =
 {
@@ -109,7 +104,7 @@ static XtResource resourcesDial[] =
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(DialWidget, dial.background),
-	 XtRString, (caddr_t) "gray"/*XtDefaultBackground*/},
+	 XtRString, (caddr_t) "#AEB2C3" /*XtDefaultBackground*/},
 	{XtNpointerColor, XtCColor, XtRPixel, sizeof(Pixel),
 	 XtOffset(DialWidget, dial.pointerColor),
 	 XtRString, (caddr_t) "Blue"},
@@ -159,7 +154,7 @@ DialClassRec dialClassRec =
 		NULL,		/* class initialize */
 		NULL,		/* class part initialize */
 		FALSE,		/* class inited */
-		(XtInitProc) InitializeDial,	/* initialize */
+		(XtInitProc) initializeDial,	/* initialize */
 		NULL,		/* initialize hook */
 		XtInheritRealize,	/* realize */
 		actionsListDial,	/* actions */
@@ -171,10 +166,10 @@ DialClassRec dialClassRec =
 		TRUE,		/* compress exposure */
 		TRUE,		/* compress enterleave */
 		TRUE,		/* visible interest */
-		(XtWidgetProc) DestroyDial,	/* destroy */
-		(XtWidgetProc) ResizeDial,	/* resize */
-		(XtExposeProc) ExposeDial,	/* expose */
-		(XtSetValuesFunc) SetValuesDial,	/* set values */
+		(XtWidgetProc) destroyDial,	/* destroy */
+		(XtWidgetProc) resizeDial,	/* resize */
+		(XtExposeProc) exposeDial,	/* expose */
+		(XtSetValuesFunc) setValuesDial,	/* set values */
 		NULL,		/* set values hook */
 		XtInheritSetValuesAlmost,	/* set values almost */
 		NULL,		/* get values hook */
@@ -203,7 +198,7 @@ setDial(DialWidget w, int reason)
 }
 
 static void
-Draw3DFrame(const DialWidget w, Pixmap dr, Boolean inside)
+draw3DFrame(const DialWidget w, Pixmap dr, Boolean inside)
 {
 	GC gc;
 
@@ -234,10 +229,10 @@ Draw3DFrame(const DialWidget w, Pixmap dr, Boolean inside)
 }
 
 static void
-EraseFrame(const DialWidget w, Pixmap dr, Boolean focus)
+eraseFrame(const DialWidget w, Pixmap dr, Boolean focus)
 {
 	if (focus) {
-		Draw3DFrame(w, dr, focus);
+		draw3DFrame(w, dr, focus);
 	} else {
 		DRAWRECTANGLE(w, dr, w->dial.inverseGC[1],
 		      0, 0, w->core.width - 1, w->core.height - 1);
@@ -250,10 +245,10 @@ EraseFrame(const DialWidget w, Pixmap dr, Boolean focus)
 }
 
 static void
-DrawFrame(DialWidget w, Pixmap dr, Boolean focus)
+drawFrame(DialWidget w, Pixmap dr, Boolean focus)
 {
 	if (focus) {
-		Draw3DFrame(w, dr, focus);
+		draw3DFrame(w, dr, focus);
 	} else {
 		DRAWRECTANGLE(w, dr, w->dial.inverseGC[1],
 			0, 0, w->core.width - 1, w->core.height - 1);
@@ -263,7 +258,7 @@ DrawFrame(DialWidget w, Pixmap dr, Boolean focus)
 }
 
 static void
-DrawPointer(DialWidget w, GC gc)
+drawPointer(DialWidget w, GC gc)
 {
 	Pixmap *dr;
 	Pixmap adr = 0;
@@ -319,7 +314,7 @@ DrawPointer(DialWidget w, GC gc)
 }
 
 static void
-MoveDial(DialWidget w , int dir)
+moveDial(DialWidget w , int dir)
 {
 	float avg, tac = w->dial.val;
 	Position pointerLength;
@@ -347,17 +342,17 @@ MoveDial(DialWidget w , int dir)
 	}
 	pointerLength = w->dial.dialRadius - w->dial.markerLength - 2;
 	avg = (w->dial.maximum + w->dial.minimum) / 2.0;
-	DrawPointer(w, w->dial.inverseGC[1]);
+	drawPointer(w, w->dial.inverseGC[1]);
 	w->dial.angle = tac * RADIANS(w->dial.maxDegree / 2) / avg +
 		 RADIANS(ST_ANGLE - RT_ANGLE - w->dial.maxDegree / 2);
 #ifdef DEBUG
-	(void) printf("MoveDial: angle %g, tac %g\n", w->dial.angle, tac);
+	(void) printf("moveDial: angle %g, tac %g\n", w->dial.angle, tac);
 #endif
 	w->dial.pointer.x = (short int) (w->dial.center.x -
 		pointerLength * cos(w->dial.angle));
 	w->dial.pointer.y = (short int) (w->dial.center.y -
 		pointerLength * sin(w->dial.angle));
-	DrawPointer(w, w->dial.pointerGC);
+	drawPointer(w, w->dial.pointerGC);
 	cb.reason = ACTION_SELECTED;
 	cb.val = w->dial.val;
 	XtCallCallbacks((Widget) w, XtNselectCallback, &cb);
@@ -407,7 +402,7 @@ darker(DialWidget w, Pixel pixel)
 }
 
 static void
-SetAllColors(DialWidget w)
+setAllColors(DialWidget w)
 {
 	XGCValues values;
 	XtGCMask valueMask;
@@ -486,18 +481,18 @@ SetAllColors(DialWidget w)
 }
 
 static void
-InitializeDial(Widget request, Widget renew)
+initializeDial(Widget request, Widget renew)
 {
 	DialWidget w = (DialWidget) renew;
 
 	w->dial.focus = False;
 	w->dial.factor = 100;
-	CheckDial(w);
-	ResizeDial(w);
+	checkDial(w);
+	resizeDial(w);
 }
 
 static void
-DestroyDial(Widget old)
+destroyDial(Widget old)
 {
 	DialWidget w = (DialWidget) old;
 	int i;
@@ -510,7 +505,7 @@ DestroyDial(Widget old)
 }
 
 static void
-ResizeDial(DialWidget w)
+resizeDial(DialWidget w)
 {
 	double angle, cosine, sine, increment;
 	int i, innerRadius, innerRadius2, radius, num, mod = 1;
@@ -551,48 +546,48 @@ ResizeDial(DialWidget w)
 			radius * cosine);
 		angle += increment;
 	}
-	CalculateDial(w);
-	SetAllColors(w);
+	calculateDial(w);
+	setAllColors(w);
 }
 
 static void
-ExposeDial(Widget renew, XEvent *event, Region region)
+exposeDial(Widget renew, XEvent *event, Region region)
 {
 	DialWidget w = (DialWidget) renew;
 
 	if (!w->core.visible)
 		return;
-	EraseFrame(w, 0, w->dial.focus);
+	eraseFrame(w, 0, w->dial.focus);
 	XDrawSegments(XtDisplay(w), XtWindow(w),
 		w->dial.markerGC, w->dial.segments, w->dial.markers);
-	DrawPointer(w, w->dial.pointerGC);
+	drawPointer(w, w->dial.pointerGC);
 }
 
 static void
-HideDial(DialWidget w, XEvent *event, char **args, int nArgs)
+hideDial(DialWidget w, XEvent *event, char **args, int nArgs)
 {
 	setDial(w, ACTION_HIDE);
 }
 
 static Boolean
-SetValuesDial(Widget current, Widget request, Widget renew)
+setValuesDial(Widget current, Widget request, Widget renew)
 {
 	DialWidget c = (DialWidget) current, w = (DialWidget) renew;
 	Boolean redraw = False, redrawPointer = False;
 
-	CheckDial(w);
+	checkDial(w);
 	if (w->dial.background != c->dial.background ||
 			w->dial.foreground != c->dial.foreground ||
 			w->dial.borderColor != c->dial.borderColor ||
 			w->dial.pointerColor != c->dial.pointerColor ||
 			w->dial.markerColor != c->dial.markerColor) {
-		SetAllColors(w);
+		setAllColors(w);
 		redraw = True;
 	}
 	if (w->dial.val != c->dial.val ||
 			w->dial.minimum != c->dial.minimum ||
 			w->dial.maximum != c->dial.maximum) {
-		CalculateDial(w);
+		calculateDial(w);
 		redrawPointer = True;
 	}
 	if (w->dial.menu != ACTION_IGNORE) {
@@ -602,7 +597,7 @@ SetValuesDial(Widget current, Widget request, Widget renew)
 		switch (menu) {
 		case ACTION_INCREMENT:
 		case ACTION_DECREMENT:
-			MoveDial(w, menu);
+			moveDial(w, menu);
 			break;
 		default:
 			break;
@@ -610,14 +605,14 @@ SetValuesDial(Widget current, Widget request, Widget renew)
 	}
 	if (redrawPointer && !redraw && XtIsRealized(renew) &&
 			renew->core.visible) {
-		DrawPointer(c, w->dial.inverseGC[1]);
-		DrawPointer(w, w->dial.pointerGC);
+		drawPointer(c, w->dial.inverseGC[1]);
+		drawPointer(w, w->dial.pointerGC);
 	}
 	return (redraw);
 }
 
 static void
-SelectDial(DialWidget w, XEvent *event, char **args, int n_args)
+selectDial(DialWidget w, XEvent *event, char **args, int n_args)
 {
 	int pos;
 	double angle;
@@ -643,7 +638,7 @@ SelectDial(DialWidget w, XEvent *event, char **args, int n_args)
 		tac = pos;
 		tac /= w->dial.factor;
 #ifdef DEBUG
-		(void) printf("SelectDial: angle %g, tac %g\n", angle, tac);
+		(void) printf("selectDial: angle %g, tac %g\n", angle, tac);
 #endif
 	}
 	cb.reason = ACTION_SELECTED;
@@ -654,7 +649,7 @@ SelectDial(DialWidget w, XEvent *event, char **args, int n_args)
 
 
 static void
-CheckDial(DialWidget w)
+checkDial(DialWidget w)
 {
 	char *buf1 = NULL, *buf2 = NULL;
 
@@ -702,13 +697,14 @@ CheckDial(DialWidget w)
 }
 
 static void
-QuitDial(DialWidget w, XEvent *event, char **args, int nArgs)
+quitDial(DialWidget w, XEvent *event, char **args, int nArgs)
 {
 	XtCloseDisplay(XtDisplay(w));
 	exit(0);
 }
 
-void CalculateDial(DialWidget w)
+void
+calculateDial(DialWidget w)
 {
 	float avg, tac = w->dial.val;
 	Position pointerLength;
@@ -719,7 +715,7 @@ void CalculateDial(DialWidget w)
 	w->dial.angle = tac * RADIANS(w->dial.maxDegree / 2) / avg +
 		 RADIANS(ST_ANGLE - RT_ANGLE - w->dial.maxDegree / 2);
 #ifdef DEBUG
-	(void) printf("CalculateDial: angle %g, tac %g\n", w->dial.angle, tac);
+	(void) printf("calculateDial: angle %g, tac %g\n", w->dial.angle, tac);
 #endif
 	w->dial.pointer.x = (short int) (w->dial.center.x -
 		pointerLength * cos(w->dial.angle));
@@ -728,28 +724,27 @@ void CalculateDial(DialWidget w)
 }
 
 static void
-EnterDial(DialWidget w , XEvent *event, char **args, int nArgs)
+enterDial(DialWidget w , XEvent *event, char **args, int nArgs)
 {
 	w->dial.focus = True;
-	DrawFrame(w, 0, w->dial.focus);
+	drawFrame(w, 0, w->dial.focus);
 }
 
 static void
-LeaveDial(DialWidget w, XEvent *event, char **args, int nArgs)
+leaveDial(DialWidget w, XEvent *event, char **args, int nArgs)
 {
 	w->dial.focus = False;
-	DrawFrame(w, 0, w->dial.focus);
+	drawFrame(w, 0, w->dial.focus);
 }
 
 static void
-IncrementDial(DialWidget w, XEvent *event, char **args, int nArgs)
+incrementDial(DialWidget w, XEvent *event, char **args, int nArgs)
 {
-	MoveDial(w, ACTION_INCREMENT);
+	moveDial(w, ACTION_INCREMENT);
 }
 
 static void
-DecrementDial(DialWidget w, XEvent *event, char **args, int nArgs)
+decrementDial(DialWidget w, XEvent *event, char **args, int nArgs)
 {
-	MoveDial(w, ACTION_DECREMENT);
+	moveDial(w, ACTION_DECREMENT);
 }
-
