@@ -1,7 +1,7 @@
 /*
  * @(#)xdial.c
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2009  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -21,7 +21,7 @@
 /* Driver file for Dial */
 
 static const char aboutHelp[] = {
-"Dial Version 7.4.1\n"
+"Dial Version 7.5\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -191,10 +191,10 @@ main(int argc, char **argv)
 	XmStringFree(fileString);
 	XmStringFree(moveString);
 	XtManageChild(menuBar);
-	quitString = XmStringCreateSimple((char *) "Quit");
+	quitString = XmStringCreateSimple((char *) "Exit");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
 		0, fileMenuListener,
-		XmVaPUSHBUTTON, quitString, 'Q', NULL, NULL,
+		XmVaPUSHBUTTON, quitString, 'x', NULL, NULL,
 		NULL);
 	XmStringFree(quitString);
 	incrementString = XmStringCreateSimple((char *) "Increment");
