@@ -54,6 +54,10 @@ static const char faceColorChar[MAX_FACES] =
 {'R', 'B', 'Y', 'G', 'W', 'O'};
 #else
 
+#if defined( USE_SOUND ) && defined( USE_NAS )
+Display *dsp;
+#endif
+
 #ifndef LOGPATH
 #ifdef VMS
 #define LOGPATH "SYS$SCRATCH:"
@@ -1616,6 +1620,11 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int face;
 
+#if 0
+#if defined( USE_SOUND ) && defined( USE_ESOUND )
+	(void) shutdown_sound();
+#endif
+#endif
 	for (face = 0; face < MAX_FACES; face++)
 		XtReleaseGC(old, w->dino.faceGC[face]);
 	XtReleaseGC(old, w->dino.borderGC);
@@ -1679,6 +1688,16 @@ Widget request, Widget renew
 #else
 	(void) SRAND(getpid());
 #endif
+#ifdef USE_SOUND
+#ifdef USE_NAS
+	dsp = XtDisplay(w);
+#endif
+#if 0
+#ifdef USE_ESOUND
+	(void) init_sound();
+#endif
+#endif
+#endif
 }
 
 void
