@@ -1,27 +1,22 @@
-/*-
-# X-BASED DINOSAUR CUBE
-#
-#  Dino2d.c
-#
-###
-#
-#  Copyright (c) 1995 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)Dino2d.c
+ *
+ * Copyright 1995 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Methods file for Dino2d */
 
@@ -29,29 +24,29 @@
 #include "Dino2dP.h"
 
 #ifndef WINVER
-static Boolean SetValuesPuzzle2D(Widget current, Widget request, Widget renew);
-static void ResizePuzzle2D(Dino2DWidget w);
-static void InitializePuzzle2D(Widget request, Widget renew);
-static void ExposePuzzle2D(Widget renew,
+static Boolean setValuesPuzzle2D(Widget current, Widget request, Widget renew);
+static void resizePuzzle2D(Dino2DWidget w);
+static void initializePuzzle2D(Widget request, Widget renew);
+static void exposePuzzle2D(Widget renew,
 	XEvent *event, Region region);
-static void MovePuzzle2DTl(Dino2DWidget w,
+static void movePuzzle2DTl(Dino2DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle2DTop(Dino2DWidget w,
+static void movePuzzle2DTop(Dino2DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle2DTr(Dino2DWidget w,
+static void movePuzzle2DTr(Dino2DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle2DLeft(Dino2DWidget w,
+static void movePuzzle2DLeft(Dino2DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle2DRight(Dino2DWidget w,
+static void movePuzzle2DRight(Dino2DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle2DBl(Dino2DWidget w,
+static void movePuzzle2DBl(Dino2DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle2DBottom(Dino2DWidget w,
+static void movePuzzle2DBottom(Dino2DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle2DBr(Dino2DWidget w,
+static void movePuzzle2DBr(Dino2DWidget w,
 	XEvent *event, char **args, int nArgs);
 
-static char defaultTranslationsPuzzle2D[] =
+static char translations2D[] =
 "<KeyPress>q: Quit()\n\
  Ctrl<KeyPress>C: Quit()\n\
  <KeyPress>osfCancel: Hide()\n\
@@ -120,45 +115,45 @@ static char defaultTranslationsPuzzle2D[] =
  <EnterWindow>: Enter()\n\
  <LeaveWindow>: Leave()";
 
-static XtActionsRec actionsListPuzzle2D[] =
+static XtActionsRec actionsList2D[] =
 {
-	{(char *) "Quit", (XtActionProc) QuitPuzzle},
-	{(char *) "Hide", (XtActionProc) HidePuzzle},
-	{(char *) "MoveTl", (XtActionProc) MovePuzzle2DTl},
-	{(char *) "MoveTop", (XtActionProc) MovePuzzle2DTop},
-	{(char *) "MoveTr", (XtActionProc) MovePuzzle2DTr},
-	{(char *) "MoveLeft", (XtActionProc) MovePuzzle2DLeft},
-	{(char *) "MoveRight", (XtActionProc) MovePuzzle2DRight},
-	{(char *) "MoveBl", (XtActionProc) MovePuzzle2DBl},
-	{(char *) "MoveBottom", (XtActionProc) MovePuzzle2DBottom},
-	{(char *) "MoveBr", (XtActionProc) MovePuzzle2DBr},
-	{(char *) "Select", (XtActionProc) SelectPuzzle},
-	{(char *) "Release", (XtActionProc) ReleasePuzzle},
-	{(char *) "PracticeMaybe", (XtActionProc) PracticePuzzleMaybe},
-	{(char *) "Practice2", (XtActionProc) PracticePuzzle2},
-	{(char *) "RandomizeMaybe", (XtActionProc) RandomizePuzzleMaybe},
-	{(char *) "Randomize2", (XtActionProc) RandomizePuzzle2},
-	{(char *) "Get", (XtActionProc) GetPuzzle},
-	{(char *) "Write", (XtActionProc) WritePuzzle},
-	{(char *) "Undo", (XtActionProc) UndoPuzzle},
-	{(char *) "Redo", (XtActionProc) RedoPuzzle},
-	{(char *) "Clear", (XtActionProc) ClearPuzzle},
-	{(char *) "Randomize", (XtActionProc) RandomizePuzzle},
-	{(char *) "Solve", (XtActionProc) SolvePuzzle},
-	{(char *) "Practice", (XtActionProc) PracticePuzzle},
-	{(char *) "Orientize", (XtActionProc) OrientizePuzzle},
-	{(char *) "Period2", (XtActionProc) Period2ModePuzzle},
-	{(char *) "Period3", (XtActionProc) Period3ModePuzzle},
-	{(char *) "Both", (XtActionProc) BothModePuzzle},
-	{(char *) "View", (XtActionProc) ViewPuzzle},
-	{(char *) "Speed", (XtActionProc) SpeedPuzzle},
-	{(char *) "Slow", (XtActionProc) SlowPuzzle},
-	{(char *) "Sound", (XtActionProc) SoundPuzzle},
-	{(char *) "Enter", (XtActionProc) EnterPuzzle},
-	{(char *) "Leave", (XtActionProc) LeavePuzzle}
+	{(char *) "Quit", (XtActionProc) quitPuzzle},
+	{(char *) "Hide", (XtActionProc) hidePuzzle},
+	{(char *) "MoveTl", (XtActionProc) movePuzzle2DTl},
+	{(char *) "MoveTop", (XtActionProc) movePuzzle2DTop},
+	{(char *) "MoveTr", (XtActionProc) movePuzzle2DTr},
+	{(char *) "MoveLeft", (XtActionProc) movePuzzle2DLeft},
+	{(char *) "MoveRight", (XtActionProc) movePuzzle2DRight},
+	{(char *) "MoveBl", (XtActionProc) movePuzzle2DBl},
+	{(char *) "MoveBottom", (XtActionProc) movePuzzle2DBottom},
+	{(char *) "MoveBr", (XtActionProc) movePuzzle2DBr},
+	{(char *) "Select", (XtActionProc) selectPuzzle},
+	{(char *) "Release", (XtActionProc) releasePuzzle},
+	{(char *) "PracticeMaybe", (XtActionProc) practicePuzzleWithQuery},
+	{(char *) "Practice2", (XtActionProc) practicePuzzleWithDoubleClick},
+	{(char *) "RandomizeMaybe", (XtActionProc) randomizePuzzleWithQuery},
+	{(char *) "Randomize2", (XtActionProc) randomizePuzzleWithDoubleClick},
+	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Write", (XtActionProc) writePuzzle},
+	{(char *) "Undo", (XtActionProc) undoPuzzle},
+	{(char *) "Redo", (XtActionProc) redoPuzzle},
+	{(char *) "Clear", (XtActionProc) clearPuzzle},
+	{(char *) "Randomize", (XtActionProc) randomizePuzzle},
+	{(char *) "Solve", (XtActionProc) solvePuzzle},
+	{(char *) "Practice", (XtActionProc) practicePuzzle},
+	{(char *) "Orientize", (XtActionProc) orientizePuzzle},
+	{(char *) "Period2", (XtActionProc) period2modePuzzle},
+	{(char *) "Period3", (XtActionProc) period3modePuzzle},
+	{(char *) "Both", (XtActionProc) bothmodePuzzle},
+	{(char *) "View", (XtActionProc) viewPuzzle},
+	{(char *) "Speed", (XtActionProc) speedUpPuzzle},
+	{(char *) "Slow", (XtActionProc) slowDownPuzzle},
+	{(char *) "Sound", (XtActionProc) toggleSoundPuzzle},
+	{(char *) "Enter", (XtActionProc) enterPuzzle},
+	{(char *) "Leave", (XtActionProc) leavePuzzle}
 };
 
-static XtResource resourcesPuzzle2D[] =
+static XtResource resources2D[] =
 {
 	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
 	 XtOffset(DinoWidget, core.width),
@@ -177,7 +172,7 @@ static XtResource resourcesPuzzle2D[] =
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(DinoWidget, dino.background),
-	 XtRString, (caddr_t) XtDefaultBackground},
+	 XtRString, (caddr_t) "#AEB2C3" /*XtDefaultBackground*/},
 	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(DinoWidget, dino.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
@@ -273,29 +268,29 @@ Dino2DClassRec dino2dClassRec =
 		NULL,		/* class initialize */
 		NULL,		/* class part initialize */
 		FALSE,		/* class inited */
-		(XtInitProc) InitializePuzzle2D,	/* initialize */
+		(XtInitProc) initializePuzzle2D,	/* initialize */
 		NULL,		/* initialize hook */
 		XtInheritRealize,	/* realize */
-		actionsListPuzzle2D,	/* actions */
-		XtNumber(actionsListPuzzle2D),	/* num actions */
-		resourcesPuzzle2D,	/* resources */
-		XtNumber(resourcesPuzzle2D),	/* num resources */
+		actionsList2D,	/* actions */
+		XtNumber(actionsList2D),	/* num actions */
+		resources2D,	/* resources */
+		XtNumber(resources2D),	/* num resources */
 		NULLQUARK,	/* xrm class */
 		TRUE,		/* compress motion */
 		TRUE,		/* compress exposure */
 		TRUE,		/* compress enterleave */
 		TRUE,		/* visible interest */
 		NULL,		/* destroy */
-		(XtWidgetProc) ResizePuzzle2D,	/* resize */
-		(XtExposeProc) ExposePuzzle2D,	/* expose */
-		(XtSetValuesFunc) SetValuesPuzzle2D,	/* set values */
+		(XtWidgetProc) resizePuzzle2D,	/* resize */
+		(XtExposeProc) exposePuzzle2D,	/* expose */
+		(XtSetValuesFunc) setValuesPuzzle2D,	/* set values */
 		NULL,		/* set values hook */
 		XtInheritSetValuesAlmost,	/* set values almost */
 		NULL,		/* get values hook */
 		XtInheritAcceptFocus,	/* accept focus */
 		XtVersion,	/* version */
 		NULL,		/* callback private */
-		defaultTranslationsPuzzle2D,	/* tm table */
+		translations2D,	/* tm table */
 		NULL,		/* query geometry */
 		NULL,		/* display accelerator */
 		NULL		/* extension */
@@ -354,7 +349,7 @@ static Point offsetList[MAX_ORIENT];
 static Pixmap dr = 0; /* dummy for future double buffering */
 
 static void
-DrawOrientLine(Dino2DWidget w, int orient, int dx, int dy, GC borderGC)
+drawOrientLine(Dino2DWidget w, int orient, int dx, int dy, GC borderGC)
 {
 	switch (orient) {
 	case TOP:
@@ -389,7 +384,7 @@ DrawOrientLine(Dino2DWidget w, int orient, int dx, int dy, GC borderGC)
 		{
 			char *buf;
 
-			intCat(&buf, "DrawOrientLine: orient ",
+			intCat(&buf, "drawOrientLine: orient ",
 				orient);
 			DISPLAY_WARNING(buf);
 			free(buf);
@@ -398,7 +393,7 @@ DrawOrientLine(Dino2DWidget w, int orient, int dx, int dy, GC borderGC)
 }
 
 void
-DrawTriangle2D(Dino2DWidget w, int face, int position, int offset)
+drawTriangle2D(Dino2DWidget w, int face, int position, int offset)
 {
 	GC faceGC, borderGC;
 	int dx, dy, letterX, letterY, newSide, orient;
@@ -453,14 +448,14 @@ DrawTriangle2D(Dino2DWidget w, int face, int position, int offset)
 		DRAWTEXT(w, dr, borderGC, letterX, letterY, buf, 1);
 	}
 	if (w->dino.orient)
-		DrawOrientLine(w, orient + 2 * MAX_ORIENT,
+		drawOrientLine(w, orient + 2 * MAX_ORIENT,
 			letterX - w->dino.letterOffset.x + 1,
 			letterY - w->dino.letterOffset.y,
 			borderGC);
 }
 
 void
-DrawFrame2D(Dino2DWidget w, Boolean focus)
+drawFrame2D(Dino2DWidget w, Boolean focus)
 {
 	int i;
 	Point pos[MAXXY + 1], letters;
@@ -500,7 +495,7 @@ DrawFrame2D(Dino2DWidget w, Boolean focus)
 }
 
 static void
-ResizePieces(Dino2DWidget w)
+resizePieces(Dino2DWidget w)
 {
 	int i, j;
 
@@ -555,12 +550,13 @@ ResizePieces(Dino2DWidget w)
 }
 
 Boolean
-SelectPieces2D(Dino2DWidget w, int x, int y, int *face, int *position)
+selectPieces2D(Dino2DWidget w, int positionX, int positionY,
+		int *face, int *position)
 {
 	int faceX, faceY, i, j;
+	int x = positionX - w->dino.puzzleOffset.x;
+	int y = positionY - w->dino.puzzleOffset.y;
 
-	x -= w->dino.puzzleOffset.x;
-	y -= w->dino.puzzleOffset.y;
 	faceX = x / w->dino2d.viewLength;
 	faceY = y / w->dino2d.viewLength;
 	i = x - faceX * w->dino2d.viewLength;
@@ -589,7 +585,7 @@ SelectPieces2D(Dino2DWidget w, int x, int y, int *face, int *position)
 }
 
 Boolean
-NarrowSelection2D(Dino2DWidget w, int *face, int *direction)
+narrowSelection2D(Dino2DWidget w, int *face, int *direction)
 {
 	if (*face == MAX_FACES - 1 && *direction < MAX_ORIENT && !w->dino.vertical) {
 		if (*direction < MAX_ORIENT)
@@ -602,13 +598,13 @@ NarrowSelection2D(Dino2DWidget w, int *face, int *direction)
 
 #ifndef WINVER
 static Boolean
-SetValuesPuzzle2D(Widget current, Widget request, Widget renew)
+setValuesPuzzle2D(Widget current, Widget request, Widget renew)
 {
 	Dino2DWidget c = (Dino2DWidget) current, w = (Dino2DWidget) renew;
 	Boolean redraw = False;
 
 	if (w->dino2d.diamondLength != c->dino2d.diamondLength) {
-		ResizePuzzle2D(w);
+		resizePuzzle2D(w);
 		redraw = TRUE;
 	}
 	return (redraw);
@@ -619,7 +615,7 @@ SetValuesPuzzle2D(Widget current, Widget request, Widget renew)
 static
 #endif
 void
-ResizePuzzle2D(Dino2DWidget w)
+resizePuzzle2D(Dino2DWidget w)
 {
 #ifdef WINVER
 	RECT rect;
@@ -653,14 +649,14 @@ ResizePuzzle2D(Dino2DWidget w)
 		/ 2;
 	w->dino.puzzleOffset.y = ((int) w->core.height - w->dino.puzzleSize.y)
 		/ 2;
-	ResizePieces(w);
+	resizePieces(w);
 }
 
 #ifndef WINVER
 static
 #endif
 void
-InitializePuzzle2D(
+initializePuzzle2D(
 #ifdef WINVER
 Dino2DWidget w
 #else
@@ -671,17 +667,17 @@ Widget request, Widget renew
 #ifndef WINVER
 	Dino2DWidget w = (Dino2DWidget) renew;
 
-	SetAllColors((DinoWidget) w);
+	setAllColors((DinoWidget) w);
 #endif
 	w->dino.dim = 2;
-	ResizePuzzle2D(w);
+	resizePuzzle2D(w);
 }
 
 #ifndef WINVER
 static
 #endif
 void
-ExposePuzzle2D(
+exposePuzzle2D(
 #ifdef WINVER
 Dino2DWidget w
 #else
@@ -697,78 +693,78 @@ Widget renew, XEvent *event, Region region
 #endif
 	FILLRECTANGLE(w, dr, w->dino.inverseGC,
 		0, 0, w->core.width, w->core.height);
-	DrawFrame2D(w, w->dino.focus);
-	DrawAllPieces((DinoWidget) w);
+	drawFrame2D(w, w->dino.focus);
+	drawAllPieces((DinoWidget) w);
 }
 
 #ifndef WINVER
 static void
-MovePuzzle2DTl(Dino2DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle2DTl(Dino2DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, TL,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, TL,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle2DTop(Dino2DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle2DTop(Dino2DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, TOP,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, TOP,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle2DTr(Dino2DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle2DTr(Dino2DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, TR,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, TR,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle2DLeft(Dino2DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle2DLeft(Dino2DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, LEFT,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, LEFT,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle2DRight(Dino2DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle2DRight(Dino2DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, RIGHT,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, RIGHT,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle2DBl(Dino2DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle2DBl(Dino2DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, BL,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, BL,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle2DBottom(Dino2DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle2DBottom(Dino2DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, BOTTOM,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, BOTTOM,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle2DBr(Dino2DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle2DBr(Dino2DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, BR,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, BR,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
