@@ -1,27 +1,22 @@
-/*-
-# X-BASED DINOSAUR CUBE
-#
-#  Dino3d.c
-#
-###
-#
-#  Copyright (c) 1995 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)Dino3d.c
+ *
+ * Copyright 1995 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Methods file for Dino3d */
 
@@ -29,32 +24,32 @@
 #include "Dino3dP.h"
 
 #ifndef WINVER
-static Boolean SetValuesPuzzle3D(Widget current, Widget request, Widget renew);
-static void ResizePuzzle3D(Dino3DWidget w);
-static void InitializePuzzle3D(Widget request, Widget renew);
-static void ExposePuzzle3D(Widget renew, XEvent *event, Region region);
-static void MovePuzzle3DCcw(Dino3DWidget w,
+static Boolean setValuesPuzzle3D(Widget current, Widget request, Widget renew);
+static void resizePuzzle3D(Dino3DWidget w);
+static void initializePuzzle3D(Widget request, Widget renew);
+static void exposePuzzle3D(Widget renew, XEvent *event, Region region);
+static void movePuzzle3DCcw(Dino3DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DTl(Dino3DWidget w,
+static void movePuzzle3DTl(Dino3DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DTop(Dino3DWidget w,
+static void movePuzzle3DTop(Dino3DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DTr(Dino3DWidget w,
+static void movePuzzle3DTr(Dino3DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DLeft(Dino3DWidget w,
+static void movePuzzle3DLeft(Dino3DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DCw(Dino3DWidget w,
+static void movePuzzle3DCw(Dino3DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DRight(Dino3DWidget w,
+static void movePuzzle3DRight(Dino3DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DBl(Dino3DWidget w,
+static void movePuzzle3DBl(Dino3DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DBottom(Dino3DWidget w,
+static void movePuzzle3DBottom(Dino3DWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzle3DBr(Dino3DWidget w,
+static void movePuzzle3DBr(Dino3DWidget w,
 	XEvent *event, char **args, int nArgs);
 
-static char defaultTranslationsPuzzle3D[] =
+static char translations3D[] =
 "<KeyPress>q: Quit()\n\
  Ctrl<KeyPress>C: Quit()\n\
  <KeyPress>osfCancel: Hide()\n\
@@ -128,47 +123,47 @@ static char defaultTranslationsPuzzle3D[] =
  <EnterWindow>: Enter()\n\
  <LeaveWindow>: Leave()";
 
-static XtActionsRec actionsListPuzzle3D[] =
+static XtActionsRec actionsList3D[] =
 {
-	{(char *) "Quit", (XtActionProc) QuitPuzzle},
-	{(char *) "Hide", (XtActionProc) HidePuzzle},
-	{(char *) "MoveCcw", (XtActionProc) MovePuzzle3DCcw},
-	{(char *) "MoveTl", (XtActionProc) MovePuzzle3DTl},
-	{(char *) "MoveTop", (XtActionProc) MovePuzzle3DTop},
-	{(char *) "MoveTr", (XtActionProc) MovePuzzle3DTr},
-	{(char *) "MoveLeft", (XtActionProc) MovePuzzle3DLeft},
-	{(char *) "MoveCw", (XtActionProc) MovePuzzle3DCw},
-	{(char *) "MoveRight", (XtActionProc) MovePuzzle3DRight},
-	{(char *) "MoveBl", (XtActionProc) MovePuzzle3DBl},
-	{(char *) "MoveBottom", (XtActionProc) MovePuzzle3DBottom},
-	{(char *) "MoveBr", (XtActionProc) MovePuzzle3DBr},
-	{(char *) "Select", (XtActionProc) SelectPuzzle},
-	{(char *) "Release", (XtActionProc) ReleasePuzzle},
-	{(char *) "PracticeMaybe", (XtActionProc) PracticePuzzleMaybe},
-	{(char *) "Practice2", (XtActionProc) PracticePuzzle2},
-	{(char *) "RandomizeMaybe", (XtActionProc) RandomizePuzzleMaybe},
-	{(char *) "Randomize2", (XtActionProc) RandomizePuzzle2},
-	{(char *) "Get", (XtActionProc) GetPuzzle},
-	{(char *) "Write", (XtActionProc) WritePuzzle},
-	{(char *) "Undo", (XtActionProc) UndoPuzzle},
-	{(char *) "Redo", (XtActionProc) RedoPuzzle},
-	{(char *) "Clear", (XtActionProc) ClearPuzzle},
-	{(char *) "Randomize", (XtActionProc) RandomizePuzzle},
-	{(char *) "Solve", (XtActionProc) SolvePuzzle},
-	{(char *) "Practice", (XtActionProc) PracticePuzzle},
-	{(char *) "Orientize", (XtActionProc) OrientizePuzzle},
-	{(char *) "Period2", (XtActionProc) Period2ModePuzzle},
-	{(char *) "Period3", (XtActionProc) Period3ModePuzzle},
-	{(char *) "Both", (XtActionProc) BothModePuzzle},
-	{(char *) "View", (XtActionProc) ViewPuzzle},
-	{(char *) "Speed", (XtActionProc) SpeedPuzzle},
-	{(char *) "Slow", (XtActionProc) SlowPuzzle},
-	{(char *) "Sound", (XtActionProc) SoundPuzzle},
-	{(char *) "Enter", (XtActionProc) EnterPuzzle},
-	{(char *) "Leave", (XtActionProc) LeavePuzzle}
+	{(char *) "Quit", (XtActionProc) quitPuzzle},
+	{(char *) "Hide", (XtActionProc) hidePuzzle},
+	{(char *) "MoveCcw", (XtActionProc) movePuzzle3DCcw},
+	{(char *) "MoveTl", (XtActionProc) movePuzzle3DTl},
+	{(char *) "MoveTop", (XtActionProc) movePuzzle3DTop},
+	{(char *) "MoveTr", (XtActionProc) movePuzzle3DTr},
+	{(char *) "MoveLeft", (XtActionProc) movePuzzle3DLeft},
+	{(char *) "MoveCw", (XtActionProc) movePuzzle3DCw},
+	{(char *) "MoveRight", (XtActionProc) movePuzzle3DRight},
+	{(char *) "MoveBl", (XtActionProc) movePuzzle3DBl},
+	{(char *) "MoveBottom", (XtActionProc) movePuzzle3DBottom},
+	{(char *) "MoveBr", (XtActionProc) movePuzzle3DBr},
+	{(char *) "Select", (XtActionProc) selectPuzzle},
+	{(char *) "Release", (XtActionProc) releasePuzzle},
+	{(char *) "PracticeMaybe", (XtActionProc) practicePuzzleWithQuery},
+	{(char *) "Practice2", (XtActionProc) practicePuzzleWithDoubleClick},
+	{(char *) "RandomizeMaybe", (XtActionProc) randomizePuzzleWithQuery},
+	{(char *) "Randomize2", (XtActionProc) randomizePuzzleWithDoubleClick},
+	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Write", (XtActionProc) writePuzzle},
+	{(char *) "Undo", (XtActionProc) undoPuzzle},
+	{(char *) "Redo", (XtActionProc) redoPuzzle},
+	{(char *) "Clear", (XtActionProc) clearPuzzle},
+	{(char *) "Randomize", (XtActionProc) randomizePuzzle},
+	{(char *) "Solve", (XtActionProc) solvePuzzle},
+	{(char *) "Practice", (XtActionProc) practicePuzzle},
+	{(char *) "Orientize", (XtActionProc) orientizePuzzle},
+	{(char *) "Period2", (XtActionProc) period2modePuzzle},
+	{(char *) "Period3", (XtActionProc) period3modePuzzle},
+	{(char *) "Both", (XtActionProc) bothmodePuzzle},
+	{(char *) "View", (XtActionProc) viewPuzzle},
+	{(char *) "Speed", (XtActionProc) speedUpPuzzle},
+	{(char *) "Slow", (XtActionProc) slowDownPuzzle},
+	{(char *) "Sound", (XtActionProc) toggleSoundPuzzle},
+	{(char *) "Enter", (XtActionProc) enterPuzzle},
+	{(char *) "Leave", (XtActionProc) leavePuzzle}
 };
 
-static XtResource resourcesPuzzle3D[] =
+static XtResource resources3D[] =
 {
 	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
 	 XtOffset(DinoWidget, core.width),
@@ -187,7 +182,7 @@ static XtResource resourcesPuzzle3D[] =
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(DinoWidget, dino.background),
-	 XtRString, (caddr_t) XtDefaultBackground},
+	 XtRString, (caddr_t) "#AEB2C3" /*XtDefaultBackground*/},
 	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(DinoWidget, dino.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
@@ -283,29 +278,29 @@ Dino3DClassRec dino3dClassRec =
 		NULL,		/* class initialize */
 		NULL,		/* class part initialize */
 		FALSE,		/* class inited */
-		(XtInitProc) InitializePuzzle3D,	/* initialize */
+		(XtInitProc) initializePuzzle3D,	/* initialize */
 		NULL,		/* initialize hook */
 		XtInheritRealize,	/* realize */
-		actionsListPuzzle3D,	/* actions */
-		XtNumber(actionsListPuzzle3D),	/* num actions */
-		resourcesPuzzle3D,	/* resources */
-		XtNumber(resourcesPuzzle3D),	/* num resources */
+		actionsList3D,	/* actions */
+		XtNumber(actionsList3D),	/* num actions */
+		resources3D,	/* resources */
+		XtNumber(resources3D),	/* num resources */
 		NULLQUARK,	/* xrm class */
 		TRUE,		/* compress motion */
 		TRUE,		/* compress exposure */
 		TRUE,		/* compress enterleave */
 		TRUE,		/* visible interest */
 		NULL,		/* destroy */
-		(XtWidgetProc) ResizePuzzle3D,	/* resize */
-		(XtExposeProc) ExposePuzzle3D,	/* expose */
-		(XtSetValuesFunc) SetValuesPuzzle3D,	/* set values */
+		(XtWidgetProc) resizePuzzle3D,	/* resize */
+		(XtExposeProc) exposePuzzle3D,	/* expose */
+		(XtSetValuesFunc) setValuesPuzzle3D,	/* set values */
 		NULL,		/* set values hook */
 		XtInheritSetValuesAlmost,	/* set values almost */
 		NULL,		/* get values hook */
 		XtInheritAcceptFocus,	/* accept focus */
 		XtVersion,	/* version */
 		NULL,		/* callback private */
-		defaultTranslationsPuzzle3D,	/* tm table */
+		translations3D,	/* tm table */
 		NULL,		/* query geometry */
 		NULL,		/* display accelerator */
 		NULL		/* extension */
@@ -332,7 +327,7 @@ static Point orientTriangle[MAX_FACES][MAX_ORIENT][2];
 static Pixmap dr = 0; /* dummy for future double buffering */
 
 static void
-DiamondOffset3D(Dino3DWidget w, int face, int *dx, int *dy)
+diamondOffset3D(Dino3DWidget w, int face, int *dx, int *dy)
 {
 	if (w->dino.vertical) {
 		switch (face) {
@@ -378,7 +373,7 @@ DiamondOffset3D(Dino3DWidget w, int face, int *dx, int *dy)
 			{
 				char *buf;
 
-				intCat(&buf, "DiamondOffset3D: face ",
+				intCat(&buf, "diamondOffset3D: face ",
 					face);
 				DISPLAY_WARNING(buf);
 				free(buf);
@@ -428,7 +423,7 @@ DiamondOffset3D(Dino3DWidget w, int face, int *dx, int *dy)
 			{
 				char *buf;
 
-				intCat(&buf, "DiamondOffset3D: face ", face);
+				intCat(&buf, "diamondOffset3D: face ", face);
 				DISPLAY_WARNING(buf);
 				free(buf);
 			}
@@ -437,11 +432,11 @@ DiamondOffset3D(Dino3DWidget w, int face, int *dx, int *dy)
 }
 
 static void
-CubeOffset3D(Dino3DWidget w, int face, int side, int *dx, int *dy)
+cubeOffset3D(Dino3DWidget w, int face, int side, int *dx, int *dy)
 {
 	int corner;
 
-	DiamondOffset3D(w, face, dx, dy);
+	diamondOffset3D(w, face, dx, dy);
 	for (corner = 1; corner <= side; corner++) {
 		*dx += tinyDiamondLoc3D[face][corner].x;
 		*dy += tinyDiamondLoc3D[face][corner].y;
@@ -449,7 +444,7 @@ CubeOffset3D(Dino3DWidget w, int face, int side, int *dx, int *dy)
 }
 
 static void
-MapTo3D(Dino3DWidget w, int face, int corner, int *side)
+mapTo3D(Dino3DWidget w, int face, int corner, int *side)
 {
 	switch (face) {
 	case 0:
@@ -470,7 +465,7 @@ MapTo3D(Dino3DWidget w, int face, int corner, int *side)
 		{
 			char *buf;
 
-			intCat(&buf, "MapTo3D: face ", face);
+			intCat(&buf, "mapTo3D: face ", face);
 			DISPLAY_WARNING(buf);
 			free(buf);
 		}
@@ -478,7 +473,7 @@ MapTo3D(Dino3DWidget w, int face, int corner, int *side)
 }
 
 static void
-MapFrom3D(Dino3DWidget w, int face, int side, int *corner)
+mapFrom3D(Dino3DWidget w, int face, int side, int *corner)
 {
 	switch (face) {
 	case 0:
@@ -499,7 +494,7 @@ MapFrom3D(Dino3DWidget w, int face, int side, int *corner)
 		{
 			char *buf;
 
-			intCat(&buf, "MapFrom3D: face ", face);
+			intCat(&buf, "mapFrom3D: face ", face);
 			DISPLAY_WARNING(buf);
 			free(buf);
 		}
@@ -507,13 +502,13 @@ MapFrom3D(Dino3DWidget w, int face, int side, int *corner)
 }
 
 void
-DrawTriangle3D(Dino3DWidget w, int face, int position, int offset)
+drawTriangle3D(Dino3DWidget w, int face, int position, int offset)
 {
 	GC faceGC, borderGC;
 	int corner = 0, dx, dy, rotation, letterX, letterY;
 
-	MapTo3D(w, face, position, &corner);
-	CubeOffset3D(w, face, corner, &dx, &dy);
+	mapTo3D(w, face, position, &corner);
+	cubeOffset3D(w, face, corner, &dx, &dy);
 	rotation = w->dino.cubeLoc[face][position].rotation;
 	letterX = dx + letter3DList[face][corner].x;
 	letterY = dy + letter3DList[face][corner].y;
@@ -567,7 +562,7 @@ DrawTriangle3D(Dino3DWidget w, int face, int position, int offset)
 }
 
 void
-DrawFrame3D(Dino3DWidget w, Boolean focus)
+drawFrame3D(Dino3DWidget w, Boolean focus)
 {
 	int face, dx, dy;
 	GC gc = (focus) ? w->dino.frameGC : w->dino.borderGC;
@@ -604,7 +599,7 @@ DrawFrame3D(Dino3DWidget w, Boolean focus)
 }
 
 static void
-ResizePieces(Dino3DWidget w)
+resizePieces(Dino3DWidget w)
 {
 	int face, orient, side, corner;
 	Point subcubeLoc3D[MAX_FACES][MAX_ORIENT];
@@ -734,7 +729,7 @@ ResizePieces(Dino3DWidget w)
 				w->dino3d.faceSize.y) / 6;
 		}
 
-		MapFrom3D(w, face, 1, &corner);
+		mapFrom3D(w, face, 1, &corner);
 		orientTriangle[face][corner][0].x = -orientCubeLoc3D[0][face][2].x / 2;
 		orientTriangle[face][corner][0].y = -orientCubeLoc3D[0][face][2].y / 2;
 		orientTriangle[face][corner][1].x = -orientCubeLoc3D[1][face][2].x / 2;
@@ -791,7 +786,7 @@ ResizePieces(Dino3DWidget w)
 			(orientCubeLoc3D[1][face][MAX_ORIENT - 1].y -
 			orientCubeLoc3D[1][face][MAX_ORIENT / 2].y) / 2;
 
-		MapFrom3D(w, face, 1, &corner);
+		mapFrom3D(w, face, 1, &corner);
 		orientTriangle[face][corner][0].x = -orientCubeLoc3D[0][face][2].x / 2;
 		orientTriangle[face][corner][0].y = -orientCubeLoc3D[0][face][2].y / 2;
 		orientTriangle[face][corner][1].x = -orientCubeLoc3D[1][face][2].x / 2;
@@ -835,7 +830,7 @@ ResizePieces(Dino3DWidget w)
 		}
 		for (orient = 1; orient < MAX_ORIENT; orient++) {
 			side = corner;
-			MapFrom3D(w, face, (orient + 1) % MAX_ORIENT, &corner);
+			mapFrom3D(w, face, (orient + 1) % MAX_ORIENT, &corner);
 			orientTriangle[face][corner][0].x =
 				orientTriangle[face][side][0].x +
 				orientDiamondLoc3D[0][face][orient].x;
@@ -857,7 +852,7 @@ ResizePieces(Dino3DWidget w)
 }
 
 Boolean
-SelectPieces3D(Dino3DWidget w, int x, int y, int *face, int *position)
+selectPieces3D(Dino3DWidget w, int x, int y, int *face, int *position)
 {
 	int u, v, front, tl, ur, ul, found, corner, dx, dy;
 	int x_1, y_1, x_2, y_2;
@@ -912,7 +907,7 @@ SelectPieces3D(Dino3DWidget w, int x, int y, int *face, int *position)
 	x = x_1;
 	y = y_1;
 	found = 0;
-	DiamondOffset3D(w, *face, &dx, &dy);
+	diamondOffset3D(w, *face, &dx, &dy);
 	for (corner = 0; corner < MAX_ORIENT; corner++) {
 		int ok = 0;
 
@@ -931,7 +926,7 @@ SelectPieces3D(Dino3DWidget w, int x, int y, int *face, int *position)
 		} else if ((x_2 - dx) * (y - dy) >= (y_2 - dy) * (x - dx))
 			ok++;
 		if (ok == 2) {
-			MapFrom3D(w, *face, corner, position);
+			mapFrom3D(w, *face, corner, position);
 			found++;
 		}
 	}
@@ -941,7 +936,7 @@ SelectPieces3D(Dino3DWidget w, int x, int y, int *face, int *position)
 }
 
 Boolean
-NarrowSelection3D(Dino3DWidget w, int *face, int *direction)
+narrowSelection3D(Dino3DWidget w, int *face, int *direction)
 {
 	switch (*direction) {
 	case TR:
@@ -1003,13 +998,13 @@ NarrowSelection3D(Dino3DWidget w, int *face, int *direction)
 
 #ifndef WINVER
 static Boolean
-SetValuesPuzzle3D(Widget current, Widget request, Widget renew)
+setValuesPuzzle3D(Widget current, Widget request, Widget renew)
 {
 	Dino3DWidget c = (Dino3DWidget) current, w = (Dino3DWidget) renew;
 	Boolean redraw = False;
 
 	if (w->dino3d.cubeSize.x != c->dino3d.cubeSize.x) {
-		ResizePuzzle3D(w);
+		resizePuzzle3D(w);
 		redraw = True;
 	}
 	return (redraw);
@@ -1020,7 +1015,7 @@ SetValuesPuzzle3D(Widget current, Widget request, Widget renew)
 static
 #endif
 void
-ResizePuzzle3D(Dino3DWidget w)
+resizePuzzle3D(Dino3DWidget w)
 {
 	Point tempSize;
 #ifdef WINVER
@@ -1077,14 +1072,14 @@ ResizePuzzle3D(Dino3DWidget w)
 	w->dino.puzzleOffset.x = ((int) w->core.width - w->dino.puzzleSize.x) / 2;
 	w->dino.puzzleOffset.y = ((int) w->core.height - w->dino.puzzleSize.y) /
 		2;
-	ResizePieces(w);
+	resizePieces(w);
 }
 
 #ifndef WINVER
 static
 #endif
 void
-InitializePuzzle3D(
+initializePuzzle3D(
 #ifdef WINVER
 Dino3DWidget w
 #else
@@ -1095,17 +1090,17 @@ Widget request, Widget renew
 #ifndef WINVER
 	Dino3DWidget w = (Dino3DWidget) renew;
 
-	SetAllColors((DinoWidget) w);
+	setAllColors((DinoWidget) w);
 #endif
 	w->dino.dim = 3;
-	ResizePuzzle3D(w);
+	resizePuzzle3D(w);
 }
 
 #ifndef WINVER
 static
 #endif
 void
-ExposePuzzle3D(
+exposePuzzle3D(
 #ifdef WINVER
 Dino3DWidget w
 #else
@@ -1121,96 +1116,96 @@ Widget renew, XEvent *event, Region region
 #endif
 	FILLRECTANGLE(w, dr, w->dino.inverseGC,
 		0, 0, w->core.width, w->core.height);
-	DrawFrame3D(w, w->dino.focus);
-	DrawAllPieces((DinoWidget) w);
+	drawFrame3D(w, w->dino.focus);
+	drawAllPieces((DinoWidget) w);
 }
 
 #ifndef WINVER
 static void
-MovePuzzle3DTl(Dino3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DTl(Dino3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, TL,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, TL,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle3DTop(Dino3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DTop(Dino3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, TOP,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, TOP,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle3DTr(Dino3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DTr(Dino3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, TR,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, TR,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle3DLeft(Dino3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DLeft(Dino3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, LEFT,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, LEFT,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle3DCw(Dino3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DCw(Dino3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, CW,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, CW,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle3DRight(Dino3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DRight(Dino3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, RIGHT,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, RIGHT,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle3DBl(Dino3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DBl(Dino3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, BL,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, BL,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle3DBottom(Dino3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DBottom(Dino3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, BOTTOM,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, BOTTOM,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle3DBr(Dino3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DBr(Dino3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, BR,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, BR,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzle3DCcw(Dino3DWidget w, XEvent *event, char **args, int nArgs)
+movePuzzle3DCcw(Dino3DWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, CCW,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y, CCW,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
