@@ -1,27 +1,22 @@
-/*-
-# X-BASED DINOSAUR CUBE
-#
-#  DinoGL.c
-#
-###
-#
-#  Copyright (c) 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)DinoGL.c
+ *
+ * Copyright 2007 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /*-
  * Permission to use, copy, modify, and distribute this software and its
@@ -122,28 +117,28 @@ static Boolean madeCurrent = False;
 static HGLRC hRC = NULL;
 #else
 static GLXContext *glXContext = (GLXContext *) NULL;
-static Boolean SetValuesPuzzleGL(Widget current, Widget request, Widget renew);
-static void ResizePuzzleGL(DinoGLWidget w);
-static void InitializePuzzleGL(Widget request, Widget renew);
-static void ExposePuzzleGL(Widget renew, XEvent *event, Region region);
-static void MovePuzzleGLTl(DinoGLWidget w,
+static Boolean setValuesPuzzleGL(Widget current, Widget request, Widget renew);
+static void resizePuzzleGL(DinoGLWidget w);
+static void initializePuzzleGL(Widget request, Widget renew);
+static void exposePuzzleGL(Widget renew, XEvent *event, Region region);
+static void movePuzzleGLTl(DinoGLWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzleGLTop(DinoGLWidget w,
+static void movePuzzleGLTop(DinoGLWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzleGLTr(DinoGLWidget w,
+static void movePuzzleGLTr(DinoGLWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzleGLLeft(DinoGLWidget w,
+static void movePuzzleGLLeft(DinoGLWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzleGLRight(DinoGLWidget w,
+static void movePuzzleGLRight(DinoGLWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzleGLBl(DinoGLWidget w,
+static void movePuzzleGLBl(DinoGLWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzleGLBottom(DinoGLWidget w,
+static void movePuzzleGLBottom(DinoGLWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzleGLBr(DinoGLWidget w,
+static void movePuzzleGLBr(DinoGLWidget w,
 	XEvent *event, char **args, int nArgs);
 
-static char defaultTranslationsPuzzleGL[] =
+static char translationsGL[] =
 "<KeyPress>q: Quit()\n\
  Ctrl<KeyPress>C: Quit()\n\
  <KeyPress>osfCancel: Hide()\n\
@@ -210,45 +205,45 @@ static char defaultTranslationsPuzzleGL[] =
  <EnterWindow>: Enter()\n\
  <LeaveWindow>: Leave()";
 
-static XtActionsRec actionsListPuzzleGL[] =
+static XtActionsRec actionsListGL[] =
 {
-	{(char *) "Quit", (XtActionProc) QuitPuzzle},
-	{(char *) "Hide", (XtActionProc) HidePuzzle},
-	{(char *) "MoveTl", (XtActionProc) MovePuzzleGLTl},
-	{(char *) "MoveTop", (XtActionProc) MovePuzzleGLTop},
-	{(char *) "MoveTr", (XtActionProc) MovePuzzleGLTr},
-	{(char *) "MoveLeft", (XtActionProc) MovePuzzleGLLeft},
-	{(char *) "MoveRight", (XtActionProc) MovePuzzleGLRight},
-	{(char *) "MoveBl", (XtActionProc) MovePuzzleGLBl},
-	{(char *) "MoveBottom", (XtActionProc) MovePuzzleGLBottom},
-	{(char *) "MoveBr", (XtActionProc) MovePuzzleGLBr},
-	{(char *) "Select", (XtActionProc) SelectPuzzle},
-	{(char *) "Release", (XtActionProc) ReleasePuzzle},
-	{(char *) "PracticeMaybe", (XtActionProc) PracticePuzzleMaybe},
-	{(char *) "Practice2", (XtActionProc) PracticePuzzle2},
-	{(char *) "RandomizeMaybe", (XtActionProc) RandomizePuzzleMaybe},
-	{(char *) "Randomize2", (XtActionProc) RandomizePuzzle2},
-	{(char *) "Get", (XtActionProc) GetPuzzle},
-	{(char *) "Write", (XtActionProc) WritePuzzle},
-	{(char *) "Undo", (XtActionProc) UndoPuzzle},
-	{(char *) "Redo", (XtActionProc) RedoPuzzle},
-	{(char *) "Clear", (XtActionProc) ClearPuzzle},
-	{(char *) "Randomize", (XtActionProc) RandomizePuzzle},
-	{(char *) "Solve", (XtActionProc) SolvePuzzle},
-	{(char *) "Practice", (XtActionProc) PracticePuzzle},
-	{(char *) "Orientize", (XtActionProc) OrientizePuzzle},
-	{(char *) "Period2", (XtActionProc) Period2ModePuzzle},
-	{(char *) "Period3", (XtActionProc) Period3ModePuzzle},
-	{(char *) "Both", (XtActionProc) BothModePuzzle},
-	{(char *) "View", (XtActionProc) ViewPuzzle},
-	{(char *) "Speed", (XtActionProc) SpeedPuzzle},
-	{(char *) "Slow", (XtActionProc) SlowPuzzle},
-	{(char *) "Sound", (XtActionProc) SoundPuzzle},
-	{(char *) "Enter", (XtActionProc) EnterPuzzle},
-	{(char *) "Leave", (XtActionProc) LeavePuzzle}
+	{(char *) "Quit", (XtActionProc) quitPuzzle},
+	{(char *) "Hide", (XtActionProc) hidePuzzle},
+	{(char *) "MoveTl", (XtActionProc) movePuzzleGLTl},
+	{(char *) "MoveTop", (XtActionProc) movePuzzleGLTop},
+	{(char *) "MoveTr", (XtActionProc) movePuzzleGLTr},
+	{(char *) "MoveLeft", (XtActionProc) movePuzzleGLLeft},
+	{(char *) "MoveRight", (XtActionProc) movePuzzleGLRight},
+	{(char *) "MoveBl", (XtActionProc) movePuzzleGLBl},
+	{(char *) "MoveBottom", (XtActionProc) movePuzzleGLBottom},
+	{(char *) "MoveBr", (XtActionProc) movePuzzleGLBr},
+	{(char *) "Select", (XtActionProc) selectPuzzle},
+	{(char *) "Release", (XtActionProc) releasePuzzle},
+	{(char *) "PracticeMaybe", (XtActionProc) practicePuzzleWithQuery},
+	{(char *) "Practice2", (XtActionProc) practicePuzzleWithDoubleClick},
+	{(char *) "RandomizeMaybe", (XtActionProc) randomizePuzzleWithQuery},
+	{(char *) "Randomize2", (XtActionProc) randomizePuzzleWithDoubleClick},
+	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Write", (XtActionProc) writePuzzle},
+	{(char *) "Undo", (XtActionProc) undoPuzzle},
+	{(char *) "Redo", (XtActionProc) redoPuzzle},
+	{(char *) "Clear", (XtActionProc) clearPuzzle},
+	{(char *) "Randomize", (XtActionProc) randomizePuzzle},
+	{(char *) "Solve", (XtActionProc) solvePuzzle},
+	{(char *) "Practice", (XtActionProc) practicePuzzle},
+	{(char *) "Orientize", (XtActionProc) orientizePuzzle},
+	{(char *) "Period2", (XtActionProc) period2modePuzzle},
+	{(char *) "Period3", (XtActionProc) period3modePuzzle},
+	{(char *) "Both", (XtActionProc) bothmodePuzzle},
+	{(char *) "View", (XtActionProc) viewPuzzle},
+	{(char *) "Speed", (XtActionProc) speedUpPuzzle},
+	{(char *) "Slow", (XtActionProc) slowDownPuzzle},
+	{(char *) "Sound", (XtActionProc) toggleSoundPuzzle},
+	{(char *) "Enter", (XtActionProc) enterPuzzle},
+	{(char *) "Leave", (XtActionProc) leavePuzzle}
 };
 
-static XtResource resourcesPuzzleGL[] =
+static XtResource resourcesGL[] =
 {
 	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
 	 XtOffset(DinoWidget, core.width),
@@ -267,7 +262,7 @@ static XtResource resourcesPuzzleGL[] =
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(DinoWidget, dino.background),
-	 XtRString, (caddr_t) XtDefaultBackground},
+	 XtRString, (caddr_t) "#AEB2C3" /*XtDefaultBackground*/},
 	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(DinoWidget, dino.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
@@ -366,29 +361,29 @@ DinoGLClassRec dinoGLClassRec =
 		NULL,		/* class initialize */
 		NULL,		/* class part initialize */
 		FALSE,		/* class inited */
-		(XtInitProc) InitializePuzzleGL,	/* initialize */
+		(XtInitProc) initializePuzzleGL,	/* initialize */
 		NULL,		/* initialize hook */
 		XtInheritRealize,	/* realize */
-		actionsListPuzzleGL,	/* actions */
-		XtNumber(actionsListPuzzleGL),	/* num actions */
-		resourcesPuzzleGL,	/* resources */
-		XtNumber(resourcesPuzzleGL),	/* num resources */
+		actionsListGL,	/* actions */
+		XtNumber(actionsListGL),	/* num actions */
+		resourcesGL,	/* resources */
+		XtNumber(resourcesGL),	/* num resources */
 		NULLQUARK,	/* xrm class */
 		TRUE,		/* compress motion */
 		TRUE,		/* compress exposure */
 		TRUE,		/* compress enterleave */
 		TRUE,		/* visible interest */
 		NULL,		/* destroy */
-		(XtWidgetProc) ResizePuzzleGL,	/* resize */
-		(XtExposeProc) ExposePuzzleGL,	/* expose */
-		(XtSetValuesFunc) SetValuesPuzzleGL,	/* set values */
+		(XtWidgetProc) resizePuzzleGL,	/* resize */
+		(XtExposeProc) exposePuzzleGL,	/* expose */
+		(XtSetValuesFunc) setValuesPuzzleGL,	/* set values */
 		NULL,		/* set values hook */
 		XtInheritSetValuesAlmost,	/* set values almost */
 		NULL,		/* get values hook */
 		XtInheritAcceptFocus,	/* accept focus */
 		XtVersion,	/* version */
 		NULL,		/* callback private */
-		defaultTranslationsPuzzleGL,	/* tm table */
+		translationsGL,	/* tm table */
 		NULL,		/* query geometry */
 		NULL,		/* display accelerator */
 		NULL		/* extension */
@@ -558,7 +553,7 @@ draw_stickerless_cubit(Boolean sep)
 }
 
 static void
-DrawOrientLine(DinoGLWidget w, int face, int rotation,
+drawOrientLine(DinoGLWidget w, int face, int rotation,
 		float x, float y, float z)
 {
 	int err = 0;
@@ -762,7 +757,7 @@ DrawOrientLine(DinoGLWidget w, int face, int rotation,
 }
 
 static void
-DrawCubit(DinoGLWidget w,
+drawCubit(DinoGLWidget w,
 	   int back, int front, int left, int right, int bottom, int top)
 {
 	Boolean mono = w->dino.mono;
@@ -779,7 +774,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(STICKERFULLSHORT, STICKERFULLLONG, 0.0);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, BACK_FACE,
+				drawOrientLine(w, BACK_FACE,
 					w->dino.cubeLoc[BACK_FACE][0].rotation,
 					0.0, CUBE_ROUND - 2.0 * CUBE_LENGTH,
 					-CUT_DEPTH + STICKER_DEPTH);
@@ -793,7 +788,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(-STICKERFULLLONG, STICKERFULLSHORT, 0.0);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, BACK_FACE,
+				drawOrientLine(w, BACK_FACE,
 					w->dino.cubeLoc[BACK_FACE][1].rotation,
 					-CUBE_ROUND + 2.0 * CUBE_LENGTH, 0.0,
 					-CUT_DEPTH + STICKER_DEPTH);
@@ -807,7 +802,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(-STICKERFULLSHORT, -STICKERFULLLONG, 0.0);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, BACK_FACE,
+				drawOrientLine(w, BACK_FACE,
 					w->dino.cubeLoc[BACK_FACE][2].rotation,
 					0.0, -CUBE_ROUND + 2.0 * CUBE_LENGTH,
 					-CUT_DEPTH + STICKER_DEPTH);
@@ -821,7 +816,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(STICKERFULLLONG, -STICKERFULLSHORT, 0.0);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, BACK_FACE,
+				drawOrientLine(w, BACK_FACE,
 					w->dino.cubeLoc[BACK_FACE][3].rotation,
 					CUBE_ROUND - 2.0 * CUBE_LENGTH, 0.0,
 					-CUT_DEPTH + STICKER_DEPTH);
@@ -841,7 +836,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(-STICKERFULLSHORT, STICKERFULLLONG, 0.0);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, FRONT_FACE,
+				drawOrientLine(w, FRONT_FACE,
 					w->dino.cubeLoc[FRONT_FACE][2].rotation,
 					0.0, CUBE_ROUND - 2.0 * CUBE_LENGTH,
 					CUT_DEPTH - STICKER_DEPTH);
@@ -855,7 +850,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(-STICKERFULLLONG, -STICKERFULLSHORT, 0.0);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, FRONT_FACE,
+				drawOrientLine(w, FRONT_FACE,
 					w->dino.cubeLoc[FRONT_FACE][1].rotation,
 					-CUBE_ROUND + 2.0 * CUBE_LENGTH, 0.0,
 					CUT_DEPTH - STICKER_DEPTH);
@@ -869,7 +864,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(STICKERFULLSHORT, -STICKERFULLLONG, 0.0);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, FRONT_FACE,
+				drawOrientLine(w, FRONT_FACE,
 					w->dino.cubeLoc[FRONT_FACE][0].rotation,
 					0.0, -CUBE_ROUND + 2.0 * CUBE_LENGTH,
 					CUT_DEPTH - STICKER_DEPTH);
@@ -883,7 +878,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(STICKERFULLLONG, STICKERFULLSHORT, 0.0);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, FRONT_FACE,
+				drawOrientLine(w, FRONT_FACE,
 					w->dino.cubeLoc[FRONT_FACE][3].rotation,
 					CUBE_ROUND - 2.0 * CUBE_LENGTH, 0.0,
 					CUT_DEPTH - STICKER_DEPTH);
@@ -903,7 +898,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(0.0, STICKERFULLSHORT, STICKERFULLLONG);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, LEFT_FACE,
+				drawOrientLine(w, LEFT_FACE,
 					w->dino.cubeLoc[LEFT_FACE][3].rotation,
 					-CUT_DEPTH + STICKER_DEPTH,
 					0.0,
@@ -918,7 +913,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(0.0, STICKERFULLLONG, -STICKERFULLSHORT);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, LEFT_FACE,
+				drawOrientLine(w, LEFT_FACE,
 					w->dino.cubeLoc[LEFT_FACE][0].rotation,
 					-CUT_DEPTH + STICKER_DEPTH,
 					CUBE_ROUND,
@@ -933,7 +928,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(0.0, -STICKERFULLSHORT, -STICKERFULLLONG);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, LEFT_FACE,
+				drawOrientLine(w, LEFT_FACE,
 					w->dino.cubeLoc[LEFT_FACE][1].rotation,
 					-CUT_DEPTH + STICKER_DEPTH,
 					0.0,
@@ -948,7 +943,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(0.0, -STICKERFULLLONG, STICKERFULLSHORT);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, LEFT_FACE,
+				drawOrientLine(w, LEFT_FACE,
 					w->dino.cubeLoc[LEFT_FACE][2].rotation,
 					-CUT_DEPTH + STICKER_DEPTH,
 					-CUBE_ROUND,
@@ -969,7 +964,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(0.0, -STICKERFULLSHORT, STICKERFULLLONG);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, RIGHT_FACE,
+				drawOrientLine(w, RIGHT_FACE,
 					w->dino.cubeLoc[RIGHT_FACE][1].rotation,
 					CUT_DEPTH - STICKER_DEPTH,
 					CUBE_ROUND - CUBE_LENGTH,
@@ -984,7 +979,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(0.0, STICKERFULLLONG, STICKERFULLSHORT);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, RIGHT_FACE,
+				drawOrientLine(w, RIGHT_FACE,
 					w->dino.cubeLoc[RIGHT_FACE][0].rotation,
 					CUT_DEPTH - STICKER_DEPTH,
 					CUBE_LENGTH,
@@ -999,7 +994,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(0.0, STICKERFULLSHORT, -STICKERFULLLONG);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, RIGHT_FACE,
+				drawOrientLine(w, RIGHT_FACE,
 					w->dino.cubeLoc[RIGHT_FACE][3].rotation,
 					CUT_DEPTH - STICKER_DEPTH,
 					0.0, -CUBE_ROUND + 2.0 * CUBE_LENGTH);
@@ -1013,7 +1008,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(0.0, -STICKERFULLLONG, -STICKERFULLSHORT);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, RIGHT_FACE,
+				drawOrientLine(w, RIGHT_FACE,
 					w->dino.cubeLoc[RIGHT_FACE][2].rotation,
 					CUT_DEPTH - STICKER_DEPTH,
 					-CUBE_LENGTH, 0.0);
@@ -1033,7 +1028,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(-STICKERFULLLONG, 0.0, -STICKERFULLSHORT);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, BOTTOM_FACE,
+				drawOrientLine(w, BOTTOM_FACE,
 					w->dino.cubeLoc[BOTTOM_FACE][3].rotation,
 					-CUBE_ROUND,
 					-CUT_DEPTH + STICKER_DEPTH, 0.0);
@@ -1047,7 +1042,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(-STICKERFULLSHORT, 0.0, STICKERFULLLONG);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, BOTTOM_FACE,
+				drawOrientLine(w, BOTTOM_FACE,
 					w->dino.cubeLoc[BOTTOM_FACE][0].rotation,
 					0.0, -CUT_DEPTH + STICKER_DEPTH,
 					CUBE_ROUND);
@@ -1061,7 +1056,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(STICKERFULLLONG, 0.0, STICKERFULLSHORT);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, BOTTOM_FACE,
+				drawOrientLine(w, BOTTOM_FACE,
 					w->dino.cubeLoc[BOTTOM_FACE][1].rotation,
 					CUBE_ROUND,
 					-CUT_DEPTH + STICKER_DEPTH, 0.0);
@@ -1075,7 +1070,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(STICKERFULLSHORT, 0.0, -STICKERFULLLONG);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, BOTTOM_FACE,
+				drawOrientLine(w, BOTTOM_FACE,
 					w->dino.cubeLoc[BOTTOM_FACE][2].rotation,
 					0.0, -CUT_DEPTH + STICKER_DEPTH,
 					-CUBE_ROUND);
@@ -1095,7 +1090,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(-STICKERFULLLONG, 0.0, STICKERFULLSHORT);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, TOP_FACE,
+				drawOrientLine(w, TOP_FACE,
 					w->dino.cubeLoc[TOP_FACE][3].rotation,
 					-CUBE_LENGTH,
 					CUT_DEPTH - STICKER_DEPTH, 0.0);
@@ -1109,7 +1104,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(STICKERFULLSHORT, 0.0, STICKERFULLLONG);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, TOP_FACE,
+				drawOrientLine(w, TOP_FACE,
 					w->dino.cubeLoc[TOP_FACE][2].rotation,
 					0.0, CUT_DEPTH - STICKER_DEPTH,
 					CUBE_LENGTH);
@@ -1123,7 +1118,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(STICKERFULLLONG, 0.0, -STICKERFULLSHORT);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, TOP_FACE,
+				drawOrientLine(w, TOP_FACE,
 					w->dino.cubeLoc[TOP_FACE][1].rotation,
 					CUBE_LENGTH,
 					CUT_DEPTH - STICKER_DEPTH, 0.0);
@@ -1137,7 +1132,7 @@ DrawCubit(DinoGLWidget w,
 			glVertex3f(-STICKERFULLSHORT, 0.0, -STICKERFULLLONG);
 			glEnd();
 			if (w->dino.orient) {
-				DrawOrientLine(w, TOP_FACE,
+				drawOrientLine(w, TOP_FACE,
 					w->dino.cubeLoc[TOP_FACE][0].rotation,
 					0.0, CUT_DEPTH - STICKER_DEPTH,
 					-CUBE_LENGTH);
@@ -1148,7 +1143,7 @@ DrawCubit(DinoGLWidget w,
 }
 
 static Boolean
-DrawCube(DinoGLWidget w)
+drawCube(DinoGLWidget w)
 {
 #define S1 1
 #define DRAW_STICKERLESS_CUBIT(s) if (!draw_stickerless_cubit(s)) return False
@@ -1160,7 +1155,7 @@ DrawCube(DinoGLWidget w)
 		slice.face = NO_FACE;
 		slice.rotation = NO_ROTATION;
 #ifdef FIXME
-	} else {
+	/*} else {*/
 		convertMove(w, w->dinoGL.movement, &slice);
 #endif
 	}
@@ -1188,7 +1183,7 @@ DrawCube(DinoGLWidget w)
 		glRotatef(180.0, 0, 0, 1);
 		DRAW_STICKERLESS_CUBIT(s); /* White Blue */
 		glPopMatrix();
-		DrawCubit(w, NO_FACE, NO_FACE,
+		drawCubit(w, NO_FACE, NO_FACE,
 			w->dino.cubeLoc[LEFT_FACE][2].face,
 			NO_FACE,
 			w->dino.cubeLoc[BOTTOM_FACE][3].face,
@@ -1199,7 +1194,7 @@ DrawCube(DinoGLWidget w)
 		glRotatef(180.0, 0, 0, 1);
 		DRAW_STICKERLESS_CUBIT(s); /* White Orange */
 		glPopMatrix();
-		DrawCubit(w, w->dino.cubeLoc[BACK_FACE][0].face,
+		drawCubit(w, w->dino.cubeLoc[BACK_FACE][0].face,
 			NO_FACE, NO_FACE, NO_FACE,
 			w->dino.cubeLoc[BOTTOM_FACE][2].face,
 			NO_FACE); /* BB */
@@ -1209,7 +1204,7 @@ DrawCube(DinoGLWidget w)
 		glRotatef(180.0, 0, 0, 1);
 		DRAW_STICKERLESS_CUBIT(s); /* White Yellow */
 		glPopMatrix();
-		DrawCubit(w, NO_FACE,
+		drawCubit(w, NO_FACE,
 			w->dino.cubeLoc[FRONT_FACE][2].face,
 			NO_FACE, NO_FACE,
 			w->dino.cubeLoc[BOTTOM_FACE][0].face,
@@ -1220,7 +1215,7 @@ DrawCube(DinoGLWidget w)
 		glRotatef(180.0, 0, 0, 1);
 		DRAW_STICKERLESS_CUBIT(s); /* White Green */
 		glPopMatrix();
-		DrawCubit(w, NO_FACE, NO_FACE, NO_FACE,
+		drawCubit(w, NO_FACE, NO_FACE, NO_FACE,
 			w->dino.cubeLoc[RIGHT_FACE][2].face,
 			w->dino.cubeLoc[BOTTOM_FACE][1].face,
 			NO_FACE); /* RB */
@@ -1232,7 +1227,7 @@ DrawCube(DinoGLWidget w)
 		glRotatef(180.0, 0, 0, 1);
 		DRAW_STICKERLESS_CUBIT(s); /* Blue Orange */
 		glPopMatrix();
-		DrawCubit(w, w->dino.cubeLoc[BACK_FACE][3].face,
+		drawCubit(w, w->dino.cubeLoc[BACK_FACE][3].face,
 			NO_FACE,
 			w->dino.cubeLoc[LEFT_FACE][3].face,
 			NO_FACE, NO_FACE, NO_FACE); /* BL */
@@ -1242,7 +1237,7 @@ DrawCube(DinoGLWidget w)
 		glRotatef(180.0, 0, 0, 1);
 		DRAW_STICKERLESS_CUBIT(s); /* Blue Yellow */
 		glPopMatrix();
-		DrawCubit(w, NO_FACE,
+		drawCubit(w, NO_FACE,
 			w->dino.cubeLoc[FRONT_FACE][3].face,
 			w->dino.cubeLoc[LEFT_FACE][1].face,
 			NO_FACE, NO_FACE, NO_FACE); /* FL */
@@ -1251,7 +1246,7 @@ DrawCube(DinoGLWidget w)
 		glRotatef(90.0, -1, 0, 0);
 		DRAW_STICKERLESS_CUBIT(s); /* Green Orange */
 		glPopMatrix();
-		DrawCubit(w, w->dino.cubeLoc[BACK_FACE][1].face,
+		drawCubit(w, w->dino.cubeLoc[BACK_FACE][1].face,
 			NO_FACE, NO_FACE,
 			w->dino.cubeLoc[RIGHT_FACE][1].face,
 			NO_FACE, NO_FACE); /* BR */
@@ -1260,7 +1255,7 @@ DrawCube(DinoGLWidget w)
 		glRotatef(90.0, 1, 0, 0);
 		DRAW_STICKERLESS_CUBIT(s); /* Green Yellow */
 		glPopMatrix();
-		DrawCubit(w, NO_FACE,
+		drawCubit(w, NO_FACE,
 			w->dino.cubeLoc[FRONT_FACE][1].face,
 			NO_FACE,
 			w->dino.cubeLoc[RIGHT_FACE][3].face,
@@ -1272,7 +1267,7 @@ DrawCube(DinoGLWidget w)
 		glRotatef(180.0, 0, 1, 0);
 		DRAW_STICKERLESS_CUBIT(s); /* Red Blue */
 		glPopMatrix();
-		DrawCubit(w,
+		drawCubit(w,
 			NO_FACE, NO_FACE,
 			w->dino.cubeLoc[LEFT_FACE][0].face,
 			NO_FACE, NO_FACE,
@@ -1282,7 +1277,7 @@ DrawCube(DinoGLWidget w)
 		glRotatef(90.0, 0, 1, 0);
 		DRAW_STICKERLESS_CUBIT(s); /* Red Orange */
 		glPopMatrix();
-		DrawCubit(w,
+		drawCubit(w,
 			w->dino.cubeLoc[BACK_FACE][2].face,
 			NO_FACE, NO_FACE, NO_FACE, NO_FACE,
 			w->dino.cubeLoc[TOP_FACE][0].face); /* BT */
@@ -1291,7 +1286,7 @@ DrawCube(DinoGLWidget w)
 		glRotatef(-90.0, 0, 1, 0);
 		DRAW_STICKERLESS_CUBIT(s); /* Red Yellow */
 		glPopMatrix();
-		DrawCubit(w, NO_FACE,
+		drawCubit(w, NO_FACE,
 			w->dino.cubeLoc[FRONT_FACE][0].face,
 			NO_FACE, NO_FACE, NO_FACE,
 			w->dino.cubeLoc[TOP_FACE][2].face); /* FT */
@@ -1299,7 +1294,7 @@ DrawCube(DinoGLWidget w)
 		glPushMatrix();
 		DRAW_STICKERLESS_CUBIT(s); /* Red Green */
 		glPopMatrix();
-		DrawCubit(w, NO_FACE, NO_FACE, NO_FACE,
+		drawCubit(w, NO_FACE, NO_FACE, NO_FACE,
 			w->dino.cubeLoc[RIGHT_FACE][0].face,
 			NO_FACE,
 			w->dino.cubeLoc[TOP_FACE][1].face); /* RT */
@@ -1311,7 +1306,7 @@ DrawCube(DinoGLWidget w)
 }
 
 void
-DrawAllPiecesGL(DinoGLWidget w)
+drawAllPiecesGL(DinoGLWidget w)
 {
 #ifdef WINVER
 	wglMakeCurrent(w->core.hDC, hRC);
@@ -1348,8 +1343,8 @@ DrawAllPiecesGL(DinoGLWidget w)
 	default:
 		break;
 	}
-	if (!DrawCube(w)) {
-		DISPLAY_WARNING("DrawCube error");
+	if (!drawCube(w)) {
+		DISPLAY_WARNING("drawCube error");
 	}
 	glPopMatrix();
 	glFlush();
@@ -1361,20 +1356,21 @@ DrawAllPiecesGL(DinoGLWidget w)
 }
 
 void
-DrawFrameGL(DinoGLWidget w, Boolean focus)
+drawFrameGL(DinoGLWidget w, Boolean focus)
 {
 	/* UNUSED */
 }
 
 Boolean
-SelectPiecesGL(DinoGLWidget w, int x, int y, int *face, int *position)
+selectPiecesGL(DinoGLWidget w, int x, int y, int *face, int *position)
 {
 	/* UNUSED */
 	return True;
 }
 
 #ifdef WINVER
-Boolean setupPixelFormat(DinoGLWidget w, BYTE type, DWORD flags)
+static Boolean
+setupPixelFormat(DinoGLWidget w, BYTE type, DWORD flags)
 {
 	PIXELFORMATDESCRIPTOR pfd;
 	int pixelFormat;
@@ -1414,13 +1410,13 @@ Boolean setupPixelFormat(DinoGLWidget w, BYTE type, DWORD flags)
 #else
 
 static Boolean
-SetValuesPuzzleGL(Widget current, Widget request, Widget renew)
+setValuesPuzzleGL(Widget current, Widget request, Widget renew)
 {
 	DinoGLWidget c = (DinoGLWidget) current, w = (DinoGLWidget) renew;
 	Boolean redraw = False;
 
 	if (w->dino.view != c->dino.view) {
-		ResizePuzzleGL(w);
+		resizePuzzleGL(w);
 		redraw = True;
 	}
 #if 0
@@ -1430,7 +1426,7 @@ SetValuesPuzzleGL(Widget current, Widget request, Widget renew)
 	    w->dinoGL.cubeSizex.y != c->dinoGL.cubeSizex.y ||
 	    w->dinoGL.cubeSizey.y != c->dinoGL.cubeSizey.y ||
 	    w->dinoGL.cubeSizez.y != c->dinoGL.cubeSizez.y) {
-		ResizePuzzleGL(w);
+		resizePuzzleGL(w);
 		redraw = True;
 	}
 #endif
@@ -1472,7 +1468,7 @@ initGL(DinoGLWidget w) {
 static
 #endif
 void
-ResizePuzzleGL(DinoGLWidget w)
+resizePuzzleGL(DinoGLWidget w)
 {
 #ifdef WINVER
 	RECT rect;
@@ -1514,7 +1510,7 @@ makeCurrentGL(DinoGLWidget w)
 			DefaultScreen(XtDisplay(w))));
 #endif
 	}
-	ResizePuzzleGL(w);
+	resizePuzzleGL(w);
 
 	glDrawBuffer(GL_BACK);
 	glClearDepth(1.0);
@@ -1554,14 +1550,14 @@ makeCurrentGL(DinoGLWidget w)
 
 #ifndef WINVER
 static void
-InitializePuzzleGL(Widget request, Widget renew)
+initializePuzzleGL(Widget request, Widget renew)
 {
 	DinoGLWidget w = (DinoGLWidget) renew;
 
-	SetAllColors((DinoWidget) w);
+	setAllColors((DinoWidget) w);
 	(void) initGL(w);
 	w->dino.dim = 4; /* 2 and 3 already taken */
-	ResizePuzzleGL(w);
+	resizePuzzleGL(w);
 }
 #endif
 
@@ -1569,7 +1565,7 @@ InitializePuzzleGL(Widget request, Widget renew)
 static
 #endif
 void
-ExposePuzzleGL(
+exposePuzzleGL(
 #ifdef WINVER
 DinoGLWidget w
 #else
@@ -1597,15 +1593,15 @@ Widget renew, XEvent *event, Region region
 	if (!madeCurrent) {
 		makeCurrentGL(w);
 	}
-	DrawFrameGL(w, w->dino.focus);
-	DrawAllPiecesGL(w);
+	drawFrameGL(w, w->dino.focus);
+	drawAllPiecesGL(w);
 }
 
 #ifndef WINVER
 static void
-MovePuzzleGLTl(DinoGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLTl(DinoGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y,
 		TL,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
@@ -1613,9 +1609,9 @@ MovePuzzleGLTl(DinoGLWidget w, XEvent *event, char **args, int nArgs)
 }
 
 static void
-MovePuzzleGLTop(DinoGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLTop(DinoGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y,
 		TOP,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
@@ -1623,9 +1619,9 @@ MovePuzzleGLTop(DinoGLWidget w, XEvent *event, char **args, int nArgs)
 }
 
 static void
-MovePuzzleGLTr(DinoGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLTr(DinoGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y,
 		TR,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
@@ -1633,9 +1629,9 @@ MovePuzzleGLTr(DinoGLWidget w, XEvent *event, char **args, int nArgs)
 }
 
 static void
-MovePuzzleGLLeft(DinoGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLLeft(DinoGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y,
 		LEFT,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
@@ -1643,9 +1639,9 @@ MovePuzzleGLLeft(DinoGLWidget w, XEvent *event, char **args, int nArgs)
 }
 
 static void
-MovePuzzleGLRight(DinoGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLRight(DinoGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y,
 		RIGHT,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
@@ -1653,9 +1649,9 @@ MovePuzzleGLRight(DinoGLWidget w, XEvent *event, char **args, int nArgs)
 }
 
 static void
-MovePuzzleGLBl(DinoGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLBl(DinoGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y,
 		BL,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
@@ -1663,9 +1659,9 @@ MovePuzzleGLBl(DinoGLWidget w, XEvent *event, char **args, int nArgs)
 }
 
 static void
-MovePuzzleGLBottom(DinoGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLBottom(DinoGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y,
 		BOTTOM,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
@@ -1673,9 +1669,9 @@ MovePuzzleGLBottom(DinoGLWidget w, XEvent *event, char **args, int nArgs)
 }
 
 static void
-MovePuzzleGLBr(DinoGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLBr(DinoGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((DinoWidget) w, event->xbutton.x, event->xbutton.y,
 		BR,
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask),
