@@ -53,6 +53,10 @@
 #else
 #include "picture.h"
 
+#if defined( USE_SOUND ) && defined( USE_NAS )
+Display *dsp;
+#endif
+
 #ifndef LOGPATH
 #ifdef VMS
 #define LOGPATH "SYS$SCRATCH:"
@@ -2862,6 +2866,11 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int i;
 
+#if 0
+#if defined( USE_SOUND ) && defined( USE_ESOUND )
+	(void) shutdown_sound();
+#endif
+#endif
 	XtReleaseGC(old, w->hexagons.textGC);
 	for (i = 0; i < FG_SHADES; i++)
 	       XtReleaseGC(old, w->hexagons.tileGC[i]);
@@ -3107,6 +3116,16 @@ Widget request, Widget renew
 		w->hexagons.delay + 1 : MAX_SLICES);
 	w->hexagons.cheat = False;
 	sizePuzzle(w);
+#ifdef USE_SOUND
+#ifdef USE_NAS
+	dsp = XtDisplay(w);
+#endif
+#if 0
+#ifdef USE_ESOUND
+	(void) init_sound();
+#endif
+#endif
+#endif
 }
 
 #ifndef WINVER
