@@ -55,6 +55,10 @@ static char wedgeColorChar[MAX_WEDGES] =
 {'Y', 'B', 'R', 'M', 'G', 'O', 'C', 'D', 'P', 'L', 'A', 'T'};
 #else
 
+#if defined( USE_SOUND ) && defined( USE_NAS )
+Display *dsp;
+#endif
+
 #ifndef LOGPATH
 #ifdef VMS
 #define LOGPATH "SYS$SCRATCH:"
@@ -2316,6 +2320,11 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int wedge;
 
+#if 0
+#if defined( USE_SOUND ) && defined( USE_ESOUND )
+	(void) shutdown_sound();
+#endif
+#endif
 	for (wedge = 0; wedge < MAX_WEDGES; wedge++)
 		XtReleaseGC(old, w->mball.wedgeGC[wedge]);
 	XtReleaseGC(old, w->mball.borderGC);
@@ -2431,6 +2440,16 @@ Widget request, Widget renew
 	(void) SRAND(getpid());
 	setAllColors(w);
 #endif
+#ifdef USE_SOUND
+#ifdef USE_NAS
+	dsp = XtDisplay(w);
+#endif
+#if 0
+#ifdef USE_ESOUND
+	(void) init_sound();
+#endif
+#endif
+#endif
 }
 
 #ifndef WINVER
