@@ -1,27 +1,22 @@
-/*-
-# X-BASED MASTERBALL(tm)
-#
-#  MballP.h
-#
-###
-#
-#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)MballP.h
+ *
+ * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /* Private header file for Mball */
 
@@ -33,41 +28,41 @@
 #include "Mball.h"
 
 #ifdef WINVER
-extern void DestroyPuzzle(HBRUSH brush);
-extern void ResizePuzzle(MballWidget w);
-extern void SizePuzzle(MballWidget w);
-extern void InitializePuzzle(MballWidget w, HBRUSH brush);
-extern void ExposePuzzle(MballWidget w);
-extern void HidePuzzle(MballWidget w);
-extern void SelectPuzzle(MballWidget w,
+extern void destroyPuzzle(HBRUSH brush);
+extern void resizePuzzle(MballWidget w);
+extern void sizePuzzle(MballWidget w);
+extern void initializePuzzle(MballWidget w, HBRUSH brush);
+extern void exposePuzzle(MballWidget w);
+extern void hidePuzzle(MballWidget w);
+extern void selectPuzzle(MballWidget w,
 	const int x, const int y, const int shift);
-extern void ReleasePuzzle(MballWidget w,
+extern void releasePuzzle(MballWidget w,
 	const int x, const int y, const int shift);
-extern void PracticePuzzle(MballWidget w);
-extern void RandomizePuzzle(MballWidget w);
-extern void GetPuzzle(MballWidget w);
-extern void WritePuzzle(MballWidget w);
-extern void UndoPuzzle(MballWidget w);
-extern void RedoPuzzle(MballWidget w);
-extern void ClearPuzzle(MballWidget w);
-extern void SolvePuzzle(MballWidget w);
-extern void IncrementPuzzle(MballWidget w);
-extern Boolean DecrementPuzzle(MballWidget w);
-extern void WedgePuzzle(MballWidget w, const int mode);
-extern void Wedge2ModePuzzle(MballWidget w);
-extern void Wedge4ModePuzzle(MballWidget w);
-extern void Wedge6ModePuzzle(MballWidget w);
-extern void Wedge8ModePuzzle(MballWidget w);
-extern void Wedge10ModePuzzle(MballWidget w);
-extern void Wedge12ModePuzzle(MballWidget w);
-extern void OrientizePuzzle(MballWidget w);
-extern void MiddlePuzzle(MballWidget w);
-extern void SpeedPuzzle(MballWidget w);
-extern void SlowPuzzle(MballWidget w);
-extern void SoundPuzzle(MballWidget w);
-extern void EnterPuzzle(MballWidget w);
-extern void LeavePuzzle(MballWidget w);
-extern void MovePuzzleInput(MballWidget w,
+extern void practicePuzzle(MballWidget w);
+extern void randomizePuzzle(MballWidget w);
+extern void getPuzzle(MballWidget w);
+extern void writePuzzle(MballWidget w);
+extern void undoPuzzle(MballWidget w);
+extern void redoPuzzle(MballWidget w);
+extern void clearPuzzle(MballWidget w);
+extern void solvePuzzle(MballWidget w);
+extern void incrementPuzzle(MballWidget w);
+extern Boolean decrementPuzzle(MballWidget w);
+extern void wedgePuzzle(MballWidget w, const int mode);
+extern void wedge2ModePuzzle(MballWidget w);
+extern void wedge4ModePuzzle(MballWidget w);
+extern void wedge6ModePuzzle(MballWidget w);
+extern void wedge8ModePuzzle(MballWidget w);
+extern void wedge10ModePuzzle(MballWidget w);
+extern void wedge12ModePuzzle(MballWidget w);
+extern void orientizePuzzle(MballWidget w);
+extern void middlePuzzle(MballWidget w);
+extern void speedUpPuzzle(MballWidget w);
+extern void slowDownPuzzle(MballWidget w);
+extern void toggleSoundPuzzle(MballWidget w);
+extern void enterPuzzle(MballWidget w);
+extern void leavePuzzle(MballWidget w);
+extern void movePuzzleInput(MballWidget w,
 	int x, int direction, int shift, int control);
 extern int  MoveMballDir(MballWidget w, const int direction);
 
@@ -122,16 +117,16 @@ extern MballClassRec mballClassRec;
 #define CIRCLE_2  (FULL_CIRCLE/2)
 #define CIRCLE_4  (FULL_CIRCLE/4)
 
-typedef struct _MoveRecord {
+typedef struct _moveRecord {
 #if 0
 	int wedge, direction, control;
 #endif
 	unsigned short int packed;  /* This makes assumptions on the data. */
 	int ring;                   /* Do not make assumptions on this one. */
-} MoveRecord;
+} moveRecord;
 
 typedef struct _MoveStack {
-	MoveRecord move;
+	moveRecord move;
 	struct _MoveStack *previous, *next;
 } MoveStack;
 
@@ -183,7 +178,7 @@ typedef struct _MballRec {
 
 extern MballLoc *startLoc[MAX_WEDGES];
 extern void setPuzzle(MballWidget w, int reason);
-extern void MovePuzzle(MballWidget w, const int wedge, const int ring,
+extern void movePuzzle(MballWidget w, const int wedge, const int ring,
 	const int direction, const int control);
 
 #if 0
@@ -191,8 +186,8 @@ extern void MovePuzzle(MballWidget w, const int wedge, const int ring,
 extern void SolveWedges(MballWidget w);
 
 #endif
-extern void DrawAllWedges(MballWidget w);
-extern Boolean CheckSolved(MballWidget w);
+extern void drawAllWedges(MballWidget w);
+extern Boolean checkSolved(MballWidget w);
 extern void newMoves(MballStack *s);
 extern void deleteMoves(MballStack *s);
 extern void setMove(MballStack *s,
