@@ -1,7 +1,7 @@
 /*
  * @(#)xmball.c
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2009  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -22,7 +22,7 @@
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Mball Version 7.4.1\n"
+"Mball Version 7.5\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -648,7 +648,7 @@ puzzleListener(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 	case ACTION_SOLVE_MESSAGE:
 #ifdef WINVER
 		(void) MessageBox(w->core.hWnd, solveHelp,
-			"Auto-Solve", MB_OK);
+			"Auto-solve", MB_OK);
 #else
 #ifdef HAVE_MOTIF
 		XtManageChild(solveDialog);
@@ -1470,13 +1470,13 @@ main(int argc, char **argv)
 	XmStringFree(playString);
 	getString = XmStringCreateSimple((char *) "Get");
 	writeString = XmStringCreateSimple((char *) "Write");
-	quitString = XmStringCreateSimple((char *) "Quit");
+	quitString = XmStringCreateSimple((char *) "Exit");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
 		0, fileMenuListener,
 		XmVaPUSHBUTTON, getString, 'G', NULL, NULL,
 		XmVaPUSHBUTTON, writeString, 'W', NULL, NULL,
 		XmVaSEPARATOR,
-		XmVaPUSHBUTTON, quitString, 'Q', NULL, NULL,
+		XmVaPUSHBUTTON, quitString, 'x', NULL, NULL,
 		NULL);
 	XmStringFree(getString);
 	XmStringFree(writeString);
@@ -1484,23 +1484,23 @@ main(int argc, char **argv)
 	undoString = XmStringCreateSimple((char *) "Undo");
 	redoString = XmStringCreateSimple((char *) "Redo");
 	clearString = XmStringCreateSimple((char *) "Clear");
-	randomizeString = XmStringCreateSimple((char *) "RandomiZe");
 	practiceString = XmStringCreateSimple((char *) "Practice");
-	solveString = XmStringCreateSimple((char *) "(Auto-Solve)");
+	randomizeString = XmStringCreateSimple((char *) "Randomize");
+	solveString = XmStringCreateSimple((char *) "(Auto-solve)");
 	incrementString = XmStringCreateSimple((char *) "Increment Rings");
 	decrementString = XmStringCreateSimple((char *) "Decrement Rings");
 	orientizeString = XmStringCreateSimple((char *) "Orientize");
-	speedString = XmStringCreateSimple((char *) ">Speed");
-	slowString = XmStringCreateSimple((char *) "<Slow");
-	soundString = XmStringCreateSimple((char *) "@Sound");
+	speedString = XmStringCreateSimple((char *) "Speed >");
+	slowString = XmStringCreateSimple((char *) "Slow <");
+	soundString = XmStringCreateSimple((char *) "Sound @");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "play_menu",
 		1, playCB,
 		XmVaPUSHBUTTON, undoString, 'U', NULL, NULL,
 		XmVaPUSHBUTTON, redoString, 'R', NULL, NULL,
 		XmVaPUSHBUTTON, clearString, 'C', NULL, NULL,
-		XmVaPUSHBUTTON, randomizeString, 'Z', NULL, NULL,
 		XmVaPUSHBUTTON, practiceString, 'P', NULL, NULL,
-		XmVaPUSHBUTTON, solveString, 'S', NULL, NULL,
+		XmVaPUSHBUTTON, randomizeString, 'z', NULL, NULL,
+		XmVaPUSHBUTTON, solveString, 's', NULL, NULL,
 		XmVaPUSHBUTTON, incrementString, 'I', NULL, NULL,
 		XmVaPUSHBUTTON, decrementString, 'D', NULL, NULL,
 		XmVaPUSHBUTTON, orientizeString, 'O', NULL, NULL,
@@ -1511,8 +1511,8 @@ main(int argc, char **argv)
 	XmStringFree(undoString);
 	XmStringFree(redoString);
 	XmStringFree(clearString);
-	XmStringFree(randomizeString);
 	XmStringFree(practiceString);
+	XmStringFree(randomizeString);
 	XmStringFree(solveString);
 	XmStringFree(incrementString);
 	XmStringFree(decrementString);
