@@ -67,6 +67,10 @@ static char faceColorChar[MAX_FACES] =
 #else
 #include "picture.h"
 
+#if defined( USE_SOUND ) && defined( USE_NAS )
+Display *dsp;
+#endif
+
 #ifndef LOGPATH
 #ifdef VMS
 #define LOGPATH "SYS$SCRATCH:"
@@ -2453,6 +2457,11 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int i;
 
+#if 0
+#if defined( USE_SOUND ) && defined( USE_ESOUND )
+	(void) shutdown_sound();
+#endif
+#endif
 	for (i = 0; i < MAX_FACES; i++)
 		XtReleaseGC(old, w->mlink.faceGC[i]);
 	XtReleaseGC(old, w->mlink.borderGC);
@@ -2673,6 +2682,16 @@ Widget request, Widget renew
 		w->mlink.delay + 1 : MAX_SLICES);
 	w->mlink.cheat = False;
 	sizePuzzle(w);
+#ifdef USE_SOUND
+#ifdef USE_NAS
+	dsp = XtDisplay(w);
+#endif
+#if 0
+#ifdef USE_ESOUND
+	(void) init_sound();
+#endif
+#endif
+#endif
 }
 
 #ifndef WINVER
