@@ -1,7 +1,7 @@
 /*
  * @(#)xmlink.c
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2009  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -22,7 +22,7 @@
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Mlink Version 7.4.1\n"
+"Mlink Version 7.5\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -648,7 +648,7 @@ puzzleListener(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
 	case ACTION_SOLVE_MESSAGE:
 #ifdef WINVER
 		(void) MessageBox(w->core.hWnd, solveHelp,
-			"Auto-Solve", MB_OK);
+			"Auto-solve", MB_OK);
 #else
 #ifdef HAVE_MOTIF
 		XtManageChild(solveDialog);
@@ -1556,13 +1556,13 @@ main(int argc, char **argv)
 	XmStringFree(playString);
 	getString = XmStringCreateSimple((char *) "Get");
 	writeString = XmStringCreateSimple((char *) "Write");
-	quitString = XmStringCreateSimple((char *) "Quit");
+	quitString = XmStringCreateSimple((char *) "Exit");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
 		0, fileMenuListener,
 		XmVaPUSHBUTTON, getString, 'G', NULL, NULL,
 		XmVaPUSHBUTTON, writeString, 'W', NULL, NULL,
 		XmVaSEPARATOR,
-		XmVaPUSHBUTTON, quitString, 'Q', NULL, NULL,
+		XmVaPUSHBUTTON, quitString, 'x', NULL, NULL,
 		NULL);
 	XmStringFree(getString);
 	XmStringFree(writeString);
@@ -1571,21 +1571,21 @@ main(int argc, char **argv)
 	redoString = XmStringCreateSimple((char *) "Redo");
 	clearString = XmStringCreateSimple((char *) "Clear");
 	practiceString = XmStringCreateSimple((char *) "Practice");
-	randomizeString = XmStringCreateSimple((char *) "RandomiZe");
-	solveString = XmStringCreateSimple((char *) "Auto-Solve");
+	randomizeString = XmStringCreateSimple((char *) "Randomize");
+	solveString = XmStringCreateSimple((char *) "Auto-solve");
 	orientizeString = XmStringCreateSimple((char *) "Orientize");
 	middleString = XmStringCreateSimple((char *) "Middle");
-	speedString = XmStringCreateSimple((char *) ">Speed");
-	slowString = XmStringCreateSimple((char *) "<Slow");
-	soundString = XmStringCreateSimple((char *) "@Sound");
+	speedString = XmStringCreateSimple((char *) "Speed >");
+	slowString = XmStringCreateSimple((char *) "Slow <");
+	soundString = XmStringCreateSimple((char *) "Sound @");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "play_menu",
 		1, playCB,
 		XmVaPUSHBUTTON, undoString, 'U', NULL, NULL,
 		XmVaPUSHBUTTON, redoString, 'R', NULL, NULL,
 		XmVaPUSHBUTTON, clearString, 'C', NULL, NULL,
 		XmVaPUSHBUTTON, practiceString, 'P', NULL, NULL,
-		XmVaPUSHBUTTON, randomizeString, 'Z', NULL, NULL,
-		XmVaPUSHBUTTON, solveString, 'S', NULL, NULL,
+		XmVaPUSHBUTTON, randomizeString, 'z', NULL, NULL,
+		XmVaPUSHBUTTON, solveString, 's', NULL, NULL,
 		XmVaPUSHBUTTON, orientizeString, 'O', NULL, NULL,
 		XmVaPUSHBUTTON, middleString, 'M', NULL, NULL,
 		XmVaPUSHBUTTON, speedString, '>', NULL, NULL,
