@@ -51,6 +51,10 @@ static char faceColorChar[MAX_FACES] =
 {'R', 'B', 'W', 'M', 'O', 'P', 'G', 'Y'};
 #else
 
+#if defined( USE_SOUND ) && defined( USE_NAS )
+Display *dsp;
+#endif
+
 #ifndef LOGPATH
 #ifdef VMS
 #define LOGPATH "SYS$SCRATCH:"
@@ -2765,6 +2769,11 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int face;
 
+#if 0
+#if defined( USE_SOUND ) && defined( USE_ESOUND )
+	(void) shutdown_sound();
+#endif
+#endif
 	for (face = 0; face < MAX_FACES; face++)
 		XtReleaseGC(old, w->oct.faceGC[face]);
 	XtReleaseGC(old, w->oct.borderGC);
@@ -2882,6 +2891,16 @@ Widget request, Widget renew
 	(void) SRAND(getpid());
 	setAllColors(w);
 #endif
+#ifdef USE_SOUND
+#ifdef USE_NAS
+	dsp = XtDisplay(w);
+#endif
+#if 0
+#ifdef USE_ESOUND
+	(void) init_sound();
+#endif
+#endif
+#endif
 }
 
 #ifndef WINVER
