@@ -44,6 +44,10 @@ static char pyramidColorChar[MAX_STACKS - 1] =
 {'M', 'O'};
 #else
 
+#if defined( USE_SOUND ) && defined( USE_NAS )
+Display *dsp;
+#endif
+
 #ifndef LOGPATH
 #ifdef VMS
 #define LOGPATH "SYS$SCRATCH:"
@@ -544,8 +548,7 @@ drawPyramid(PanexWidget w, Pixmap dr, int color, int i, int j, int size,
 	trapazoidList[0].y = j * w->panex.pos.y + w->panex.delta.y +
 		w->panex.puzzleOffset.y + offsetPosition + 2;
 	if (w->panex.mono) {
-		pyramidGC = (offsetPosition) ? w->panex.tileGC[4] :
-			w->panex.inverseGC[1];
+		pyramidGC = w->panex.inverseGC[1];
 	} else {
 #ifndef WINVER
 		if ((w->panex.pyramidColor[color] == w->panex.borderColor)
@@ -1978,6 +1981,11 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int i;
 
+#if 0
+#if defined( USE_SOUND ) && defined( USE_ESOUND )
+	(void) shutdown_sound();
+#endif
+#endif
 	for (i = 0; i < w->panex.stacks; i++)
 		XtReleaseGC(old, w->panex.pyramidGC[i]);
 	for (i = 0; i < FG_SHADES; i++)
@@ -2142,6 +2150,16 @@ Widget request, Widget renew
 	w->panex.numSlices = ((w->panex.delay < MAX_SLICES) ?
 		w->panex.delay + 1 : MAX_SLICES);
 	sizePuzzle(w);
+#ifdef USE_SOUND
+#ifdef USE_NAS
+	dsp = XtDisplay(w);
+#endif
+#if 0
+#ifdef USE_ESOUND
+	(void) init_sound();
+#endif
+#endif
+#endif
 }
 
 void
