@@ -37,6 +37,7 @@
 #define XtNdelay ((char *) "delay")
 #define XtNsound ((char *) "sound")
 #define XtNmoveSound ((char *) "moveSound")
+#define XtNdripSound ((char *) "dripSound")
 #define XtNtiles ((char *) "tiles")
 #define XtNmode ((char *) "mode")
 #define XtNuserName ((char *) "userName")
@@ -52,6 +53,7 @@
 #define XtCDelay ((char *) "Delay")
 #define XtCSound ((char *) "Sound")
 #define XtCMoveSound ((char *) "MoveSound")
+#define XtCDripSound ((char *) "DripSound")
 #define XtCTiles ((char *) "Tiles")
 #define XtCMode ((char *) "Mode")
 #define XtCUserName ((char *) "UserName")
@@ -101,8 +103,9 @@ typedef struct {
 #define MIN_TILES 1
 #define DEFAULT_TILES 10
 #define HANOI 0
-#define PANEX 1
-#define MAX_MODES 2
+#define ALGORITHME 1
+#define PANEX 2
+#define MAX_MODES 3
 #define DEFAULT_MODE PANEX
 #ifdef MONOTEST
 #define DEFAULT_MONO TRUE
