@@ -1,7 +1,7 @@
 /*
  * @(#)xpanex.c
  *
- * Copyright 1996 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1996 - 2009  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -22,7 +22,7 @@
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Panex Version 7.4.2\n"
+"Panex Version 7.5\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -100,7 +100,7 @@ static const char featuresHelp[] = {
 "(one pyramid column), Algorithme and Panex (each has\n"
 "two pyramid columns) modes (they each have different rules).  "
 "In Hanoi, one can not place larger trapezoid on a smaller\n"
-"trapezoid.  Here the goal is to move the pile from the left " 
+"trapezoid.  Here the goal is to move the pile from the left "
 "peg to the rightmost peg.  Algorithme is similar, here we\n"
 "must exchange tiles and we are limited by the size of the "
 "stack.  A move from stack 1 to stack 3 and vice-versa when\n"
@@ -1218,13 +1218,13 @@ main(int argc, char **argv)
 	XmStringFree(playString);
 	getString = XmStringCreateSimple((char *) "Get");
 	writeString = XmStringCreateSimple((char *) "Write");
-	quitString = XmStringCreateSimple((char *) "Quit");
+	quitString = XmStringCreateSimple((char *) "Exit");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
 		0, fileMenuListener,
 		XmVaPUSHBUTTON, getString, 'G', NULL, NULL,
 		XmVaPUSHBUTTON, writeString, 'W', NULL, NULL,
 		XmVaSEPARATOR,
-		XmVaPUSHBUTTON, quitString, 'Q', NULL, NULL,
+		XmVaPUSHBUTTON, quitString, 'x', NULL, NULL,
 		NULL);
 	XmStringFree(getString);
 	XmStringFree(writeString);
@@ -1232,19 +1232,19 @@ main(int argc, char **argv)
 	undoString = XmStringCreateSimple((char *) "Undo");
 	redoString = XmStringCreateSimple((char *) "Redo");
 	clearString = XmStringCreateSimple((char *) "Clear");
-	solveString = XmStringCreateSimple((char *) "Auto-Solve");
+	solveString = XmStringCreateSimple((char *) "Auto-solve");
 	mode = XmStringCreateSimple((char *) "Mode (Hanoi/Algorithme/Panex)");
 	incrementString = XmStringCreateSimple((char *) "Increment");
 	decrementString = XmStringCreateSimple((char *) "Decrement");
-	speedString = XmStringCreateSimple((char *) ">Speed");
-	slowString = XmStringCreateSimple((char *) "<Slow");
-	soundString = XmStringCreateSimple((char *) "@Sound");
+	speedString = XmStringCreateSimple((char *) "Speed >");
+	slowString = XmStringCreateSimple((char *) "Slow <");
+	soundString = XmStringCreateSimple((char *) "Sound @");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "play_menu",
 		1, playCB,
 		XmVaPUSHBUTTON, undoString, 'U', NULL, NULL,
 		XmVaPUSHBUTTON, redoString, 'R', NULL, NULL,
 		XmVaPUSHBUTTON, clearString, 'C', NULL, NULL,
-		XmVaPUSHBUTTON, solveString, 'S', NULL, NULL,
+		XmVaPUSHBUTTON, solveString, 's', NULL, NULL,
 		XmVaPUSHBUTTON, mode, 'M', NULL, NULL,
 		XmVaPUSHBUTTON, incrementString, 'I', NULL, NULL,
 		XmVaPUSHBUTTON, decrementString, 'D', NULL, NULL,
