@@ -47,6 +47,10 @@ static const char faceColorChar[MAX_FACES] =
 {'B', 'R', 'Y', 'G'};
 #else
 
+#if defined( USE_SOUND ) && defined( USE_NAS )
+Display *dsp;
+#endif
+
 #ifndef LOGPATH
 #ifdef VMS
 #define LOGPATH "SYS$SCRATCH:"
@@ -2664,6 +2668,11 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int face;
 
+#if 0
+#if defined( USE_SOUND ) && defined( USE_ESOUND )
+	(void) shutdown_sound();
+#endif
+#endif
 	for (face = 0; face < MAX_FACES; face++)
 		XtReleaseGC(old, w->pyraminx.faceGC[face]);
 	XtReleaseGC(old, w->pyraminx.borderGC);
@@ -2787,6 +2796,16 @@ Widget request, Widget renew
 	(void) SRAND(getpid());
 	setAllColors(w);
 #endif
+#ifdef USE_SOUND
+#ifdef USE_NAS
+	dsp = XtDisplay(w);
+#endif
+#if 0
+#ifdef USE_ESOUND
+	(void) init_sound();
+#endif
+#endif
+#endif
 }
 
 #ifndef WINVER
