@@ -1,27 +1,22 @@
-/*-
-# X-BASED RUBIK'S CUBE(tm)
-#
-#  RubikGL.c
-#
-###
-#
-#  Copyright (c) 2003 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#                   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)RubikGL.c
+ *
+ * Copyright 2003 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /*-
  * Permission to use, copy, modify, and distribute this software and its
@@ -171,28 +166,28 @@ static Boolean madeCurrent = False;
 static HGLRC hRC = NULL;
 #else
 static GLXContext *glXContext = (GLXContext *) NULL;
-static Boolean SetValuesPuzzleGL(Widget current, Widget request, Widget renew);
-static void ResizePuzzleGL(RubikGLWidget w);
-static void InitializePuzzleGL(Widget request, Widget renew);
-static void ExposePuzzleGL(Widget renew, XEvent *event, Region region);
-static void MovePuzzleGLTl(RubikGLWidget w,
+static Boolean setValuesPuzzleGL(Widget current, Widget request, Widget renew);
+static void resizePuzzleGL(RubikGLWidget w);
+static void initializePuzzleGL(Widget request, Widget renew);
+static void exposePuzzleGL(Widget renew, XEvent *event, Region region);
+static void movePuzzleGLTl(RubikGLWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzleGLTop(RubikGLWidget w,
+static void movePuzzleGLTop(RubikGLWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzleGLTr(RubikGLWidget w,
+static void movePuzzleGLTr(RubikGLWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzleGLLeft(RubikGLWidget w,
+static void movePuzzleGLLeft(RubikGLWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzleGLRight(RubikGLWidget w,
+static void movePuzzleGLRight(RubikGLWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzleGLBl(RubikGLWidget w,
+static void movePuzzleGLBl(RubikGLWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzleGLBottom(RubikGLWidget w,
+static void movePuzzleGLBottom(RubikGLWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzleGLBr(RubikGLWidget w,
+static void movePuzzleGLBr(RubikGLWidget w,
 	XEvent *event, char **args, int nArgs);
 
-static char defaultTranslationsPuzzleGL[] =
+static char translationsGL[] =
 "<KeyPress>q: Quit()\n\
  Ctrl<KeyPress>C: Quit()\n\
  <KeyPress>osfCancel: Hide()\n\
@@ -266,49 +261,49 @@ static char defaultTranslationsPuzzleGL[] =
  <EnterWindow>: Enter()\n\
  <LeaveWindow>: Leave()";
 
-static XtActionsRec actionsListPuzzleGL[] =
+static XtActionsRec actionsListGL[] =
 {
-	{(char *) "Quit", (XtActionProc) QuitPuzzle},
-	{(char *) "Hide", (XtActionProc) HidePuzzle},
-	{(char *) "MoveCcw", (XtActionProc) MovePuzzleCcw},
-	{(char *) "MoveTl", (XtActionProc) MovePuzzleGLTl},
-	{(char *) "MoveTop", (XtActionProc) MovePuzzleGLTop},
-	{(char *) "MoveTr", (XtActionProc) MovePuzzleGLTr},
-	{(char *) "MoveLeft", (XtActionProc) MovePuzzleGLLeft},
-	{(char *) "MoveCw", (XtActionProc) MovePuzzleCw},
-	{(char *) "MoveRight", (XtActionProc) MovePuzzleGLRight},
-	{(char *) "MoveBl", (XtActionProc) MovePuzzleGLBl},
-	{(char *) "MoveBottom", (XtActionProc) MovePuzzleGLBottom},
-	{(char *) "MoveBr", (XtActionProc) MovePuzzleGLBr},
-	{(char *) "Select", (XtActionProc) SelectPuzzle},
-	{(char *) "Release", (XtActionProc) ReleasePuzzle},
-	{(char *) "PracticeMaybe", (XtActionProc) PracticePuzzleMaybe},
-	{(char *) "Practice2", (XtActionProc) PracticePuzzle2},
-	{(char *) "RandomizeMaybe", (XtActionProc) RandomizePuzzleMaybe},
-	{(char *) "Randomize2", (XtActionProc) RandomizePuzzle2},
-	{(char *) "Get", (XtActionProc) GetPuzzle},
-	{(char *) "Write", (XtActionProc) WritePuzzle},
-	{(char *) "Undo", (XtActionProc) UndoPuzzle},
-	{(char *) "Redo", (XtActionProc) RedoPuzzle},
-	{(char *) "Clear", (XtActionProc) ClearPuzzle},
-	{(char *) "Randomize", (XtActionProc) RandomizePuzzle},
-	{(char *) "Solve", (XtActionProc) SolvePuzzle},
-	{(char *) "Practice", (XtActionProc) PracticePuzzle},
-	{(char *) "Orientize", (XtActionProc) OrientizePuzzle},
-	{(char *) "Decrement", (XtActionProc) DecrementPuzzle},
-	{(char *) "Increment", (XtActionProc) IncrementPuzzle},
-	{(char *) "IncrementX", (XtActionProc) IncrementXPuzzle},
-	{(char *) "IncrementY", (XtActionProc) IncrementYPuzzle},
-	{(char *) "IncrementZ", (XtActionProc) IncrementZPuzzle},
-	{(char *) "View", (XtActionProc) ViewPuzzle},
-	{(char *) "Speed", (XtActionProc) SpeedPuzzle},
-	{(char *) "Slow", (XtActionProc) SlowPuzzle},
-	{(char *) "Sound", (XtActionProc) SoundPuzzle},
-	{(char *) "Enter", (XtActionProc) EnterPuzzle},
-	{(char *) "Leave", (XtActionProc) LeavePuzzle}
+	{(char *) "Quit", (XtActionProc) quitPuzzle},
+	{(char *) "Hide", (XtActionProc) hidePuzzle},
+	{(char *) "MoveCcw", (XtActionProc) movePuzzleCcw},
+	{(char *) "MoveTl", (XtActionProc) movePuzzleGLTl},
+	{(char *) "MoveTop", (XtActionProc) movePuzzleGLTop},
+	{(char *) "MoveTr", (XtActionProc) movePuzzleGLTr},
+	{(char *) "MoveLeft", (XtActionProc) movePuzzleGLLeft},
+	{(char *) "MoveCw", (XtActionProc) movePuzzleCw},
+	{(char *) "MoveRight", (XtActionProc) movePuzzleGLRight},
+	{(char *) "MoveBl", (XtActionProc) movePuzzleGLBl},
+	{(char *) "MoveBottom", (XtActionProc) movePuzzleGLBottom},
+	{(char *) "MoveBr", (XtActionProc) movePuzzleGLBr},
+	{(char *) "Select", (XtActionProc) selectPuzzle},
+	{(char *) "Release", (XtActionProc) releasePuzzle},
+	{(char *) "PracticeMaybe", (XtActionProc) practicePuzzleWithQuery},
+	{(char *) "Practice2", (XtActionProc) practicePuzzleWithDoubleClick},
+	{(char *) "RandomizeMaybe", (XtActionProc) randomizePuzzleWithQuery},
+	{(char *) "Randomize2", (XtActionProc) randomizePuzzleWithDoubleClick},
+	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Write", (XtActionProc) writePuzzle},
+	{(char *) "Undo", (XtActionProc) undoPuzzle},
+	{(char *) "Redo", (XtActionProc) redoPuzzle},
+	{(char *) "Clear", (XtActionProc) clearPuzzle},
+	{(char *) "Randomize", (XtActionProc) randomizePuzzle},
+	{(char *) "Solve", (XtActionProc) solvePuzzle},
+	{(char *) "Practice", (XtActionProc) practicePuzzle},
+	{(char *) "Orientize", (XtActionProc) orientizePuzzle},
+	{(char *) "Decrement", (XtActionProc) decrementPuzzle},
+	{(char *) "Increment", (XtActionProc) incrementPuzzle},
+	{(char *) "IncrementX", (XtActionProc) incrementXPuzzle},
+	{(char *) "IncrementY", (XtActionProc) incrementYPuzzle},
+	{(char *) "IncrementZ", (XtActionProc) incrementZPuzzle},
+	{(char *) "View", (XtActionProc) viewPuzzle},
+	{(char *) "Speed", (XtActionProc) speedUpPuzzle},
+	{(char *) "Slow", (XtActionProc) slowDownPuzzle},
+	{(char *) "Sound", (XtActionProc) toggleSoundPuzzle},
+	{(char *) "Enter", (XtActionProc) enterPuzzle},
+	{(char *) "Leave", (XtActionProc) leavePuzzle}
 };
 
-static XtResource resourcesPuzzleGL[] =
+static XtResource resourcesGL[] =
 {
 	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
 	 XtOffset(RubikWidget, core.width),
@@ -327,7 +322,7 @@ static XtResource resourcesPuzzleGL[] =
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(RubikWidget, rubik.background),
-	 XtRString, (caddr_t) XtDefaultBackground},
+	 XtRString, (caddr_t) "#AEB2C3" /*XtDefaultBackground*/},
 	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(RubikWidget, rubik.frameColor),
 	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
@@ -435,29 +430,29 @@ RubikGLClassRec rubikGLClassRec =
 		NULL,		/* class initialize */
 		NULL,		/* class part initialize */
 		FALSE,		/* class inited */
-		(XtInitProc) InitializePuzzleGL,	/* initialize */
+		(XtInitProc) initializePuzzleGL,	/* initialize */
 		NULL,		/* initialize hook */
 		XtInheritRealize,	/* realize */
-		actionsListPuzzleGL,	/* actions */
-		XtNumber(actionsListPuzzleGL),	/* num actions */
-		resourcesPuzzleGL,	/* resources */
-		XtNumber(resourcesPuzzleGL),	/* num resources */
+		actionsListGL,	/* actions */
+		XtNumber(actionsListGL),	/* num actions */
+		resourcesGL,	/* resources */
+		XtNumber(resourcesGL),	/* num resources */
 		NULLQUARK,	/* xrm class */
 		TRUE,		/* compress motion */
 		TRUE,		/* compress exposure */
 		TRUE,		/* compress enterleave */
 		TRUE,		/* visible interest */
 		NULL,		/* destroy */
-		(XtWidgetProc) ResizePuzzleGL,	/* resize */
-		(XtExposeProc) ExposePuzzleGL,	/* expose */
-		(XtSetValuesFunc) SetValuesPuzzleGL,	/* set values */
+		(XtWidgetProc) resizePuzzleGL,	/* resize */
+		(XtExposeProc) exposePuzzleGL,	/* expose */
+		(XtSetValuesFunc) setValuesPuzzleGL,	/* set values */
 		NULL,		/* set values hook */
 		XtInheritSetValuesAlmost,	/* set values almost */
 		NULL,		/* get values hook */
 		XtInheritAcceptFocus,	/* accept focus */
 		XtVersion,	/* version */
 		NULL,		/* callback private */
-		defaultTranslationsPuzzleGL,	/* tm table */
+		translationsGL,	/* tm table */
 		NULL,		/* query geometry */
 		NULL,		/* display accelerator */
 		NULL		/* extension */
@@ -699,7 +694,7 @@ draw_stickerless_cubit(void)
 }
 
 static Boolean
-DrawCubit(RubikGLWidget w,
+drawCubit(RubikGLWidget w,
 		int back, int front, int left, int right, int bottom, int top)
 {
 	Boolean mono = w->rubik.mono;
@@ -752,7 +747,7 @@ DrawCubit(RubikGLWidget w,
 				glVertex3f(-CUT, CUT, -CUT_DEPTH);
 				break;
 			default:
-				intCat(&buf1, "DrawCubit: face ", BACK_FACE);
+				intCat(&buf1, "drawCubit: face ", BACK_FACE);
 				stringCat(&buf2, buf1, ", rotation ");
 				free(buf1);
 				intCat(&buf1, buf2, rotation);
@@ -808,7 +803,7 @@ DrawCubit(RubikGLWidget w,
 				glVertex3f(-CUT, -CUT, CUT_DEPTH);
 				break;
 			default:
-				intCat(&buf1, "DrawCubit: face ", FRONT_FACE);
+				intCat(&buf1, "drawCubit: face ", FRONT_FACE);
 				stringCat(&buf2, buf1, ", rotation ");
 				free(buf1);
 				intCat(&buf1, buf2, rotation);
@@ -864,7 +859,7 @@ DrawCubit(RubikGLWidget w,
 				glVertex3f(-CUT_DEPTH, -CUT, -CUT);
 				break;
 			default:
-				intCat(&buf1, "DrawCubit: face ", LEFT_FACE);
+				intCat(&buf1, "drawCubit: face ", LEFT_FACE);
 				stringCat(&buf2, buf1, ", rotation ");
 				free(buf1);
 				intCat(&buf1, buf2, rotation);
@@ -920,7 +915,7 @@ DrawCubit(RubikGLWidget w,
 				glVertex3f(CUT_DEPTH, -CUT, CUT);
 				break;
 			default:
-				intCat(&buf1, "DrawCubit: face ", RIGHT_FACE);
+				intCat(&buf1, "drawCubit: face ", RIGHT_FACE);
 				stringCat(&buf2, buf1, ", rotation ");
 				free(buf1);
 				intCat(&buf1, buf2, rotation);
@@ -976,7 +971,7 @@ DrawCubit(RubikGLWidget w,
 				glVertex3f(-CUT, -CUT_DEPTH, -CUT);
 				break;
 			default:
-				intCat(&buf1, "DrawCubit: face ", BOTTOM_FACE);
+				intCat(&buf1, "drawCubit: face ", BOTTOM_FACE);
 				stringCat(&buf2, buf1, ", rotation ");
 				free(buf1);
 				intCat(&buf1, buf2, rotation);
@@ -1032,7 +1027,7 @@ DrawCubit(RubikGLWidget w,
 				glVertex3f(-CUT, CUT_DEPTH, CUT);
 				break;
 			default:
-				intCat(&buf1, "DrawCubit: face ", TOP_FACE);
+				intCat(&buf1, "drawCubit: face ", TOP_FACE);
 				stringCat(&buf2, buf1, ", rotation ");
 				free(buf1);
 				intCat(&buf1, buf2, rotation);
@@ -1081,7 +1076,7 @@ convertMove(RubikGLWidget w, RubikMove move, RubikSlice * slice)
 
 /* Assume the size is at least 2, or its just not challenging... */
 static Boolean
-DrawCube(RubikGLWidget w)
+drawCube(RubikGLWidget w)
 {
 #define S1 1
 #define SX ((GLint)S1*(MAX_SIZEX-1))
@@ -1093,7 +1088,7 @@ DrawCube(RubikGLWidget w)
 #define MIDX(a) (((GLfloat)(2*a-MAX_SIZEX+1))/2.0)
 #define MIDY(a) (((GLfloat)(2*a-MAX_SIZEY+1))/2.0)
 #define MIDZ(a) (((GLfloat)(2*a-MAX_SIZEZ+1))/2.0)
-#define DRAW_CUBIT(w,b,f,l,r,bm,t) if (!DrawCubit(w,b,f,l,r,bm,t)) return False
+#define DRAW_CUBIT(w,b,f,l,r,bm,t) if (!drawCubit(w,b,f,l,r,bm,t)) return False
 	RubikSlice slice = {NO_FACE, NO_ROTATION, NO_DEPTH};
 	GLfloat rotateStep;
 	int i, j, k;
@@ -1794,7 +1789,7 @@ slice.face = FRONT_FACE;
 }
 
 void
-MovePiecesGL(RubikGLWidget w, int face, int position, int direction,
+movePiecesGL(RubikGLWidget w, int face, int position, int direction,
 		Boolean control, int fast)
 {
 	int i;
@@ -1823,7 +1818,7 @@ MovePiecesGL(RubikGLWidget w, int face, int position, int direction,
 					w->rubikGL.angleStepZ = -angleStep;
 				else if (rotateDir[face][direction] == 3)
 					w->rubikGL.angleStepZ = angleStep;
-				DrawAllPiecesGL(w);
+				drawAllPiecesGL(w);
 				Sleep(w->rubik.delay / (w->rubikGL.numTurnInc * fast));
 			}
 		else
@@ -1841,7 +1836,7 @@ MovePiecesGL(RubikGLWidget w, int face, int position, int direction,
 					w->rubikGL.angleStepZ = -angleStep;
 				else if (rotateDir[face][direction] == 3)
 					w->rubikGL.angleStepZ = angleStep;
-				DrawAllPiecesGL(w);
+				drawAllPiecesGL(w);
 				Sleep(w->rubik.delay / (w->rubikGL.numTurnInc * fast) *
 					2 / 3); /* Longer so move a little faster */
 			}
@@ -1852,13 +1847,13 @@ MovePiecesGL(RubikGLWidget w, int face, int position, int direction,
 		if (w->rubik.degreeTurn == 90)
 			for (i = 0; i < w->rubikGL.numTurnInc / fast; i++) {
 				w->rubikGL.rotateStep += 90.0 * fast / w->rubikGL.numTurnInc;
-				DrawAllPiecesGL(w);
+				drawAllPiecesGL(w);
 				Sleep(w->rubik.delay / (w->rubikGL.numTurnInc * fast));
 			}
 		else
 			for (i = 0; i < w->rubikGL.numTurnInc * 2 / fast; i++) {
 				w->rubikGL.rotateStep += 90.0 * fast / w->rubikGL.numTurnInc;
-				DrawAllPiecesGL(w);
+				drawAllPiecesGL(w);
 				Sleep(w->rubik.delay / (w->rubikGL.numTurnInc * fast) *
 					2 / 3); /* Longer so move a little faster */
 			}
@@ -1869,7 +1864,7 @@ MovePiecesGL(RubikGLWidget w, int face, int position, int direction,
 }
 
 void
-DrawAllPiecesGL(RubikGLWidget w)
+drawAllPiecesGL(RubikGLWidget w)
 {
 #ifdef WINVER
 	wglMakeCurrent(w->core.hDC, hRC);
@@ -1909,8 +1904,8 @@ DrawAllPiecesGL(RubikGLWidget w)
 	glRotatef(w->rubikGL.angleStepX, 0, 1, 0);
 	glRotatef(w->rubikGL.angleStepY, 1, 0, 0);
 	glRotatef(w->rubikGL.angleStepZ, 0, 0, 1);
-	if (!DrawCube(w)) {
-		DISPLAY_WARNING("DrawCube error");
+	if (!drawCube(w)) {
+		DISPLAY_WARNING("drawCube error");
 	}
 	glPopMatrix();
 	glFlush();
@@ -1922,20 +1917,21 @@ DrawAllPiecesGL(RubikGLWidget w)
 }
 
 void
-DrawFrameGL(RubikGLWidget w, Boolean focus)
+drawFrameGL(RubikGLWidget w, Boolean focus)
 {
 	/* UNUSED */
 }
 
 Boolean
-SelectPiecesGL(RubikGLWidget w, int x, int y, int *face, int *position)
+selectPiecesGL(RubikGLWidget w, int x, int y, int *face, int *position)
 {
 	/* UNUSED */
 	return True;
 }
 
 #ifdef WINVER
-Boolean setupPixelFormat(RubikGLWidget w, BYTE type, DWORD flags)
+static Boolean
+setupPixelFormat(RubikGLWidget w, BYTE type, DWORD flags)
 {
 	PIXELFORMATDESCRIPTOR pfd;
 	int pixelFormat;
@@ -1973,20 +1969,20 @@ Boolean setupPixelFormat(RubikGLWidget w, BYTE type, DWORD flags)
 }
 #else
 static Boolean
-SetValuesPuzzleGL(Widget current, Widget request, Widget renew)
+setValuesPuzzleGL(Widget current, Widget request, Widget renew)
 {
 	RubikGLWidget c = (RubikGLWidget) current, w = (RubikGLWidget) renew;
 	Boolean redraw = False;
 
 	if (w->rubik.view != c->rubik.view) {
-		ResizePuzzleGL(w);
+		resizePuzzleGL(w);
 		redraw = True;
 	}
 	if (w->rubik.sizex != c->rubik.sizex ||
 			w->rubik.sizey != c->rubik.sizey ||
 			w->rubik.sizez != c->rubik.sizez) {
-		ResetPieces((RubikWidget) w);
-		ResizePuzzleGL(w);
+		resetPieces((RubikWidget) w);
+		resizePuzzleGL(w);
 		redraw = True;
 	}
 #if 0
@@ -1996,7 +1992,7 @@ SetValuesPuzzleGL(Widget current, Widget request, Widget renew)
 			w->rubikGL.cubeSizex.y != c->rubikGL.cubeSizex.y ||
 			w->rubikGL.cubeSizey.y != c->rubikGL.cubeSizey.y ||
 			w->rubikGL.cubeSizez.y != c->rubikGL.cubeSizez.y) {
-		ResizePuzzleGL(w);
+		resizePuzzleGL(w);
 		redraw = True;
 	}
 #endif
@@ -2042,7 +2038,7 @@ initGL(RubikGLWidget w) {
 static
 #endif
 void
-ResizePuzzleGL(RubikGLWidget w)
+resizePuzzleGL(RubikGLWidget w)
 {
 #ifdef WINVER
 	RECT rect;
@@ -2087,7 +2083,7 @@ makeCurrentGL(RubikGLWidget w)
 			DefaultScreen(XtDisplay(w))));
 #endif
 	}
-	ResizePuzzleGL(w);
+	resizePuzzleGL(w);
 
 	glDrawBuffer(GL_BACK);
 	glClearDepth(1.0);
@@ -2126,16 +2122,16 @@ makeCurrentGL(RubikGLWidget w)
 
 #ifndef WINVER
 static void
-InitializePuzzleGL(Widget request, Widget renew)
+initializePuzzleGL(Widget request, Widget renew)
 {
 	RubikGLWidget w = (RubikGLWidget) renew;
 
-	SetAllColors((RubikWidget) w);
+	setAllColors((RubikWidget) w);
 	(void) initGL(w);
 	w->rubik.dim = 4; /* 2 and 3 already taken */
 	w->rubikGL.numTurnInc = ((w->rubik.delay < MAX_TURN_INC) ?
 		w->rubik.delay + 1 : MAX_TURN_INC);
-	ResizePuzzleGL(w);
+	resizePuzzleGL(w);
 }
 #endif
 
@@ -2143,7 +2139,7 @@ InitializePuzzleGL(Widget request, Widget renew)
 static
 #endif
 void
-ExposePuzzleGL(
+exposePuzzleGL(
 #ifdef WINVER
 RubikGLWidget w
 #else
@@ -2178,71 +2174,71 @@ Widget renew, XEvent *event, Region region
 	if (!madeCurrent) {
 		makeCurrentGL(w);
 	}
-	DrawFrameGL(w, w->rubik.focus);
-	DrawAllPiecesGL(w);
+	drawFrameGL(w, w->rubik.focus);
+	drawAllPiecesGL(w);
 }
 
 #ifndef WINVER
 static void
-MovePuzzleGLTl(RubikGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLTl(RubikGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
 		TL,
 		(int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzleGLTop(RubikGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLTop(RubikGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
 		TOP,
 		(int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzleGLTr(RubikGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLTr(RubikGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
 		TR,
 		(int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzleGLLeft(RubikGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLLeft(RubikGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
 		LEFT,
 		(int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzleGLRight(RubikGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLRight(RubikGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
 		RIGHT,
 		(int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzleGLBl(RubikGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLBl(RubikGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
 		BL,
 		(int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzleGLBottom(RubikGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLBottom(RubikGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
 		BOTTOM,
 		(int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzleGLBr(RubikGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLBr(RubikGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((RubikWidget) w, event->xbutton.x, event->xbutton.y,
 		BR,
 		(int) (event->xkey.state & ControlMask));
 }
