@@ -53,6 +53,9 @@ static const char *faceColorString[MAX_FACES] =
 static const char faceColorChar[MAX_FACES] =
 {'R', 'B', 'W', 'G', 'P', 'Y'};
 #else
+#if defined( USE_SOUND ) && defined( USE_NAS )
+Display *dsp;
+#endif
 
 #ifndef LOGPATH
 #ifdef VMS
@@ -1626,6 +1629,11 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int face;
 
+#if 0
+#if defined( USE_SOUND ) && defined( USE_ESOUND )
+	(void) shutdown_sound();
+#endif
+#endif
 	for (face = 0; face < MAX_FACES; face++)
 		XtReleaseGC(old, w->skewb.faceGC[face]);
 	XtReleaseGC(old, w->skewb.borderGC);
@@ -1688,6 +1696,16 @@ Widget request, Widget renew
 #else
 	(void) SRAND(getpid());
 #endif
+#ifdef USE_SOUND
+#ifdef USE_NAS
+	dsp = XtDisplay(w);
+#endif
+#if 0
+#ifdef USE_ESOUND
+	(void) init_sound();
+#endif
+#endif
+#endif
 }
 
 void
