@@ -1,27 +1,22 @@
-/*-
-# X-BASED SKEWB
-#
-#  SkewbGL.c
-#
-###
-#
-#  Copyright (c) 2003 - 2007	David A. Bagley, bagleyd@tux.org
-#
-#		   All Rights Reserved
-#
-#  Permission to use, copy, modify, and distribute this software and
-#  its documentation for any purpose and without fee is hereby granted,
-#  provided that the above copyright notice appear in all copies and
-#  that both that copyright notice and this permission notice appear in
-#  supporting documentation, and that the name of the author not be
-#  used in advertising or publicity pertaining to distribution of the
-#  software without specific, written prior permission.
-#
-#  This program is distributed in the hope that it will be "playable",
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#
-*/
+/*
+ * @(#)SkewbGL.c
+ *
+ * Copyright 2003 - 2008  David A. Bagley, bagleyd@tux.org
+ *
+ * All rights reserved.
+ *
+ * Permission to use, copy, modify, and distribute this software and
+ * its documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and
+ * that both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of the author not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * This program is distributed in the hope that it will be "useful",
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ */
 
 /*-
  * Permission to use, copy, modify, and distribute this software and its
@@ -284,28 +279,28 @@ static Boolean madeCurrent = False;
 static HGLRC hRC = NULL;
 #else
 static GLXContext *glXContext = (GLXContext *) NULL;
-static Boolean SetValuesPuzzleGL(Widget current, Widget request, Widget renew);
-static void ResizePuzzleGL(SkewbGLWidget w);
-static void InitializePuzzleGL(Widget request, Widget renew);
-static void ExposePuzzleGL(Widget renew, XEvent *event, Region region);
-static void MovePuzzleGLTl(SkewbGLWidget w,
+static Boolean setValuesPuzzleGL(Widget current, Widget request, Widget renew);
+static void resizePuzzleGL(SkewbGLWidget w);
+static void initializePuzzleGL(Widget request, Widget renew);
+static void exposePuzzleGL(Widget renew, XEvent *event, Region region);
+static void movePuzzleGLTl(SkewbGLWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzleGLTop(SkewbGLWidget w,
+static void movePuzzleGLTop(SkewbGLWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzleGLTr(SkewbGLWidget w,
+static void movePuzzleGLTr(SkewbGLWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzleGLLeft(SkewbGLWidget w,
+static void movePuzzleGLLeft(SkewbGLWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzleGLRight(SkewbGLWidget w,
+static void movePuzzleGLRight(SkewbGLWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzleGLBl(SkewbGLWidget w,
+static void movePuzzleGLBl(SkewbGLWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzleGLBottom(SkewbGLWidget w,
+static void movePuzzleGLBottom(SkewbGLWidget w,
 	XEvent *event, char **args, int nArgs);
-static void MovePuzzleGLBr(SkewbGLWidget w,
+static void movePuzzleGLBr(SkewbGLWidget w,
 	XEvent *event, char **args, int nArgs);
 
-static char defaultTranslationsPuzzleGL[] =
+static char translationsGL[] =
 "<KeyPress>q: Quit()\n\
  Ctrl<KeyPress>C: Quit()\n\
  <KeyPress>osfCancel: Hide()\n\
@@ -374,44 +369,44 @@ static char defaultTranslationsPuzzleGL[] =
  <EnterWindow>: Enter()\n\
  <LeaveWindow>: Leave()";
 
-static XtActionsRec actionsListPuzzleGL[] =
+static XtActionsRec actionsListGL[] =
 {
-	{(char *) "Quit", (XtActionProc) QuitPuzzle},
-	{(char *) "Hide", (XtActionProc) HidePuzzle},
-	{(char *) "MoveCcw", (XtActionProc) MovePuzzleCcw},
-	{(char *) "MoveTl", (XtActionProc) MovePuzzleGLTl},
-	{(char *) "MoveTop", (XtActionProc) MovePuzzleGLTop},
-	{(char *) "MoveTr", (XtActionProc) MovePuzzleGLTr},
-	{(char *) "MoveLeft", (XtActionProc) MovePuzzleGLLeft},
-	{(char *) "MoveCw", (XtActionProc) MovePuzzleCw},
-	{(char *) "MoveRight", (XtActionProc) MovePuzzleGLRight},
-	{(char *) "MoveBl", (XtActionProc) MovePuzzleGLBl},
-	{(char *) "MoveBottom", (XtActionProc) MovePuzzleGLBottom},
-	{(char *) "MoveBr", (XtActionProc) MovePuzzleGLBr},
-	{(char *) "Select", (XtActionProc) SelectPuzzle},
-	{(char *) "Release", (XtActionProc) ReleasePuzzle},
-	{(char *) "PracticeMaybe", (XtActionProc) PracticePuzzleMaybe},
-	{(char *) "Practice2", (XtActionProc) PracticePuzzle2},
-	{(char *) "RandomizeMaybe", (XtActionProc) RandomizePuzzleMaybe},
-	{(char *) "Randomize2", (XtActionProc) RandomizePuzzle2},
-	{(char *) "Get", (XtActionProc) GetPuzzle},
-	{(char *) "Write", (XtActionProc) WritePuzzle},
-	{(char *) "Undo", (XtActionProc) UndoPuzzle},
-	{(char *) "Redo", (XtActionProc) RedoPuzzle},
-	{(char *) "Clear", (XtActionProc) ClearPuzzle},
-	{(char *) "Randomize", (XtActionProc) RandomizePuzzle},
-	{(char *) "Solve", (XtActionProc) SolvePuzzle},
-	{(char *) "Practice", (XtActionProc) PracticePuzzle},
-	{(char *) "Orientize", (XtActionProc) OrientizePuzzle},
-	{(char *) "View", (XtActionProc) ViewPuzzle},
-	{(char *) "Speed", (XtActionProc) SpeedPuzzle},
-	{(char *) "Slow", (XtActionProc) SlowPuzzle},
-	{(char *) "Sound", (XtActionProc) SoundPuzzle},
-	{(char *) "Enter", (XtActionProc) EnterPuzzle},
-	{(char *) "Leave", (XtActionProc) LeavePuzzle}
+	{(char *) "Quit", (XtActionProc) quitPuzzle},
+	{(char *) "Hide", (XtActionProc) hidePuzzle},
+	{(char *) "MoveCcw", (XtActionProc) movePuzzleCcw},
+	{(char *) "MoveTl", (XtActionProc) movePuzzleGLTl},
+	{(char *) "MoveTop", (XtActionProc) movePuzzleGLTop},
+	{(char *) "MoveTr", (XtActionProc) movePuzzleGLTr},
+	{(char *) "MoveLeft", (XtActionProc) movePuzzleGLLeft},
+	{(char *) "MoveCw", (XtActionProc) movePuzzleCw},
+	{(char *) "MoveRight", (XtActionProc) movePuzzleGLRight},
+	{(char *) "MoveBl", (XtActionProc) movePuzzleGLBl},
+	{(char *) "MoveBottom", (XtActionProc) movePuzzleGLBottom},
+	{(char *) "MoveBr", (XtActionProc) movePuzzleGLBr},
+	{(char *) "Select", (XtActionProc) selectPuzzle},
+	{(char *) "Release", (XtActionProc) releasePuzzle},
+	{(char *) "PracticeMaybe", (XtActionProc) practicePuzzleWithQuery},
+	{(char *) "Practice2", (XtActionProc) practicePuzzleWithDoubleClick},
+	{(char *) "RandomizeMaybe", (XtActionProc) randomizePuzzleWithQuery},
+	{(char *) "Randomize2", (XtActionProc) randomizePuzzleWithDoubleClick},
+	{(char *) "Get", (XtActionProc) getPuzzle},
+	{(char *) "Write", (XtActionProc) writePuzzle},
+	{(char *) "Undo", (XtActionProc) undoPuzzle},
+	{(char *) "Redo", (XtActionProc) redoPuzzle},
+	{(char *) "Clear", (XtActionProc) clearPuzzle},
+	{(char *) "Randomize", (XtActionProc) randomizePuzzle},
+	{(char *) "Solve", (XtActionProc) solvePuzzle},
+	{(char *) "Practice", (XtActionProc) practicePuzzle},
+	{(char *) "Orientize", (XtActionProc) orientizePuzzle},
+	{(char *) "View", (XtActionProc) viewPuzzle},
+	{(char *) "Speed", (XtActionProc) speedUpPuzzle},
+	{(char *) "Slow", (XtActionProc) slowDownPuzzle},
+	{(char *) "Sound", (XtActionProc) toggleSoundPuzzle},
+	{(char *) "Enter", (XtActionProc) enterPuzzle},
+	{(char *) "Leave", (XtActionProc) leavePuzzle}
 };
 
-static XtResource resourcesPuzzleGL[] =
+static XtResource resourcesGL[] =
 {
 	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
 	 XtOffset(SkewbWidget, core.width),
@@ -430,7 +425,7 @@ static XtResource resourcesPuzzleGL[] =
 	 XtRString, (caddr_t) XtDefaultForeground},
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(SkewbWidget, skewb.background),
-	 XtRString, (caddr_t) XtDefaultBackground},
+	 XtRString, (caddr_t) "#AEB2C3" /*XtDefaultBackground*/},
 	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(SkewbWidget, skewb.frameColor),
 	 XtRString, (caddr_t) "Cyan" /*XtDefaultForeground*/},
@@ -523,29 +518,29 @@ SkewbGLClassRec skewbGLClassRec =
 		NULL,		/* class initialize */
 		NULL,		/* class part initialize */
 		FALSE,		/* class inited */
-		(XtInitProc) InitializePuzzleGL,	/* initialize */
+		(XtInitProc) initializePuzzleGL,	/* initialize */
 		NULL,		/* initialize hook */
 		XtInheritRealize,	/* realize */
-		actionsListPuzzleGL,	/* actions */
-		XtNumber(actionsListPuzzleGL),	/* num actions */
-		resourcesPuzzleGL,	/* resources */
-		XtNumber(resourcesPuzzleGL),	/* num resources */
+		actionsListGL,	/* actions */
+		XtNumber(actionsListGL),	/* num actions */
+		resourcesGL,	/* resources */
+		XtNumber(resourcesGL),	/* num resources */
 		NULLQUARK,	/* xrm class */
 		TRUE,		/* compress motion */
 		TRUE,		/* compress exposure */
 		TRUE,		/* compress enterleave */
 		TRUE,		/* visible interest */
 		NULL,		/* destroy */
-		(XtWidgetProc) ResizePuzzleGL,	/* resize */
-		(XtExposeProc) ExposePuzzleGL,	/* expose */
-		(XtSetValuesFunc) SetValuesPuzzleGL,	/* set values */
+		(XtWidgetProc) resizePuzzleGL,	/* resize */
+		(XtExposeProc) exposePuzzleGL,	/* expose */
+		(XtSetValuesFunc) setValuesPuzzleGL,	/* set values */
 		NULL,		/* set values hook */
 		XtInheritSetValuesAlmost,	/* set values almost */
 		NULL,		/* get values hook */
 		XtInheritAcceptFocus,	/* accept focus */
 		XtVersion,	/* version */
 		NULL,		/* callback private */
-		defaultTranslationsPuzzleGL,	/* tm table */
+		translationsGL,	/* tm table */
 		NULL,		/* query geometry */
 		NULL,		/* display accelerator */
 		NULL		/* extension */
@@ -745,7 +740,7 @@ draw_stickerless_facit(void)
 }
 
 static void
-DrawOrientLine(SkewbGLWidget w, int face, int rotation,
+drawOrientLine(SkewbGLWidget w, int face, int rotation,
 		float size, float x, float y, float z)
 {
 	int err = 0;
@@ -950,7 +945,7 @@ DrawOrientLine(SkewbGLWidget w, int face, int rotation,
 }
 
 static void
-DrawFacit(SkewbGLWidget w, int face)
+drawFacit(SkewbGLWidget w, int face)
 {
 	Boolean mono = w->skewb.mono;
 
@@ -966,7 +961,7 @@ DrawFacit(SkewbGLWidget w, int face)
 		glVertex3f(FSTICKER_LONG, FSTICKER_DEPTH, 0.0);
 		glEnd();
 		if (w->skewb.orient) {
-			DrawOrientLine(w, face,
+			drawOrientLine(w, face,
 				w->skewb.cubeLoc[face][MAX_ORIENT].rotation,
 				2.0,
 				0.0, FCUT_DEPTH, 0.0);
@@ -981,7 +976,7 @@ DrawFacit(SkewbGLWidget w, int face)
 		glVertex3f(-FSTICKER_DEPTH, FSTICKER_LONG, 0.0);
 		glEnd();
 		if (w->skewb.orient) {
-			DrawOrientLine(w, face,
+			drawOrientLine(w, face,
 				w->skewb.cubeLoc[face][MAX_ORIENT].rotation,
 				2.0,
 				-FCUT_DEPTH, 0.0, 0.0);
@@ -996,7 +991,7 @@ DrawFacit(SkewbGLWidget w, int face)
 		glVertex3f(0.0, FSTICKER_LONG, FSTICKER_DEPTH);
 		glEnd();
 		if (w->skewb.orient) {
-			DrawOrientLine(w, face,
+			drawOrientLine(w, face,
 				w->skewb.cubeLoc[face][MAX_ORIENT].rotation,
 				2.0,
 				0.0, 0.0, FCUT_DEPTH);
@@ -1011,7 +1006,7 @@ DrawFacit(SkewbGLWidget w, int face)
 		glVertex3f(FSTICKER_DEPTH, 0.0, -FSTICKER_LONG);
 		glEnd();
 		if (w->skewb.orient) {
-			DrawOrientLine(w, face,
+			drawOrientLine(w, face,
 				w->skewb.cubeLoc[face][MAX_ORIENT].rotation,
 				2.0,
 				FCUT_DEPTH, 0.0, 0.0);
@@ -1026,7 +1021,7 @@ DrawFacit(SkewbGLWidget w, int face)
 		glVertex3f(0.0, -FSTICKER_DEPTH, -FSTICKER_LONG);
 		glEnd();
 		if (w->skewb.orient) {
-			DrawOrientLine(w, face,
+			drawOrientLine(w, face,
 				w->skewb.cubeLoc[face][MAX_ORIENT].rotation,
 				2.0,
 				0.0, -FCUT_DEPTH, 0.0);
@@ -1041,7 +1036,7 @@ DrawFacit(SkewbGLWidget w, int face)
 		glVertex3f(-FSTICKER_LONG, 0.0, -FSTICKER_DEPTH);
 		glEnd();
 		if (w->skewb.orient) {
-			DrawOrientLine(w, face,
+			drawOrientLine(w, face,
 				w->skewb.cubeLoc[face][MAX_ORIENT].rotation,
 				2.0,
 				0.0, 0.0, -FCUT_DEPTH);
@@ -1052,7 +1047,7 @@ DrawFacit(SkewbGLWidget w, int face)
 }
 
 static void
-DrawCubit(SkewbGLWidget w,
+drawCubit(SkewbGLWidget w,
 	int back, int front, int left, int right, int bottom, int top)
 {
 	Boolean mono = w->skewb.mono;
@@ -1081,25 +1076,25 @@ DrawCubit(SkewbGLWidget w,
 		glEnd();
 		if (w->skewb.orient) {
 			if (right != NO_FACE && top != NO_FACE) {
-				DrawOrientLine(w, BACK_FACE,
+				drawOrientLine(w, BACK_FACE,
 					w->skewb.cubeLoc[BACK_FACE][1].rotation,
 					0.5,
 					0.1, 0.5 * STICKER_SHORT, -CUT_DEPTH);
 			}
 			if (left != NO_FACE && top != NO_FACE) {
-				DrawOrientLine(w, BACK_FACE,
+				drawOrientLine(w, BACK_FACE,
 					w->skewb.cubeLoc[BACK_FACE][2].rotation,
 					0.5,
 					-0.5 * STICKER_SHORT, 0.1, -CUT_DEPTH);
 			}
 			if (right != NO_FACE && bottom != NO_FACE) {
-				DrawOrientLine(w, BACK_FACE,
+				drawOrientLine(w, BACK_FACE,
 					w->skewb.cubeLoc[BACK_FACE][0].rotation,
 					0.5,
 					0.1, -0.5 * STICKER_SHORT, -CUT_DEPTH);
 			}
 			if (left != NO_FACE && bottom != NO_FACE) {
-				DrawOrientLine(w, BACK_FACE,
+				drawOrientLine(w, BACK_FACE,
 					w->skewb.cubeLoc[BACK_FACE][3].rotation,
 					0.5,
 					-0.5 * STICKER_SHORT, -0.1, -CUT_DEPTH);
@@ -1131,25 +1126,25 @@ DrawCubit(SkewbGLWidget w,
 		glEnd();
 		if (w->skewb.orient) {
 			if (right != NO_FACE && top != NO_FACE) {
-				DrawOrientLine(w, FRONT_FACE,
+				drawOrientLine(w, FRONT_FACE,
 					w->skewb.cubeLoc[FRONT_FACE][0].rotation,
 					0.5,
 					0.1, 0.5 * STICKER_SHORT, CUT_DEPTH);
 			}
 			if (left != NO_FACE && top != NO_FACE) {
-				DrawOrientLine(w, FRONT_FACE,
+				drawOrientLine(w, FRONT_FACE,
 					w->skewb.cubeLoc[FRONT_FACE][3].rotation,
 					0.5,
 					-0.5 * STICKER_SHORT, 0.1, CUT_DEPTH);
 			}
 			if (right != NO_FACE && bottom != NO_FACE) {
-				DrawOrientLine(w, FRONT_FACE,
+				drawOrientLine(w, FRONT_FACE,
 					w->skewb.cubeLoc[FRONT_FACE][1].rotation,
 					0.5,
 					0.1, -0.5 * STICKER_SHORT, CUT_DEPTH);
 			}
 			if (left != NO_FACE && bottom != NO_FACE) {
-				DrawOrientLine(w, FRONT_FACE,
+				drawOrientLine(w, FRONT_FACE,
 					w->skewb.cubeLoc[FRONT_FACE][2].rotation,
 					0.5,
 					-0.5 * STICKER_SHORT, -0.1, CUT_DEPTH);
@@ -1181,25 +1176,25 @@ DrawCubit(SkewbGLWidget w,
 		glEnd();
 		if (w->skewb.orient) {
 			if (front != NO_FACE && top != NO_FACE) {
-				DrawOrientLine(w, LEFT_FACE,
+				drawOrientLine(w, LEFT_FACE,
 					w->skewb.cubeLoc[LEFT_FACE][0].rotation,
 					0.5,
 					-CUT_DEPTH, 0.1, 0.5 * STICKER_SHORT);
 			}
 			if (back != NO_FACE && top != NO_FACE) {
-				DrawOrientLine(w, LEFT_FACE,
+				drawOrientLine(w, LEFT_FACE,
 					w->skewb.cubeLoc[LEFT_FACE][3].rotation,
 					0.5,
 					-CUT_DEPTH, 0.5 * STICKER_SHORT, -0.1);
 			}
 			if (front != NO_FACE && bottom != NO_FACE) {
-				DrawOrientLine(w, LEFT_FACE,
+				drawOrientLine(w, LEFT_FACE,
 					w->skewb.cubeLoc[LEFT_FACE][1].rotation,
 					0.5,
 					-CUT_DEPTH, -0.1, 0.5 * STICKER_SHORT);
 			}
 			if (back != NO_FACE && bottom != NO_FACE) {
-				DrawOrientLine(w, LEFT_FACE,
+				drawOrientLine(w, LEFT_FACE,
 					w->skewb.cubeLoc[LEFT_FACE][2].rotation,
 					0.5,
 					-CUT_DEPTH, -0.5 * STICKER_SHORT, -0.1);
@@ -1231,25 +1226,25 @@ DrawCubit(SkewbGLWidget w,
 		glEnd();
 		if (w->skewb.orient) {
 			if (front != NO_FACE && top != NO_FACE) {
-				DrawOrientLine(w, RIGHT_FACE,
+				drawOrientLine(w, RIGHT_FACE,
 					w->skewb.cubeLoc[RIGHT_FACE][3].rotation,
 					0.5,
 					CUT_DEPTH, 0.1, 0.5 * STICKER_SHORT);
 			}
 			if (back != NO_FACE && top != NO_FACE) {
-				DrawOrientLine(w, RIGHT_FACE,
+				drawOrientLine(w, RIGHT_FACE,
 					w->skewb.cubeLoc[RIGHT_FACE][0].rotation,
 					0.5,
 					CUT_DEPTH, 0.5 * STICKER_SHORT, -0.1);
 			}
 			if (front != NO_FACE && bottom != NO_FACE) {
-				DrawOrientLine(w, RIGHT_FACE,
+				drawOrientLine(w, RIGHT_FACE,
 					w->skewb.cubeLoc[RIGHT_FACE][2].rotation,
 					0.5,
 					CUT_DEPTH, -0.1, 0.5 * STICKER_SHORT);
 			}
 			if (back != NO_FACE && bottom != NO_FACE) {
-				DrawOrientLine(w, RIGHT_FACE,
+				drawOrientLine(w, RIGHT_FACE,
 					w->skewb.cubeLoc[RIGHT_FACE][1].rotation,
 					0.5,
 					CUT_DEPTH, -0.5 * STICKER_SHORT, -0.1);
@@ -1281,25 +1276,25 @@ DrawCubit(SkewbGLWidget w,
 		glEnd();
 		if (w->skewb.orient) {
 			if (right != NO_FACE && back != NO_FACE) {
-				DrawOrientLine(w, BOTTOM_FACE,
+				drawOrientLine(w, BOTTOM_FACE,
 					w->skewb.cubeLoc[BOTTOM_FACE][1].rotation,
 					0.5,
 					0.5 * STICKER_SHORT, -CUT_DEPTH, -0.1);
 			}
 			if (left != NO_FACE && back != NO_FACE) {
-				DrawOrientLine(w, BOTTOM_FACE,
+				drawOrientLine(w, BOTTOM_FACE,
 					w->skewb.cubeLoc[BOTTOM_FACE][2].rotation,
 					0.5,
 					-0.5 * STICKER_SHORT, -CUT_DEPTH, -0.1);
 			}
 			if (right != NO_FACE && front != NO_FACE) {
-				DrawOrientLine(w, BOTTOM_FACE,
+				drawOrientLine(w, BOTTOM_FACE,
 					w->skewb.cubeLoc[BOTTOM_FACE][0].rotation,
 					0.5,
 					0.5 * STICKER_SHORT, -CUT_DEPTH, 0.1);
 			}
 			if (left != NO_FACE && front != NO_FACE) {
-				DrawOrientLine(w, BOTTOM_FACE,
+				drawOrientLine(w, BOTTOM_FACE,
 					w->skewb.cubeLoc[BOTTOM_FACE][3].rotation,
 					0.5,
 					-0.5 * STICKER_SHORT, -CUT_DEPTH, 0.1);
@@ -1331,25 +1326,25 @@ DrawCubit(SkewbGLWidget w,
 		glEnd();
 		if (w->skewb.orient) {
 			if (right != NO_FACE && back != NO_FACE) {
-				DrawOrientLine(w, TOP_FACE,
+				drawOrientLine(w, TOP_FACE,
 					w->skewb.cubeLoc[TOP_FACE][0].rotation,
 					0.5,
 					0.5 * STICKER_SHORT, CUT_DEPTH, -0.1);
 			}
 			if (left != NO_FACE && back != NO_FACE) {
-				DrawOrientLine(w, TOP_FACE,
+				drawOrientLine(w, TOP_FACE,
 					w->skewb.cubeLoc[TOP_FACE][3].rotation,
 					0.5,
 					-0.5 * STICKER_SHORT, CUT_DEPTH, -0.1);
 			}
 			if (right != NO_FACE && front != NO_FACE) {
-				DrawOrientLine(w, TOP_FACE,
+				drawOrientLine(w, TOP_FACE,
 					w->skewb.cubeLoc[TOP_FACE][1].rotation,
 					0.5,
 					0.5 * STICKER_SHORT, CUT_DEPTH, 0.1);
 			}
 			if (left != NO_FACE && front != NO_FACE) {
-				DrawOrientLine(w, TOP_FACE,
+				drawOrientLine(w, TOP_FACE,
 					w->skewb.cubeLoc[TOP_FACE][2].rotation,
 					0.5,
 					-0.5 * STICKER_SHORT, CUT_DEPTH, 0.1);
@@ -1360,7 +1355,7 @@ DrawCubit(SkewbGLWidget w,
 }
 
 static Boolean
-DrawCube(SkewbGLWidget w)
+drawCube(SkewbGLWidget w)
 {
 #define S1 1
 #define DRAW_STICKERLESS_FACIT() if (!draw_stickerless_facit()) return False
@@ -1373,7 +1368,7 @@ DrawCube(SkewbGLWidget w)
 		slice.face = NO_FACE;
 		slice.rotation = NO_ROTATION;
 #ifdef FIXME
-	} else {
+	/*} else {*/
 		convertMove(w, w->skewbGL.movement, &slice);
 #endif
 	}
@@ -1420,7 +1415,7 @@ DrawCube(SkewbGLWidget w)
 		glPopMatrix();
 		for (i = 0; i < MAX_FACES; i++) {
 			glPushMatrix();
-			DrawFacit(w, i);
+			drawFacit(w, i);
 			glPopMatrix();
 		}
 		glTranslatef(-0.5, -0.5, -0.5);
@@ -1429,7 +1424,7 @@ DrawCube(SkewbGLWidget w)
 		glRotatef(180.0, 1, 0, 0);
 		DRAW_STICKERLESS_CUBIT();
 		glPopMatrix();
-		DrawCubit(w, w->skewb.cubeLoc[BACK_FACE][3].face,
+		drawCubit(w, w->skewb.cubeLoc[BACK_FACE][3].face,
 			NO_FACE,
 			w->skewb.cubeLoc[LEFT_FACE][2].face,
 			NO_FACE,
@@ -1440,7 +1435,7 @@ DrawCube(SkewbGLWidget w)
 		glRotatef(180.0, 0, 0, 1);
 		DRAW_STICKERLESS_CUBIT();
 		glPopMatrix();
-		DrawCubit(w, NO_FACE,
+		drawCubit(w, NO_FACE,
 			w->skewb.cubeLoc[FRONT_FACE][2].face,
 			w->skewb.cubeLoc[LEFT_FACE][1].face,
 			NO_FACE,
@@ -1452,7 +1447,7 @@ DrawCube(SkewbGLWidget w)
 		glRotatef(90.0, 1, 0, 0);
 		DRAW_STICKERLESS_CUBIT();
 		glPopMatrix();
-		DrawCubit(w, w->skewb.cubeLoc[BACK_FACE][0].face,
+		drawCubit(w, w->skewb.cubeLoc[BACK_FACE][0].face,
 			NO_FACE, NO_FACE,
 			w->skewb.cubeLoc[RIGHT_FACE][1].face,
 			w->skewb.cubeLoc[BOTTOM_FACE][1].face,
@@ -1462,7 +1457,7 @@ DrawCube(SkewbGLWidget w)
 		glRotatef(90.0, 1, 0, 0);
 		DRAW_STICKERLESS_CUBIT();
 		glPopMatrix();
-		DrawCubit(w, NO_FACE,
+		drawCubit(w, NO_FACE,
 			w->skewb.cubeLoc[FRONT_FACE][1].face,
 			NO_FACE,
 			w->skewb.cubeLoc[RIGHT_FACE][2].face,
@@ -1476,7 +1471,7 @@ DrawCube(SkewbGLWidget w)
 		glRotatef(90.0, 0, 0, 1);
 		DRAW_STICKERLESS_CUBIT();
 		glPopMatrix();
-		DrawCubit(w,
+		drawCubit(w,
 			w->skewb.cubeLoc[BACK_FACE][2].face,
 			NO_FACE,
 			w->skewb.cubeLoc[LEFT_FACE][3].face,
@@ -1487,7 +1482,7 @@ DrawCube(SkewbGLWidget w)
 		glRotatef(90.0, 0, 0, 1);
 		DRAW_STICKERLESS_CUBIT();
 		glPopMatrix();
-		DrawCubit(w, NO_FACE,
+		drawCubit(w, NO_FACE,
 			w->skewb.cubeLoc[FRONT_FACE][3].face,
 			w->skewb.cubeLoc[LEFT_FACE][0].face,
 			NO_FACE, NO_FACE,
@@ -1497,7 +1492,7 @@ DrawCube(SkewbGLWidget w)
 		glRotatef(90.0, 0, 1, 0);
 		DRAW_STICKERLESS_CUBIT();
 		glPopMatrix();
-		DrawCubit(w,
+		drawCubit(w,
 			w->skewb.cubeLoc[BACK_FACE][1].face,
 			NO_FACE, NO_FACE,
 			w->skewb.cubeLoc[RIGHT_FACE][0].face,
@@ -1505,7 +1500,7 @@ DrawCube(SkewbGLWidget w)
 			w->skewb.cubeLoc[TOP_FACE][0].face); /* BUR */
 		glTranslatef(0, 0, S1);
 		DRAW_STICKERLESS_CUBIT();
-		DrawCubit(w, NO_FACE,
+		drawCubit(w, NO_FACE,
 			w->skewb.cubeLoc[FRONT_FACE][0].face,
 			NO_FACE,
 			w->skewb.cubeLoc[RIGHT_FACE][3].face,
@@ -1519,7 +1514,7 @@ DrawCube(SkewbGLWidget w)
 }
 
 void
-DrawAllPiecesGL(SkewbGLWidget w)
+drawAllPiecesGL(SkewbGLWidget w)
 {
 #ifdef WINVER
 	wglMakeCurrent(w->core.hDC, hRC);
@@ -1556,8 +1551,8 @@ DrawAllPiecesGL(SkewbGLWidget w)
 	default:
 		break;
 	}
-	if (!DrawCube(w)) {
-		DISPLAY_WARNING("DrawCube error");
+	if (!drawCube(w)) {
+		DISPLAY_WARNING("drawCube error");
 	}
 	glPopMatrix();
 	glFlush();
@@ -1569,20 +1564,21 @@ DrawAllPiecesGL(SkewbGLWidget w)
 }
 
 void
-DrawFrameGL(SkewbGLWidget w, Boolean focus)
+drawFrameGL(SkewbGLWidget w, Boolean focus)
 {
 	/* UNUSED */
 }
 
 Boolean
-SelectPiecesGL(SkewbGLWidget w, int x, int y, int *face, int *position)
+selectPiecesGL(SkewbGLWidget w, int x, int y, int *face, int *position)
 {
 	/* UNUSED */
 	return True;
 }
 
 #ifdef WINVER
-Boolean setupPixelFormat(SkewbGLWidget w, BYTE type, DWORD flags)
+static Boolean
+setupPixelFormat(SkewbGLWidget w, BYTE type, DWORD flags)
 {
 	PIXELFORMATDESCRIPTOR pfd;
 	int pixelFormat;
@@ -1623,13 +1619,13 @@ Boolean setupPixelFormat(SkewbGLWidget w, BYTE type, DWORD flags)
 #else
 
 static Boolean
-SetValuesPuzzleGL(Widget current, Widget request, Widget renew)
+setValuesPuzzleGL(Widget current, Widget request, Widget renew)
 {
 	SkewbGLWidget c = (SkewbGLWidget) current, w = (SkewbGLWidget) renew;
 	Boolean redraw = False;
 
 	if (w->skewb.view != c->skewb.view) {
-		ResizePuzzleGL(w);
+		resizePuzzleGL(w);
 		redraw = True;
 	}
 #if 0
@@ -1639,7 +1635,7 @@ SetValuesPuzzleGL(Widget current, Widget request, Widget renew)
 			w->skewbGL.cubeSizex.y != c->skewbGL.cubeSizex.y ||
 			w->skewbGL.cubeSizey.y != c->skewbGL.cubeSizey.y ||
 			w->skewbGL.cubeSizez.y != c->skewbGL.cubeSizez.y) {
-		ResizePuzzleGL(w);
+		resizePuzzleGL(w);
 		redraw = True;
 	}
 #endif
@@ -1681,7 +1677,7 @@ initGL(SkewbGLWidget w) {
 static
 #endif
 void
-ResizePuzzleGL(SkewbGLWidget w)
+resizePuzzleGL(SkewbGLWidget w)
 {
 #ifdef WINVER
 	RECT rect;
@@ -1723,7 +1719,7 @@ makeCurrentGL(SkewbGLWidget w)
 			DefaultScreen(XtDisplay(w))));
 #endif
 	}
-	ResizePuzzleGL(w);
+	resizePuzzleGL(w);
 
 	glDrawBuffer(GL_BACK);
 	glClearDepth(1.0);
@@ -1763,14 +1759,14 @@ makeCurrentGL(SkewbGLWidget w)
 
 #ifndef WINVER
 static void
-InitializePuzzleGL(Widget request, Widget renew)
+initializePuzzleGL(Widget request, Widget renew)
 {
 	SkewbGLWidget w = (SkewbGLWidget) renew;
 
-	SetAllColors((SkewbWidget) w);
+	setAllColors((SkewbWidget) w);
 	(void) initGL(w);
 	w->skewb.dim = 4; /* 2 and 3 already taken */
-	ResizePuzzleGL(w);
+	resizePuzzleGL(w);
 }
 #endif
 
@@ -1778,7 +1774,7 @@ InitializePuzzleGL(Widget request, Widget renew)
 static
 #endif
 void
-ExposePuzzleGL(
+exposePuzzleGL(
 #ifdef WINVER
 SkewbGLWidget w
 #else
@@ -1806,78 +1802,78 @@ Widget renew, XEvent *event, Region region
 	if (!madeCurrent) {
 		makeCurrentGL(w);
 	}
-	DrawFrameGL(w, w->skewb.focus);
-	DrawAllPiecesGL(w);
+	drawFrameGL(w, w->skewb.focus);
+	drawAllPiecesGL(w);
 }
 
 #ifndef WINVER
 static void
-MovePuzzleGLTl(SkewbGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLTl(SkewbGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		TL,
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzleGLTop(SkewbGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLTop(SkewbGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		TOP,
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzleGLTr(SkewbGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLTr(SkewbGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		TR,
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzleGLLeft(SkewbGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLLeft(SkewbGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		LEFT,
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzleGLRight(SkewbGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLRight(SkewbGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		RIGHT,
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzleGLBl(SkewbGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLBl(SkewbGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		BL,
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzleGLBottom(SkewbGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLBottom(SkewbGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		BOTTOM,
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
 }
 
 static void
-MovePuzzleGLBr(SkewbGLWidget w, XEvent *event, char **args, int nArgs)
+movePuzzleGLBr(SkewbGLWidget w, XEvent *event, char **args, int nArgs)
 {
-	MovePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
+	movePuzzleInput((SkewbWidget) w, event->xbutton.x, event->xbutton.y,
 		BR,
 		(int) (event->xkey.state & ControlMask),
 		(int) (event->xkey.state & Mod1Mask));
