@@ -1,7 +1,7 @@
 /*
  * @(#)xskewb.c
  *
- * Copyright 1993 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1993 - 2009  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -22,7 +22,7 @@
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Skewb Version 7.4.1\n"
+"Skewb Version 7.5\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -782,7 +782,7 @@ puzzleListener(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 	case ACTION_SOLVE_MESSAGE:
 #ifdef WINVER
 		(void) MessageBox(w->core.hWnd, solveHelp,
-			"Auto-Solve", MB_OK);
+			"Auto-solve", MB_OK);
 #else
 #ifdef HAVE_MOTIF
 		XtManageChild(solveDialog);
@@ -1261,7 +1261,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			break;
 		case ACTION_VIEW:
 			(void) viewPuzzle(&widget);
-			sizePuzzle(&widget);
+			resizePuzzle(&widget);
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_TR:
@@ -1664,13 +1664,13 @@ main(int argc, char **argv)
 	XmStringFree(playString);
 	getString = XmStringCreateSimple((char *) "Get");
 	writeString = XmStringCreateSimple((char *) "Write");
-	quitString = XmStringCreateSimple((char *) "Quit");
+	quitString = XmStringCreateSimple((char *) "Exit");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
 		0, fileMenuListener,
 		XmVaPUSHBUTTON, getString, 'G', NULL, NULL,
 		XmVaPUSHBUTTON, writeString, 'W', NULL, NULL,
 		XmVaSEPARATOR,
-		XmVaPUSHBUTTON, quitString, 'Q', NULL, NULL,
+		XmVaPUSHBUTTON, quitString, 'x', NULL, NULL,
 		NULL);
 	XmStringFree(getString);
 	XmStringFree(writeString);
@@ -1679,12 +1679,12 @@ main(int argc, char **argv)
 	redoString = XmStringCreateSimple((char *) "Redo");
 	clearString = XmStringCreateSimple((char *) "Clear");
 	practiceString = XmStringCreateSimple((char *) "Practice");
-	randomizeString = XmStringCreateSimple((char *) "RandomiZe");
-	solveString = XmStringCreateSimple((char *) "(Auto-Solve)");
+	randomizeString = XmStringCreateSimple((char *) "Randomize");
+	solveString = XmStringCreateSimple((char *) "(Auto-solve)");
 	orientizeString = XmStringCreateSimple((char *) "Orientize");
-	speedString = XmStringCreateSimple((char *) ">Speed");
-	slowString = XmStringCreateSimple((char *) "<Slow");
-	soundString = XmStringCreateSimple((char *) "@Sound");
+	speedString = XmStringCreateSimple((char *) "Speed >");
+	slowString = XmStringCreateSimple((char *) "Slow <");
+	soundString = XmStringCreateSimple((char *) "Sound @");
 	viewString = XmStringCreateSimple((char *) "View");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "play_menu",
 		1, playCB,
@@ -1692,8 +1692,8 @@ main(int argc, char **argv)
 		XmVaPUSHBUTTON, redoString, 'R', NULL, NULL,
 		XmVaPUSHBUTTON, clearString, 'C', NULL, NULL,
 		XmVaPUSHBUTTON, practiceString, 'P', NULL, NULL,
-		XmVaPUSHBUTTON, randomizeString, 'Z', NULL, NULL,
-		XmVaPUSHBUTTON, solveString, 'S', NULL, NULL,
+		XmVaPUSHBUTTON, randomizeString, 'z', NULL, NULL,
+		XmVaPUSHBUTTON, solveString, 's', NULL, NULL,
 		XmVaPUSHBUTTON, orientizeString, 'O', NULL, NULL,
 		XmVaPUSHBUTTON, speedString, '>', NULL, NULL,
 		XmVaPUSHBUTTON, slowString, '<', NULL, NULL,
