@@ -39,6 +39,10 @@
 #define DATAFILE "threed.dat"
 #endif
 
+#if defined( USE_SOUND ) && defined( USE_NAS )
+Display *dsp;
+#endif
+
 static void initializeThreeD(Widget request, Widget renew);
 static void exposeThreeD(Widget renew, XEvent *event, Region region);
 static void resizeThreeD(ThreeDWidget w);
@@ -1454,6 +1458,11 @@ destroyThreeD(Widget old)
 	ThreeDWidget w = (ThreeDWidget) old;
 	int i;
 
+#if 0
+#if defined( USE_SOUND ) && defined( USE_ESOUND )
+	(void) shutdown_sound();
+#endif
+#endif
 	for (i = 0; i < COLORS; i++)
 		XtReleaseGC(old, w->threed.shadeGC[i]);
 	XtReleaseGC(old, w->threed.graphicsGC);
@@ -1610,6 +1619,16 @@ Widget request, Widget renew
 #else
 	setAllColors(w);
 #endif
+#ifdef USE_SOUND
+#ifdef USE_NAS
+	dsp = XtDisplay(w);
+#endif
+#if 0
+#ifdef USE_ESOUND
+	(void) init_sound();
+#endif
+#endif
+#endif
 }
 
 #ifndef WINVER
