@@ -120,11 +120,8 @@ typedef struct _Surface {
 	Boolean twoSided;
 	Boolean clipped;
 	Boolean active;
-#ifdef DEPTHINDEX
-	int     depthIndex;
-#else
+	int     depthIndex; /* links surfaces, old use obscure */
 	double  averageDepth;
-#endif
 	double  normalLength;
 } Surface;
 
