@@ -1,7 +1,7 @@
 /*
  * @(#)xthreed.c
  *
- * Copyright 1994 - 2008  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2009  David A. Bagley, bagleyd@tux.org
  *
  * All rights reserved.
  *
@@ -22,7 +22,7 @@
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Threed Version 7.4.1\n"
+"Threed Version 7.5\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -1161,15 +1161,15 @@ int main(int argc, char **argv)
 		NULL);
 	XmStringFree(fileString);
 	XmStringFree(controlsString);
-	quitString = XmStringCreateSimple((char *) "Quit");
+	quitString = XmStringCreateSimple((char *) "Exit");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "file_menu",
 		0, fileMenuListener,
-		XmVaPUSHBUTTON, quitString, 'Q', NULL, NULL,
+		XmVaPUSHBUTTON, quitString, 'x', NULL, NULL,
 		NULL);
 	XmStringFree(quitString);
-	speedString = XmStringCreateSimple((char *) ">Speed");
-	slowString = XmStringCreateSimple((char *) "<Slow");
-	soundString = XmStringCreateSimple((char *) "@Sound");
+	speedString = XmStringCreateSimple((char *) "Speed >");
+	slowString = XmStringCreateSimple((char *) "Slow <");
+	soundString = XmStringCreateSimple((char *) "Sound @");
 	(void) XmVaCreateSimplePulldownMenu(menuBar, (char *) "controlsMenu",
 		1, controlsMenuListener,
 		XmVaPUSHBUTTON, speedString, '>', NULL, NULL,
