@@ -53,6 +53,10 @@
 #else
 #include "picture.h"
 
+#if defined( USE_SOUND ) && defined( USE_NAS )
+Display *dsp;
+#endif
+
 #ifndef LOGPATH
 #ifdef VMS
 #define LOGPATH "SYS$SCRATCH:"
@@ -2305,6 +2309,11 @@ destroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int i;
 
+#if 0
+#if defined( USE_SOUND ) && defined( USE_ESOUND )
+	(void) shutdown_sound();
+#endif
+#endif
 	XtReleaseGC(old, w->triangles.textGC);
 	for (i = 0; i < FG_SHADES; i++)
                 XtReleaseGC(old, w->triangles.tileGC[i]);
@@ -2547,6 +2556,16 @@ Widget request, Widget renew
 	w->triangles.cheat = False;
 	w->triangles.cw = (NRAND(2) == 0); /* they take the same # of moves */
 	sizePuzzle(w);
+#ifdef USE_SOUND
+#ifdef USE_NAS
+	dsp = XtDisplay(w);
+#endif
+#if 0
+#ifdef USE_ESOUND
+	(void) init_sound();
+#endif
+#endif
+#endif
 }
 
 #ifndef WINVER
